#include <glib.h>
#include <glib-object.h>
#include <lasso/lasso.h>
#include <config.h>
#include <jni.h>
#include "com_entrouvert_lasso_LassoJNI.h"
#include <string.h>
#include "../ghashtable.h"

#if defined(__GNUC__)
#  define lasso_log(level, filename, line, function, format, args...) \
        g_log("Lasso", level, "%s:%i:%s" format, filename, line, function, ##args)
#elif defined(HAVE_VARIADIC_MACROS)
#  define lasso_log(level, format, line, function, ...)  \
        g_log("Lasso", leve, "%s:%i:%s" format, filename, line, function, __VA_ARGS__)
#else
static inline void lasso_log(GLogLevelFlags level, const char *filename,
    int line, const char *function, const char *format, ...)
{
	va_list ap;
	char s[1024];
	va_start(ap, format);
	g_vsnprintf(s, 1024, format, ap);
	va_end(ap);
    g_log("Lasso", level, "%s:%i:%s %s", filename, line, function, s);
}
#define lasso_log lasso_log
#endif

#include "../../lasso/utils.h"
#include "../utils.c"
#include "../../lasso/backward_comp.h"

#define LASSO_ROOT "com/entrouvert/lasso/"
#define check_exception (*env)->ExceptionCheck(env)
#define g_return_val_if_exception(value) if ((*env)->ExceptionCheck(env)) return (value);
#define g_return_if_exception() if ((*env)->ExceptionCheck(env)) return;
#define convert_jlong_to_gobject(value) ((GObject*)(ptrdiff_t)value)
#define g_error_if_fail(value) { if (!(value)) { g_on_error_query("LassoJNI"); } }
#define PTR_TO_JLONG(x) (jlong)((ptrdiff_t)x)

static GQuark lasso_wrapper_key = 0;
typedef int (*Converter)(JNIEnv *env, void *from, jobject *to);
typedef int *(*OutConverter)(JNIEnv *env, jobject from, gpointer *to);

/* Static declarations */
G_GNUC_UNUSED static int gpointer_equal(const gpointer p1, const gpointer p2);
G_GNUC_UNUSED static int new_object_with_gobject(JNIEnv *env, GObject *obj, const char *clsName, jobject *jobj);
G_GNUC_UNUSED static int jstring_to_local_string(JNIEnv *env, jstring jstr, const char **str);
G_GNUC_UNUSED static void release_local_string(JNIEnv *env, jstring str, const char *utf_str);
G_GNUC_UNUSED static int get_jlong_field(JNIEnv *env, jobject obj, const char *field, jlong *dest);
G_GNUC_UNUSED static jclass get_jclass_by_name(JNIEnv *env, const char *name);
G_GNUC_UNUSED static int get_array_element(JNIEnv *env, jobjectArray arr, jsize i, jobject *dest);
G_GNUC_UNUSED static int set_array_element(JNIEnv *env, jobjectArray arr, jsize i, jobject value);
G_GNUC_UNUSED static int get_array_size(JNIEnv *env, jobjectArray arr, jsize *dest);
G_GNUC_UNUSED static int create_object_array(JNIEnv *env, const char *clsName, jsize size, jobjectArray *jarr);
G_GNUC_UNUSED static jobject get_shadow_object(JNIEnv *env, GObject *obj);
G_GNUC_UNUSED static void set_shadow_object(JNIEnv *env, GObject *obj, jobject shadow_object);
G_GNUC_UNUSED static void exception(JNIEnv *env, const char *message);
G_GNUC_UNUSED static int string_to_jstring(JNIEnv *env, const char* str, jstring *jstr);
G_GNUC_UNUSED static int string_to_jstring_and_free(JNIEnv *env, char* str, jstring *jstr);
G_GNUC_UNUSED static int jstring_to_string(JNIEnv *env, jstring jstr, char **str);
G_GNUC_UNUSED static int xml_node_to_jstring(JNIEnv *env, xmlNode *xmlnode, jstring *jstr);
G_GNUC_UNUSED static int jstring_to_xml_node(JNIEnv *env, jstring jstr, xmlNode **xmlnode);
G_GNUC_UNUSED static int gobject_to_jobject_aux(JNIEnv *env, GObject *obj, gboolean doRef, jobject *job);
G_GNUC_UNUSED static int gobject_to_jobject(JNIEnv *env, GObject *obj, jobject *jobj);
G_GNUC_UNUSED static int gobject_to_jobject_and_ref(JNIEnv *env, GObject *obj, jobject *jobj);

G_GNUC_UNUSED static int jobject_to_gobject(JNIEnv *env, jobject obj, GObject **gobj);
G_GNUC_UNUSED static int jobject_to_gobject_noref(JNIEnv *env, jobject obj, GObject **gobj);
G_GNUC_UNUSED static void free_glist(GList **list, GFunc free_function);
G_GNUC_UNUSED static int get_list(JNIEnv *env, const char *clsName, const GList *list, Converter convert, jobjectArray *jarr);
G_GNUC_UNUSED static int set_list(JNIEnv *env, GList **list, jobjectArray jarr, GFunc free_function, OutConverter convert);
G_GNUC_UNUSED static int remove_from_list(JNIEnv *env,GList **list,jobject obj,GFunc free_function,GCompareFunc compare,OutConverter convert);
G_GNUC_UNUSED static int add_to_list(JNIEnv* env, GList** list, jobject obj, OutConverter convert);
G_GNUC_UNUSED static int get_hash(JNIEnv *env, char *clsName, GHashTable *hashtable, Converter convert, jobjectArray *jarr);
G_GNUC_UNUSED static int set_hash_of_objects(JNIEnv *env, GHashTable *hashtable, jobjectArray jarr);
G_GNUC_UNUSED static int set_hash_of_strings(JNIEnv *env, GHashTable *hashtable, jobjectArray jarr);
G_GNUC_UNUSED static int remove_from_hash(JNIEnv *env, GHashTable *hashtable, jstring jkey);
G_GNUC_UNUSED static int add_to_hash(JNIEnv *env, GHashTable *hashtable, jstring jkey, jobject jvalue, OutConverter convert, GFunc free_function);
G_GNUC_UNUSED static int get_hash_by_name(JNIEnv *env, GHashTable *hashtable, jstring jkey, Converter convert, jobject *jvalue);
#define get_list_of_strings(env,list,jarr) get_list(env,"java/lang/String",list,(Converter)string_to_jstring,jarr)
#define get_list_of_xml_nodes(env,list,jarr) get_list(env,"java/lang/String",list,(Converter)xml_node_to_jstring,jarr)
#define get_list_of_objects(env,list,jarr) get_list(env,"java/lang/Object",list,(Converter)gobject_to_jobject_and_ref,jarr)
#define set_list_of_strings(env,list,jarr) set_list(env,list,jarr,(GFunc)g_free,(OutConverter)jstring_to_string)
#define set_list_of_xml_nodes(env,list,jarr) set_list(env,list,jarr,(GFunc)xmlFreeNode,(OutConverter)jstring_to_xml_node)
#define set_list_of_objects(env,list,jarr) set_list(env,list,jarr,(GFunc)g_object_unref,(OutConverter)jobject_to_gobject)
// remove_from_list_of_strings is now implemented directly
//#define remove_from_list_of_strings(env,list,obj) remove_from_list(env,list,obj,(GFunc)g_free,(GCompareFunc)strcmp,(OutConverter)jstring_to_local_string)
//#define remove_from_list_of_xml_nodes(env,list,obj) remove_from_list(env,list,obj,(GFunc)xmlFreeNode,(GCompareFunc)strcmp,(OutConverter)jstring_to_xml_node)
#define remove_from_list_of_objects(env,list,obj) remove_from_list(env,list,obj,(GFunc)g_object_unref,(GCompareFunc)gpointer_equal,(OutConverter)jobject_to_gobject_noref)
#define add_to_list_of_strings(env,list,obj) add_to_list(env,list,obj,(OutConverter)jstring_to_string)
#define add_to_list_of_xml_nodes(env,list,obj) add_to_list(env,list,obj,(OutConverter)jstring_to_xml_node)
// Use jobject_to_gobject_for_list because ref count must be augmented by one when inserted inside a list
#define add_to_list_of_objects(env,list,obj) add_to_list(env,list,obj,(OutConverter)jobject_to_gobject)
#define get_hash_of_strings(env,hash,jarr) get_hash(env,"java/lang/String",hash,(Converter)string_to_jstring, jarr)
#define get_hash_of_objects(env,hash,jarr) get_hash(env,"java/lang/Object",hash,(Converter)gobject_to_jobject_and_ref, jarr)
//#define remove_from_hash_of_strings(env,hash,key) remove_from_hash(env,hash,key)
//#define remove_from_hash_of_objects(env,hash,key) remove_from_hash(env,hash,key)
#define add_to_hash_of_strings(env,hash,key,obj) add_to_hash(env,hash,key,obj,(OutConverter)jstring_to_string,(GFunc)g_free)
#define add_to_hash_of_objects(env,hash,key,obj) add_to_hash(env,hash,key,obj,(OutConverter)jobject_to_gobject,(GFunc)g_object_unref)
//#define get_hash_of_strings_by_name(end,hash,key) get_hash_by_name(end,hash,key,(Converter)string_to_jstring)
//#define get_hash_of_objects_by_name(end,hash,key) get_hash_by_name(end,hash,key,(Converter)gobject_to_jobject_and_ref)
G_GNUC_UNUSED static void throw_by_name(JNIEnv *env, const char *name, const char *msg);


static int
gpointer_equal(const gpointer p1, const gpointer p2) {
    return p1 != p2;
}

static int
new_object_with_gobject(JNIEnv *env, GObject *obj, const char *clsName, jobject *jobj) {
    jclass cls;
    jmethodID mid;

    g_error_if_fail(env && clsName && obj && G_IS_OBJECT(obj));

    lasso_return_val_if_fail((cls = (*env)->FindClass(env, clsName)), 0);
    lasso_return_val_if_fail((mid = (*env)->GetMethodID(env, cls, "<init>", "(J)V")), 0);
    lasso_return_val_if_fail((*jobj = (*env)->NewObject(env, cls, mid, PTR_TO_JLONG(obj))), 0);
    return 1;
}

/** Convert a java string to a jstring */
static int
jstring_to_local_string(JNIEnv *env, jstring jstr, const char **str)
{
    g_error_if_fail(env);

    if (jstr) {
        *str = (*env)->GetStringUTFChars(env, jstr, NULL);
        lasso_return_val_if_fail(*str, 0);
    } else {
        *str = NULL;
    }
    return 1;
}

/** Release a local string. IT'S MANDATORY TO CALL THIS !!! */
static void
release_local_string(JNIEnv *env, jstring str, const char *utf_str) {
    g_error_if_fail(env);

    if (utf_str && str) {
        (*env)->ReleaseStringUTFChars(env, str, utf_str);
    }
}

static int
get_jlong_field(JNIEnv *env, jobject obj, const char *field, jlong *dest)
{
    jclass cls;
    jfieldID fid;

    cls = (*env)->GetObjectClass(env, obj);
    lasso_return_val_if_fail(cls, 0);
    fid = (*env)->GetFieldID(env, cls, field, "J");
    lasso_return_val_if_fail(fid, 0);
    *dest = (*env)->GetLongField(env, obj, fid);
    g_return_val_if_exception(0);

    return 1;
}

static jclass
get_jclass_by_name(JNIEnv *env, const char *name) {
    return (*env)->FindClass(env,name);
}

static int
get_array_element(JNIEnv *env, jobjectArray arr, jsize i, jobject *dest) {
    *dest = (*env)->GetObjectArrayElement(env, arr, i);
    lasso_return_val_if_fail(! (*env)->ExceptionCheck(env), 0);
    return 1;
}

static int
set_array_element(JNIEnv *env, jobjectArray arr, jsize i, jobject value) {
        (*env)->SetObjectArrayElement(env, arr, i, value);
        g_return_val_if_exception(0);
        return 1;
}
static int
get_array_size(JNIEnv *env, jobjectArray jarr, jsize *dest) {
    *dest = (*env)->GetArrayLength(env, jarr);
    g_return_val_if_exception(0);
    return 1;
}
static int
create_object_array(JNIEnv *env, const char *clsName, jsize size, jobjectArray *jarr) {
    jclass cls;

    g_error_if_fail(env && clsName && jarr);

    cls = get_jclass_by_name(env, clsName);
    lasso_return_val_if_fail(cls, 0);
    *jarr = (*env)->NewObjectArray(env, size, get_jclass_by_name(env, clsName), NULL);
    lasso_return_val_if_fail(*jarr, 0);
    return 1;
}
static int nullWeakRef(JNIEnv *env, jweak weakRef) {
    return weakRef && (*env)->IsSameObject(env, weakRef, NULL);
}
/** Return the shadow object associated with the gobject.
 *  If the weak global reference is dead, frees it.
 *  If not shadow object is present, return NULL. */
static jobject
get_shadow_object(JNIEnv *env, GObject *obj) {
    jweak weakRef;

    g_error_if_fail (obj && env);
    weakRef = (jweak)g_object_get_qdata(obj, lasso_wrapper_key);
    if (weakRef == NULL) {
        return NULL;
    } else if (nullWeakRef(env, weakRef)) {
        /** Remove null weak ref. */
        (*env)->DeleteWeakGlobalRef(env, weakRef);
        g_object_set_qdata(obj, lasso_wrapper_key, NULL);
        return NULL;
    } else {
        return (*env)->NewLocalRef(env, weakRef);
    }
}
/** Sets the java shadow object associated with the GObject obj.
 * If a shadow object is already present, frees its weak global reference.
 * Replacing a non NULL weak global reference by another one should not happend.
 * It means that two java shadow object for the same GObject exist at the same time
 */
static void
set_shadow_object(JNIEnv *env, GObject *obj, jobject shadow_object) {
    jweak weakRef;
    jweak old_weakRef;

    g_error_if_fail(obj && env);

    old_weakRef = (jweak)g_object_get_qdata(obj, lasso_wrapper_key);
    if (old_weakRef) {
        if (shadow_object != NULL && ! (*env)->IsSameObject(env, old_weakRef, NULL)) {
            g_warning("remplacement d'un shadow object non nulle par un shadow object non nulle %p %p", shadow_object, old_weakRef);
        }
        (*env)->DeleteWeakGlobalRef(env, old_weakRef);
    }
    g_object_set_qdata(obj, lasso_wrapper_key, NULL);
    if (shadow_object) {
        weakRef = (*env)->NewWeakGlobalRef(env, shadow_object);
        g_object_set_qdata(obj, lasso_wrapper_key, weakRef);
    }
}
/** Throw a new RuntimeException containing this message. */
static void
exception(JNIEnv *env, const char *message) {
    jclass cls = (*env)->FindClass(env, "java/lang/RuntimeException");
    if (cls != NULL) {
        throw_by_name(env, "java/lang/RuntimeException", message);
    }
    (*env)->DeleteLocalRef(env, cls);
}

/* Conversion fonctions */
/** Convert a C string to java string. NULL is a valid C string giving a null
 * java object. */
static int
string_to_jstring(JNIEnv *env, const char* str, jstring *jstr) {
    if (str) {
        *jstr = (*env)->NewStringUTF(env, str);
        lasso_return_val_if_fail(jstr, 0);
    } else {
        *jstr = NULL;
    }
    return 1;
}

/** Convert a string to a java string then free it. Don't frees it
 * if conversion failed. */
static int
string_to_jstring_and_free(JNIEnv *env, char* str, jstring *jstr) {
    lasso_return_val_if_fail(string_to_jstring(env, str, jstr), 0);
    if (str)
        g_free(str);
    return 1;
}

/** Convert a jstring to a C string and copy it. Returned string is owner by the caller.*/
static int
jstring_to_string(JNIEnv *env, jstring jstr, char **str) {
    const char *local_str = NULL;

    lasso_return_val_if_fail(jstring_to_local_string(env, jstr, &local_str), 0);
    if (local_str) {
        lasso_assign_string(*str, local_str);
        release_local_string(env, jstr, local_str);
        if (!str) {
            /* Maybe launch a OutOfMemoryException. */
            exception(env, "could not alloc a copy of a jstring");
            return 0;
        }
    } else {
        *str = NULL;
    }
    return 1;
}


/* xmlNode handling */
static xmlBuffer*
xmlnode_to_xmlbuffer(xmlNode *node)
{
	xmlOutputBufferPtr output_buffer;
	xmlBuffer *buffer;

	if (! node)
		return NULL;

	buffer = xmlBufferCreate();
	output_buffer = xmlOutputBufferCreateBuffer(buffer, NULL);
	xmlNodeDumpOutput(output_buffer, NULL, node, 0, 0, NULL);
	xmlOutputBufferClose(output_buffer);
	xmlBufferAdd(buffer, BAD_CAST "", 1);

	return buffer;
}

static int
xml_node_to_jstring(JNIEnv *env, xmlNode *xmlnode, jstring *jstr) {
    xmlBuffer *buffer;

    g_error_if_fail(env);
    if (! xmlnode) {
        *jstr = NULL;
        return 1;
    }
    buffer = xmlnode_to_xmlbuffer(xmlnode);
    if (! buffer) {
        exception(env, "could not alloc an xml output buffer");
        return 0;
    }
    return string_to_jstring(env, (char*)xmlBufferContent(buffer), jstr);
}

/** Convert a java string to an xml node. Return 0 if it failed with an exception
 * throwed. */
static int
jstring_to_xml_node(JNIEnv *env, jstring jstr, xmlNode **xmlnode) {
    xmlDoc *doc = NULL;
    xmlNode *node = NULL;
    const char *local_str = NULL;
    int ret = 1;

    g_error_if_fail(env && xmlnode);
    lasso_return_val_if_fail(jstring_to_local_string(env, jstr, &local_str), 0);

    if (local_str) {
        node = lasso_string_fragment_to_xmlnode(local_str, 0);
    }
    lasso_assign_new_xml_node(*xmlnode, node)
    lasso_release_doc(doc);
    if (jstr && local_str)
        release_local_string(env, jstr, local_str);
    return ret;
}

/* lasso objects handling impl */
static void
create_class_name(char *dest, const char *typename) {
        char *ret = NULL;

        ret = strstr(typename, "Lasso");
        if (ret) {
            typename = ret+5;
        }
        strncpy(dest+sizeof(LASSO_ROOT)-1, typename,50);
        dest[sizeof(LASSO_ROOT)+49] = 0;
}
/** Convert the GObject obj to a java object encapsulating it.
 * If obj is NULL, return NULL.
 * Throws if obj is not a GObject or if anyhting fail. */
static int
gobject_to_jobject_aux(JNIEnv *env, GObject *obj, gboolean doRef, jobject *jobj) {
    jobject self = NULL;
    int ret = 1;

    if (obj == NULL) {
        goto out;
    }

    if (! G_IS_OBJECT(obj)) {
        exception(env, "tried to convert something that is not a GObject to a Java object");
        ret = 0;
        goto out;
    }

    /* Try to get an already created java object. */
    self = get_shadow_object(env, obj);
    if (self) {
        goto out;
    } else {
        /* Create the shadow object */
        char clsName[sizeof(LASSO_ROOT)+50] = LASSO_ROOT;
        const char *typename = NULL;

        typename = G_OBJECT_TYPE_NAME(obj);
        create_class_name(clsName, typename);
        if (! new_object_with_gobject(env, obj, clsName, &self)) {
            ret = 0;
            goto out;
        }
        set_shadow_object(env, obj, self);
        /** If all goes well increment reference count eventually. */
        if (doRef) {
            g_object_ref(obj);
        }
    }
out:
    *jobj = self;
    return ret;
}
/** Get or create a new java object encapsulating this lasso GObject, do not increase ref count if created. */
static int
gobject_to_jobject(JNIEnv *env, GObject *obj, jobject *jobj) {
    return gobject_to_jobject_aux(env, obj, FALSE, jobj);
}
/** Get or create a new java object encapsulating this lasso GObject, increase ref count if created. */
static int
gobject_to_jobject_and_ref(JNIEnv *env, GObject *obj, jobject *jobj) {
    return gobject_to_jobject_aux(env, obj, TRUE, jobj);
}

/** Get the gobject encapsulated by the java object obj. If cptr is
 * null return NULL.
 * It throws and return 0 if anything fail unexpectedly. */
static int
jobject_to_gobject(JNIEnv *env, jobject obj, GObject **gobj) {
    jlong value = 0;
    GObject *gobject = NULL;

    g_error_if_fail(env);

    if (! obj) {
        *gobj = NULL;
        return 1;
    }
    lasso_return_val_if_fail(get_jlong_field(env, obj, "cptr", &value), 0);
    gobject = convert_jlong_to_gobject(value);
    if (gobject && ! G_IS_OBJECT(gobject)) {
#define s "jobject->cptr is not a pointer on a gobject: XXXXXXXXXXXXXXXXXXXXXXX"
        char str[] = s;
        snprintf(str, sizeof(s)-1, "jobject->cptr is not a pointer on a gobject = %p", gobject);
        exception(env, str);
#undef s
        return 0;
    } else {
        lasso_assign_gobject(*gobj, gobject);
        return 1;
    }
}

/** Get the gobject encapsulated by the java object obj and increase its ref count. The only
 * use for this function is composed with set_list_of_objects or set_hash_of_object. */
static int
jobject_to_gobject_noref(JNIEnv *env, jobject obj, GObject **gobj) {
    lasso_return_val_if_fail(jobject_to_gobject(env, obj, gobj), 0);
    if (*gobj) {
        g_object_unref(*gobj);
    }
    return 1;
}

/* List handling */
static void
free_glist(GList **list, GFunc free_function) {
    lasso_return_if_fail(list);
    if (*list) {
        if (free_function) {
            g_list_foreach(*list, free_function, NULL);
        }
        g_list_free(*list);
    }
    *list = NULL;
}

/** Get an object array from a GList*, convert C object to java object using
 * the convert function.
 *
 * Can throw. If list is null or empty, return NULL.
 */
static int
get_list(JNIEnv *env, const char *clsName, const GList *list, Converter convert, jobjectArray *jarr) {
    jsize l,i;
    jclass cls;

    g_error_if_fail (env && clsName && convert);
    l = g_list_length((GList*)list);
    if (!l) {
        *jarr = NULL;
        goto out;
    }
    cls = get_jclass_by_name(env, clsName);
    lasso_return_val_if_fail(cls, 0);

    lasso_return_val_if_fail(create_object_array(env, clsName, l, jarr), 0);
    for (i=0;i<l;i++) {
        jobject item;

        lasso_return_val_if_fail(convert(env, list->data, &item), 0);
        lasso_return_val_if_fail(set_array_element(env, *jarr, i, item), 0);
        list = g_list_next(list);
    }
out:
    return 1;
}

/** Sets a GList* field using a java array of object. Use free_function if an old list exist.
 * Use convert to convert the java objects to C values. */
static int
set_list(JNIEnv *env, GList **list, jobjectArray jarr, GFunc free_function, OutConverter convert) {
    jobject element = NULL;
    jsize size = 0;
    jsize i = 0;
    GList *new = NULL;

    g_error_if_fail (list && free_function && convert && env);
    if (jarr) {
        if (! get_array_size(env, jarr, &size))
            goto error;
        for (i=0; i < size; i++) {
            gpointer result = NULL;

            if (! get_array_element(env, jarr, i, &element)
                || ! convert(env, element, &result)) {
                goto error;
            }
            new =  g_list_append(new, result);
        }
    }

    free_glist(list, free_function);
    *list = new;
    return 1;

error:
    free_glist(&new, free_function);
    return 0;
}
/** Remove a value obtained via the convert function on obj from *list.
 * It is searched inside *list using the compare function.
 * If pointer is found, it is freed using the free_function.
 * Return 0 if an exception was throwed.
 **/
static int
remove_from_list(JNIEnv *env, GList **list, jobject obj, GFunc free_function, GCompareFunc compare, OutConverter convert) {
    gpointer data = NULL;
    GList *found = NULL;

    g_error_if_fail(env && list && compare && convert && free_function);
    lasso_return_val_if_fail(obj, 1);
    lasso_return_val_if_fail(convert(env, obj, &data), 0);
    found = g_list_find_custom(*list, data, compare);
    if (found) {
        free_function(found->data, NULL);
        *list = g_list_delete_link(*list, found);
    }
    return 1;
}
static int
remove_from_list_of_strings(JNIEnv *env, GList **list, jstring jstr) {
    const char *local_string = NULL;
    GList *found = NULL;

    g_error_if_fail(env && list);
    lasso_return_val_if_fail(jstr, 1);
    lasso_return_val_if_fail(jstring_to_local_string(env, jstr, &local_string), 0);
    found = g_list_find_custom(*list, local_string, (GCompareFunc)g_strcmp0);
    if (found) {
        g_free(found->data);
        *list = g_list_delete_link(*list, found);
    }
    release_local_string(env, jstr, local_string);
    return 1;
}
/** Add obj to GList *list.
 * Returns 1.
 * Returns 0 and throws if anything fail.
 */
static int
add_to_list(JNIEnv* env, GList** list, jobject obj, OutConverter convert) {
    gpointer data = NULL;

    g_error_if_fail(env && list && convert);
    lasso_return_val_if_fail(convert(env, obj, &data), 0);
    if (data)
        *list = g_list_append(*list, data);
    return 1;
}

/* Ghash table handling impl */
/** Create a java array from a GHashTable, using the convert function. */
static int
get_hash(JNIEnv *env, char *clsName, GHashTable *hashtable, Converter convert, jobjectArray *jarr)
{
    jsize l = 0, i = 0;

    GList *keys = NULL, *values = NULL;
    int ret = 1;

    g_error_if_fail (env && hashtable && convert);
    l = g_hash_table_size(hashtable);
    lasso_return_val_if_fail(create_object_array(env, clsName, 2*l, jarr), 0);
    keys = g_hash_table_get_keys(hashtable);
    values = g_hash_table_get_values(hashtable);
    if (! (keys && values)) {
        ret = 0;
        exception(env, "cannot allocate for converting GHashTable to an array");
        goto out;
    }
    for (i=0; i < 2*l && keys && values; i+=2) {
        jstring key = NULL;
        jobject value = NULL;

        if (! (string_to_jstring(env, (char*)keys->data, &key)
               && convert(env, (gpointer)values->data, &value)
               && set_array_element(env, *jarr, i, key)
               && set_array_element(env, *jarr, i+1, value))) {
               ret = 0;
               goto out;
        }
        keys = g_list_next(keys);
        values = g_list_next(values);
    }
out:
    if (keys)
        g_list_free(keys);
    if (values)
        g_list_free(values);
    return ret;
}
/** Fill a GHashTable with content of java array arr.
 * Even indexed element coressponds to keys (jstring) and
 * odd indexed one to value (GObject).
 * Returns 1.
 * Returns 0 and thows an exception if anything fail.
 */
static int
set_hash_of_objects(JNIEnv *env, GHashTable *hashtable, jobjectArray jarr)
{
    jsize l = 0, i = 0;

    g_error_if_fail (env && hashtable);
    if (jarr) {
        /** First increment ref count of object in jarr */
        lasso_return_val_if_fail(get_array_size(env, jarr, &l), 0);
        if (l % 2 != 0) {
            exception(env, "java array not of an even size");
            return 0;
        }
        for (i = 1; i < l; i += 2) {
            jobject jobj = NULL;
            GObject *gobj = NULL;

            lasso_return_val_if_fail(get_array_element(env, jarr, i, &jobj), 0);
            lasso_return_val_if_fail(jobject_to_gobject_noref(env, jobj, &gobj), 0);
            (*env)->DeleteLocalRef(env, jobj);
        }
        /* increment ref count of objects */
        for (i = 1; i < l; i += 2) {
            jobject jobj = NULL;
            GObject *gobj = NULL;

            get_array_element(env, jarr, i, &jobj);
            jobject_to_gobject(env, jobj, &gobj);
            (*env)->DeleteLocalRef(env, jobj);
        }
    }
    /** Remove old values, if hashtable is well initialized
     * it should unref objects automatically. */
    g_hash_table_remove_all(hashtable);
    /** Insert new values */
    if (jarr) {
        for (i = 0; i < l; i += 2) {
            jstring jkey = NULL;
            char *key = NULL;
            jobject jvalue = NULL;
            GObject *value = NULL;

            lasso_return_val_if_fail(get_array_element(env, jarr, i, &jkey), 0);
            lasso_return_val_if_fail(get_array_element(env, jarr, i+1, &jvalue), 0);
            lasso_return_val_if_fail(jstring_to_string(env, jkey, &key), 0);
            if (! jobject_to_gobject_noref(env, jvalue, &value)) {
                if (key)
                    g_free(key);
                g_hash_table_remove_all(hashtable);
                return 0;
            }
            g_hash_table_insert (hashtable, key, value);
            (*env)->DeleteLocalRef(env, jkey);
            (*env)->DeleteLocalRef(env, jvalue);
        }
    }
    return 1;
}
/** Insert a java String array, containing
 * keys at odd indexes, and values at even indexes into an existing
 * GHashTable. Old entries are lost, but hopefully deallocated by
 * the hashtable free functions --- setted at creation, see GLib
 * documentation.
 *
 * @param env the JNI context given by the JVM
 * @param hashtable an existing GHashTable
 * @param a ref to a java object Array of size multiple of two
 *
 * @return 1 if successful, 0 if anything bad happen.
 */
static int
set_hash_of_strings(JNIEnv *env, GHashTable *hashtable, jobjectArray jarr) {
    jsize l = 0, i = 0;

    g_error_if_fail (env && hashtable);

    g_hash_table_remove_all(hashtable);
    if (jarr) {
        lasso_return_val_if_fail(get_array_size(env, jarr, &l), 0);
        if (l % 2 != 0) {
            exception(env, "java array not of an even size");
            return 0;
        }
        for (i = 0; i < l; i += 2) {
            jstring jkey = NULL;
            char *key = NULL;
            jstring jvalue = NULL;
            char *value = NULL;

            lasso_return_val_if_fail(get_array_element(env, jarr, i, &jkey)
                                 && get_array_element(env, jarr, i+1, &jvalue)
                                 && jstring_to_string(env, jkey, &key), 0);
            if (! key) {
                exception(env, "key is null");
                return 0;
            }
            if (! jstring_to_string(env, jvalue, &value)) {
                if (key)
                    g_free(key);
                g_hash_table_remove_all(hashtable);
                return 0;
            }
            /* Can use insert because hash table is empty */
            g_hash_table_insert(hashtable, key, value);
            (*env)->DeleteLocalRef(env, jkey);
            (*env)->DeleteLocalRef(env, jvalue);
        }
    }
    return 1;
}

/** Remove the value for the given key from hashtable. */
static int
remove_from_hash(JNIEnv *env, GHashTable *hashtable, jstring jkey) {
    const char *key = NULL;

    g_error_if_fail (env && hashtable);

    lasso_return_val_if_fail(jstring_to_local_string(env, jkey, &key), 0);
    g_hash_table_remove(hashtable, key);
    release_local_string(env, jkey, key);
    return 1;
}
/** Add a jobject to an hashtable */
static int
add_to_hash(JNIEnv *env, GHashTable *hashtable, jstring jkey, jobject jvalue, OutConverter convert, GFunc free_function)
{
    void *value = NULL;
    char *key = NULL;

    g_error_if_fail (env && hashtable && key && convert);

    if (! (convert(env, jvalue, &value)
           && jstring_to_string(env, jkey, &key)))
           goto error;

    g_hash_table_replace(hashtable, key, value);
    return 1;
error:
    if (key)
        g_free(key);
    if (value)
        free_function(value, NULL);
    return 0;
}
static int
get_hash_by_name(JNIEnv *env, GHashTable *hashtable, jstring jkey, Converter convert, jobject *jvalue)
{
    const char *key = NULL;
    gpointer value = NULL;

    g_error_if_fail (env && hashtable && convert);

    lasso_return_val_if_fail(jstring_to_local_string(env, jkey, &key), 0);
    value = g_hash_table_lookup(hashtable, key);
    release_local_string(env, jkey, key);
    return convert(env, value, jvalue);
}
static void
throw_by_name(JNIEnv *env, const char *name, const char *msg)
{
    jclass cls = (*env)->FindClass(env, name);
    /* if cls is NULL, an exception has already been thrown */
    if (cls != NULL) {
        (*env)->ThrowNew(env, cls, msg);
    }
    /* free the local ref */
    (*env)->DeleteLocalRef(env, cls);
}


/* JNI Functions */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_init2(JNIEnv *env, jclass cls) {
    lasso_wrapper_key = g_quark_from_static_string("JavaLasso::wrapper");
}
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_destroy(JNIEnv *env, jclass cls, jlong cptr) {
    GObject *obj = (GObject*)(ptrdiff_t)cptr;
    set_shadow_object(env, obj, NULL);
    g_object_unref(obj);
}
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_set_1shadow_1object(JNIEnv *env, jclass cls, jlong cptr, jobject shadow_object) {
    GObject *gobj = NULL;

    gobj = convert_jlong_to_gobject(cptr);
    set_shadow_object(env, gobj, shadow_object);
}


#include <lasso/ctypes.h>
#include <lasso/export.h>
#include <lasso/errors.h>
#include <lasso/registry.h>
#include <lasso/backward_comp.h>
#include <lasso/key.h>
#include <lasso/debug.h>
#include <lasso/lasso.h>
#include <lasso/logging.h>
#include <lasso/utils.h>
#include <lasso/saml-2.0/profile.h>
#include <lasso/saml-2.0/name_id_management.h>
#include <lasso/saml-2.0/provider.h>
#include <lasso/saml-2.0/assertion_query.h>
#include <lasso/saml-2.0/ecp.h>
#include <lasso/saml-2.0/saml2_helper.h>
#include <lasso/xml/saml_authentication_statement.h>
#include <lasso/xml/lib_logout_response.h>
#include <lasso/xml/lib_authn_request_envelope.h>
#include <lasso/xml/saml_subject_confirmation.h>
#include <lasso/xml/lib_authn_request.h>
#include <lasso/xml/lib_status_response.h>
#include <lasso/xml/saml_subject_statement.h>
#include <lasso/xml/lib_register_name_identifier_request.h>
#include <lasso/xml/saml_conditions.h>
#include <lasso/xml/saml_name_identifier.h>
#include <lasso/xml/misc_text_node.h>
#include <lasso/xml/saml_advice.h>
#include <lasso/xml/lib_authn_context.h>
#include <lasso/xml/lib_federation_termination_notification.h>
#include <lasso/xml/paos_response.h>
#include <lasso/xml/saml_attribute_value.h>
#include <lasso/xml/saml_condition_abstract.h>
#include <lasso/xml/saml_assertion.h>
#include <lasso/xml/paos_request.h>
#include <lasso/xml/saml_attribute.h>
#include <lasso/xml/saml_subject_statement_abstract.h>
#include <lasso/xml/tools.h>
#include <lasso/xml/lib_subject.h>
#include <lasso/xml/saml_statement_abstract.h>
#include <lasso/xml/lib_register_name_identifier_response.h>
#include <lasso/xml/samlp_response_abstract.h>
#include <lasso/xml/samlp_status_code.h>
#include <lasso/xml/lib_authn_response.h>
#include <lasso/xml/lib_assertion.h>
#include <lasso/xml/lib_request_authn_context.h>
#include <lasso/xml/strings.h>
#include <lasso/xml/samlp_request.h>
#include <lasso/xml/saml_attribute_designator.h>
#include <lasso/xml/saml_subject.h>
#include <lasso/xml/lib_logout_request.h>
#include <lasso/xml/lib_authn_response_envelope.h>
#include <lasso/xml/saml_authority_binding.h>
#include <lasso/xml/xml_enc.h>
#include <lasso/xml/lib_name_identifier_mapping_response.h>
#include <lasso/xml/lib_idp_list.h>
#include <lasso/xml/lib_authentication_statement.h>
#include <lasso/xml/lib_name_identifier_mapping_request.h>
#include <lasso/xml/saml_attribute_statement.h>
#include <lasso/xml/lib_idp_entry.h>
#include <lasso/xml/saml_audience_restriction_condition.h>
#include <lasso/xml/lib_idp_entries.h>
#include <lasso/xml/xml.h>
#include <lasso/xml/lib_scoping.h>
#include <lasso/xml/saml_subject_locality.h>
#include <lasso/xml/samlp_request_abstract.h>
#include <lasso/xml/samlp_response.h>
#include <lasso/xml/samlp_status.h>
#include <lasso/xml/saml-2.0/samlp2_name_id_policy.h>
#include <lasso/xml/saml-2.0/saml2_name_id.h>
#include <lasso/xml/saml-2.0/samlp2_requested_authn_context.h>
#include <lasso/xml/saml-2.0/saml2_subject_locality.h>
#include <lasso/xml/saml-2.0/saml2_attribute_statement.h>
#include <lasso/xml/saml-2.0/saml2_audience_restriction.h>
#include <lasso/xml/saml-2.0/saml2_base_idabstract.h>
#include <lasso/xml/saml-2.0/saml2_condition_abstract.h>
#include <lasso/xml/saml-2.0/saml2_attribute_value.h>
#include <lasso/xml/saml-2.0/samlp2_artifact_resolve.h>
#include <lasso/xml/saml-2.0/samlp2_name_id_mapping_request.h>
#include <lasso/xml/saml-2.0/saml2_assertion.h>
#include <lasso/xml/saml-2.0/saml2_subject.h>
#include <lasso/xml/saml-2.0/samlp2_manage_name_id_request.h>
#include <lasso/xml/saml-2.0/samlp2_status_detail.h>
#include <lasso/xml/saml-2.0/saml2_statement_abstract.h>
#include <lasso/xml/saml-2.0/saml2_advice.h>
#include <lasso/xml/saml-2.0/samlp2_response.h>
#include <lasso/xml/saml-2.0/samlp2_logout_response.h>
#include <lasso/xml/saml-2.0/saml2_key_info_confirmation_data.h>
#include <lasso/xml/saml-2.0/samlp2_status.h>
#include <lasso/xml/saml-2.0/samlp2_attribute_query.h>
#include <lasso/xml/saml-2.0/samlp2_status_code.h>
#include <lasso/xml/saml-2.0/saml2_encrypted_element.h>
#include <lasso/xml/saml-2.0/saml2_action.h>
#include <lasso/xml/saml-2.0/saml2_key_info_confirmation_data_type.h>
#include <lasso/xml/saml-2.0/saml2_strings.h>
#include <lasso/xml/saml-2.0/samlp2_scoping.h>
#include <lasso/xml/saml-2.0/samlp2_authn_query.h>
#include <lasso/xml/saml-2.0/samlp2_request_abstract.h>
#include <lasso/xml/saml-2.0/saml2_conditions.h>
#include <lasso/xml/saml-2.0/samlp2_assertion_id_request.h>
#include <lasso/xml/saml-2.0/saml2_authn_statement.h>
#include <lasso/xml/saml-2.0/saml2_authz_decision_statement.h>
#include <lasso/xml/saml-2.0/samlp2_authn_request.h>
#include <lasso/xml/saml-2.0/samlp2_terminate.h>
#include <lasso/xml/saml-2.0/saml2_proxy_restriction.h>
#include <lasso/xml/saml-2.0/samlp2_artifact_response.h>
#include <lasso/xml/saml-2.0/saml2_authn_context.h>
#include <lasso/xml/saml-2.0/saml2_one_time_use.h>
#include <lasso/xml/saml-2.0/samlp2_idp_list.h>
#include <lasso/xml/saml-2.0/samlp2_name_id_mapping_response.h>
#include <lasso/xml/saml-2.0/samlp2_authz_decision_query.h>
#include <lasso/xml/saml-2.0/samlp2_extensions.h>
#include <lasso/xml/saml-2.0/saml2_evidence.h>
#include <lasso/xml/saml-2.0/saml2_attribute.h>
#include <lasso/xml/saml-2.0/samlp2_idp_entry.h>
#include <lasso/xml/saml-2.0/saml2_subject_confirmation.h>
#include <lasso/xml/saml-2.0/samlp2_manage_name_id_response.h>
#include <lasso/xml/saml-2.0/samlp2_subject_query_abstract.h>
#include <lasso/xml/saml-2.0/samlp2_logout_request.h>
#include <lasso/xml/saml-2.0/saml2_subject_confirmation_data.h>
#include <lasso/xml/saml-2.0/samlp2_status_response.h>
#include <lasso/xml/ecp/ecp_request.h>
#include <lasso/xml/ecp/ecp_response.h>
#include <lasso/xml/ecp/ecp_relaystate.h>
#include <lasso/xml/soap-1.1/soap_detail.h>
#include <lasso/xml/soap-1.1/soap_body.h>
#include <lasso/xml/soap-1.1/soap_envelope.h>
#include <lasso/xml/soap-1.1/soap_fault.h>
#include <lasso/xml/soap-1.1/soap_header.h>
#include <lasso/xml/dsig/ds_key_info.h>
#include <lasso/xml/dsig/xml_dsig.h>
#include <lasso/xml/dsig/ds_key_value.h>
#include <lasso/xml/dsig/ds_rsa_key_value.h>
#include <lasso/xml/dsig/strings.h>
#include <lasso/xml/dsig/ds_x509_data.h>
#include <lasso/id-ff/server.h>
#include <lasso/id-ff/federation.h>
#include <lasso/id-ff/login.h>
#include <lasso/id-ff/profile.h>
#include <lasso/id-ff/name_registration.h>
#include <lasso/id-ff/defederation.h>
#include <lasso/id-ff/provider.h>
#include <lasso/id-ff/session.h>
#include <lasso/id-ff/logout.h>
#include <lasso/id-ff/name_identifier_mapping.h>
#include <lasso/id-ff/identity.h>
#include <lasso/id-ff/lecp.h>
/* Declaration of constants */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ERROR_1UNDEFINED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ERROR_UNDEFINED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ERROR_1UNIMPLEMENTED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ERROR_UNIMPLEMENTED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ERROR_1OUT_1OF_1MEMORY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ERROR_OUT_OF_MEMORY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ERROR_1CAST_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ERROR_CAST_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1ERROR_1NODE_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_XML_ERROR_NODE_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1ERROR_1NODE_1CONTENT_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_XML_ERROR_NODE_CONTENT_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1ERROR_1ATTR_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_XML_ERROR_ATTR_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1ERROR_1ATTR_1VALUE_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_XML_ERROR_ATTR_VALUE_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1ERROR_1INVALID_1FILE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_XML_ERROR_INVALID_FILE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1ERROR_1OBJECT_1CONSTRUCTION_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_XML_ERROR_OBJECT_CONSTRUCTION_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1ERROR_1MISSING_1NAMESPACE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_XML_ERROR_MISSING_NAMESPACE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1ERROR_1SCHEMA_1INVALID_1FRAGMENT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_XML_ERROR_SCHEMA_INVALID_FRAGMENT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1ERROR_1ATTR_1VALUE_1INVALID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_XML_ERROR_ATTR_VALUE_INVALID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1SIGNATURE_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_SIGNATURE_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1INVALID_1SIGNATURE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_INVALID_SIGNATURE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1SIGNATURE_1TMPL_1CREATION_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_SIGNATURE_TMPL_CREATION_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1CONTEXT_1CREATION_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_CONTEXT_CREATION_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1PUBLIC_1KEY_1LOAD_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_PUBLIC_KEY_LOAD_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1PRIVATE_1KEY_1LOAD_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_PRIVATE_KEY_LOAD_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1CERTIFICATE_1LOAD_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_CERTIFICATE_LOAD_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1SIGNATURE_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_SIGNATURE_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1KEYS_1MNGR_1CREATION_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_KEYS_MNGR_CREATION_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1KEYS_1MNGR_1INIT_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_KEYS_MNGR_INIT_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1SIGNATURE_1VERIFICATION_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_SIGNATURE_VERIFICATION_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1CA_1CERT_1CHAIN_1LOAD_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_CA_CERT_CHAIN_LOAD_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1INVALID_1SIGALG_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_INVALID_SIGALG;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1DIGEST_1COMPUTE_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_DIGEST_COMPUTE_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1SIGNATURE_1TEMPLATE_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_SIGNATURE_TEMPLATE_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1TOO_1MUCH_1REFERENCES_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_TOO_MUCH_REFERENCES;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1INVALID_1REFERENCE_1FOR_1SAML_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_INVALID_REFERENCE_FOR_SAML;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1DECRYPTION_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_DECRYPTION_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1ENCRYPTION_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_ENCRYPTION_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1ERROR_1DECRYPTION_1FAILED_1MISSING_1PRIVATE_1KEY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DS_ERROR_DECRYPTION_FAILED_MISSING_PRIVATE_KEY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SERVER_1ERROR_1PROVIDER_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SERVER_ERROR_PROVIDER_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SERVER_1ERROR_1ADD_1PROVIDER_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SERVER_ERROR_ADD_PROVIDER_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SERVER_1ERROR_1ADD_1PROVIDER_1PROTOCOL_1MISMATCH_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SERVER_ERROR_ADD_PROVIDER_PROTOCOL_MISMATCH;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SERVER_1ERROR_1SET_1ENCRYPTION_1PRIVATE_1KEY_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SERVER_ERROR_SET_ENCRYPTION_PRIVATE_KEY_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SERVER_1ERROR_1INVALID_1XML_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SERVER_ERROR_INVALID_XML;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SERVER_1ERROR_1NO_1PROVIDER_1LOADED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SERVER_ERROR_NO_PROVIDER_LOADED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGOUT_1ERROR_1UNSUPPORTED_1PROFILE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGOUT_ERROR_UNSUPPORTED_PROFILE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGOUT_1ERROR_1REQUEST_1DENIED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGOUT_ERROR_REQUEST_DENIED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGOUT_1ERROR_1FEDERATION_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGOUT_ERROR_FEDERATION_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGOUT_1ERROR_1UNKNOWN_1PRINCIPAL_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGOUT_ERROR_UNKNOWN_PRINCIPAL;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGOUT_1ERROR_1PARTIAL_1LOGOUT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGOUT_ERROR_PARTIAL_LOGOUT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1QUERY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_QUERY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1POST_1MSG_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_POST_MSG;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1SOAP_1MSG_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_SOAP_MSG;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1HTTP_1METHOD_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_HTTP_METHOD;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1PROTOCOLPROFILE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_PROTOCOLPROFILE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1MSG_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_MSG;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1REMOTE_1PROVIDERID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_REMOTE_PROVIDERID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1UNSUPPORTED_1PROFILE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_UNSUPPORTED_PROFILE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1UNKNOWN_1PROFILE_1URL_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_UNKNOWN_PROFILE_URL;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1IDENTITY_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_IDENTITY_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1FEDERATION_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_FEDERATION_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1NAME_1IDENTIFIER_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_NAME_IDENTIFIER_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1BUILDING_1QUERY_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_BUILDING_QUERY_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1BUILDING_1REQUEST_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_BUILDING_REQUEST_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1BUILDING_1MESSAGE_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_BUILDING_MESSAGE_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1BUILDING_1RESPONSE_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_BUILDING_RESPONSE_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1SESSION_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_SESSION_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1BAD_1IDENTITY_1DUMP_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_BAD_IDENTITY_DUMP;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1BAD_1SESSION_1DUMP_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_BAD_SESSION_DUMP;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1RESPONSE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_RESPONSE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1STATUS_1CODE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_STATUS_CODE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1ARTIFACT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_ARTIFACT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1RESOURCE_1OFFERING_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_RESOURCE_OFFERING;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1SERVICE_1DESCRIPTION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_SERVICE_DESCRIPTION;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1SERVICE_1TYPE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_SERVICE_TYPE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1ASSERTION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_ASSERTION;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1SUBJECT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_SUBJECT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1NAME_1IDENTIFIER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_NAME_IDENTIFIER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1ARTIFACT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_ARTIFACT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1ENCRYPTION_1PRIVATE_1KEY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_ENCRYPTION_PRIVATE_KEY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1STATUS_1NOT_1SUCCESS_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_STATUS_NOT_SUCCESS;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1ISSUER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_ISSUER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1SERVICE_1INSTANCE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_SERVICE_INSTANCE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1ENDPOINT_1REFERENCE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_ENDPOINT_REFERENCE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1ENDPOINT_1REFERENCE_1ADDRESS_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_ENDPOINT_REFERENCE_ADDRESS;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1ISSUER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_ISSUER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1MISSING_1SERVER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_MISSING_SERVER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1UNKNOWN_1PROVIDER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_UNKNOWN_PROVIDER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1CANNOT_1VERIFY_1SIGNATURE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_CANNOT_VERIFY_SIGNATURE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1CANNOT_1FIND_1A_1PROVIDER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_CANNOT_FIND_A_PROVIDER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1RESPONSE_1DOES_1NOT_1MATCH_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_RESPONSE_DOES_NOT_MATCH_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1RESPONSE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_RESPONSE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1UNSUPPORTED_1BINDING_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_UNSUPPORTED_BINDING;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1ASSERTION_1CONDITIONS_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_ASSERTION_CONDITIONS;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1ASSERTION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_ASSERTION;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1UNKNOWN_1ISSUER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_UNKNOWN_ISSUER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1ISSUER_1IS_1NOT_1AN_1IDP_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_ISSUER_IS_NOT_AN_IDP;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1REQUEST_1DENIED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_REQUEST_DENIED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1ENDPOINT_1INDEX_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_ENDPOINT_INDEX_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1ERROR_1INVALID_1IDP_1LIST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_ERROR_INVALID_IDP_LIST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PARAM_1ERROR_1BAD_1TYPE_1OR_1NULL_1OBJ_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PARAM_1ERROR_1INVALID_1VALUE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PARAM_ERROR_INVALID_VALUE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PARAM_1ERROR_1CHECK_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PARAM_ERROR_CHECK_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PARAM_1ERROR_1NON_1INITIALIZED_1OBJECT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PARAM_ERROR_NON_INITIALIZED_OBJECT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1FEDERATION_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_FEDERATION_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1CONSENT_1NOT_1OBTAINED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_CONSENT_NOT_OBTAINED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1INVALID_1NAMEIDPOLICY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_INVALID_NAMEIDPOLICY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1REQUEST_1DENIED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_REQUEST_DENIED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1INVALID_1SIGNATURE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_INVALID_SIGNATURE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1UNSIGNED_1AUTHN_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_UNSIGNED_AUTHN_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1STATUS_1NOT_1SUCCESS_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_STATUS_NOT_SUCCESS;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1UNKNOWN_1PRINCIPAL_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_UNKNOWN_PRINCIPAL;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1NO_1DEFAULT_1ENDPOINT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_NO_DEFAULT_ENDPOINT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1ASSERTION_1REPLAY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_ASSERTION_REPLAY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1ASSERTION_1DOES_1NOT_1MATCH_1REQUEST_1ID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_ASSERTION_DOES_NOT_MATCH_REQUEST_ID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1ERROR_1INVALID_1ASSERTION_1SIGNATURE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_ERROR_INVALID_ASSERTION_SIGNATURE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DEFEDERATION_1ERROR_1MISSING_1NAME_1IDENTIFIER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DEFEDERATION_ERROR_MISSING_NAME_IDENTIFIER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1ERROR_1REDIRECT_1REQUEST_1FAULT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SOAP_ERROR_REDIRECT_REQUEST_FAULT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1FAULT_1REDIRECT_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SOAP_FAULT_REDIRECT_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1ERROR_1MISSING_1ENVELOPE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SOAP_ERROR_MISSING_ENVELOPE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1ERROR_1MISSING_1HEADER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SOAP_ERROR_MISSING_HEADER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1ERROR_1MISSING_1BODY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SOAP_ERROR_MISSING_BODY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1ERROR_1MISSING_1SOAP_1FAULT_1DETAIL_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SOAP_ERROR_MISSING_SOAP_FAULT_DETAIL;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1NAME_1IDENTIFIER_1MAPPING_1ERROR_1MISSING_1TARGET_1NAMESPACE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_NAME_IDENTIFIER_MAPPING_ERROR_MISSING_TARGET_NAMESPACE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1NAME_1IDENTIFIER_1MAPPING_1ERROR_1FORBIDDEN_1CALL_1ON_1THIS_1SIDE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_NAME_IDENTIFIER_MAPPING_ERROR_FORBIDDEN_CALL_ON_THIS_SIDE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1NAME_1IDENTIFIER_1MAPPING_1ERROR_1MISSING_1TARGET_1IDENTIFIER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_NAME_IDENTIFIER_MAPPING_ERROR_MISSING_TARGET_IDENTIFIER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DATA_1SERVICE_1ERROR_1UNREGISTERED_1DST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DATA_SERVICE_ERROR_UNREGISTERED_DST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DATA_1SERVICE_1ERROR_1CANNOT_1ADD_1ITEM_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DATA_SERVICE_ERROR_CANNOT_ADD_ITEM;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1MISSING_1CORRELATION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_MISSING_CORRELATION;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1MISSING_1SECURITY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_MISSING_SECURITY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1MISSING_1ASSERTION_1ID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_MISSING_ASSERTION_ID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1MISSING_1ENDPOINT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_MISSING_ENDPOINT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1SOAP_1FAULT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_SOAP_FAULT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1UNSUPPORTED_1SECURITY_1MECHANISM_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_UNSUPPORTED_SECURITY_MECHANISM;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1MISSING_1DESCRIPTION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_MISSING_DESCRIPTION;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1MISSING_1RESOURCE_1ID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_MISSING_RESOURCE_ID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1MISSING_1CREDENTIAL_1REF_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_MISSING_CREDENTIAL_REF;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1INVALID_1OR_1MISSING_1REFERENCE_1TO_1MESSAGE_1ID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_INVALID_OR_MISSING_REFERENCE_TO_MESSAGE_ID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1SECURITY_1MECHANISM_1CHECK_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_SECURITY_MECHANISM_CHECK_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1UNKNOWN_1STATUS_1CODE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_UNKNOWN_STATUS_CODE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1SERVER_1INTERACTION_1REQUIRED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_SERVER_INTERACTION_REQUIRED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1SERVER_1INTERACTION_1REQUIRED_1FOR_1DATA_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_SERVER_INTERACTION_REQUIRED_FOR_DATA;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1REDIRECT_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_REDIRECT_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1REDIRECT_1REQUEST_1UNSUPPORTED_1BY_1REQUESTER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_REDIRECT_REQUEST_UNSUPPORTED_BY_REQUESTER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1PROFILE_1ERROR_1MISSING_1SENDER_1ID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSF_PROFILE_ERROR_MISSING_SENDER_ID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DISCOVERY_1ERROR_1SVC_1METADATA_1REGISTER_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DISCOVERY_ERROR_SVC_METADATA_REGISTER_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DISCOVERY_1ERROR_1SVC_1METADATA_1ASSOCIATION_1ADD_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DISCOVERY_ERROR_SVC_METADATA_ASSOCIATION_ADD_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DISCOVERY_1ERROR_1MISSING_1REQUESTED_1SERVICE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DISCOVERY_ERROR_MISSING_REQUESTED_SERVICE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DISCOVERY_1ERROR_1FAILED_1TO_1BUILD_1ENDPOINT_1REFERENCE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DISCOVERY_ERROR_FAILED_TO_BUILD_ENDPOINT_REFERENCE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DST_1ERROR_1MISSING_1SERVICE_1DATA_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DST_ERROR_MISSING_SERVICE_DATA;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DST_1ERROR_1QUERY_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DST_ERROR_QUERY_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DST_1ERROR_1QUERY_1PARTIALLY_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DST_ERROR_QUERY_PARTIALLY_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DST_1ERROR_1MODIFY_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DST_ERROR_MODIFY_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DST_1ERROR_1MODIFY_1PARTIALLY_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DST_ERROR_MODIFY_PARTIALLY_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DST_1ERROR_1NEW_1DATA_1MISSING_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DST_ERROR_NEW_DATA_MISSING;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DST_1ERROR_1QUERY_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DST_ERROR_QUERY_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DST_1ERROR_1NO_1DATA_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DST_ERROR_NO_DATA;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DST_1ERROR_1MALFORMED_1QUERY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DST_ERROR_MALFORMED_QUERY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DST_1ERROR_1EMPTY_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DST_ERROR_EMPTY_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REGISTRY_1ERROR_1KEY_1EXISTS_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REGISTRY_ERROR_KEY_EXISTS;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ERROR_1MISSING_1PUBLIC_1KEY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ERROR_MISSING_PUBLIC_KEY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSSEC_1ERROR_1MISSING_1SECURITY_1TOKEN_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSSEC_ERROR_MISSING_SECURITY_TOKEN;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSSEC_1ERROR_1BAD_1PASSWORD_1get(JNIEnv *env, jclass clss
) {
   return LASSO_WSSEC_ERROR_BAD_PASSWORD;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1IDWSF2_1DISCOVERY_1ERROR_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_IDWSF2_DISCOVERY_ERROR_FAILED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1IDWSF2_1DISCOVERY_1ERROR_1FORBIDDEN_1get(JNIEnv *env, jclass clss
) {
   return LASSO_IDWSF2_DISCOVERY_ERROR_FORBIDDEN;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1IDWSF2_1DISCOVERY_1ERROR_1DUPLICATE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_IDWSF2_DISCOVERY_ERROR_DUPLICATE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1IDWSF2_1DISCOVERY_1ERROR_1LOGICAL_1DUPLICATE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_IDWSF2_DISCOVERY_ERROR_LOGICAL_DUPLICATE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1IDWSF2_1DISCOVERY_1ERROR_1NO_1RESULTS_1get(JNIEnv *env, jclass clss
) {
   return LASSO_IDWSF2_DISCOVERY_ERROR_NO_RESULTS;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1IDWSF2_1DISCOVERY_1ERROR_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_IDWSF2_DISCOVERY_ERROR_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1IDWSF2_1DST_1ERROR_1DUPLICATE_1ITEM_1get(JNIEnv *env, jclass clss
) {
   return LASSO_IDWSF2_DST_ERROR_DUPLICATE_ITEM;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1IDWSF2_1DST_1ERROR_1PARTIAL_1FAILURE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_IDWSF2_DST_ERROR_PARTIAL_FAILURE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1IDWSF2_1DST_1ERROR_1UNKNOWN_1STATUS_1CODE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_IDWSF2_DST_ERROR_UNKNOWN_STATUS_CODE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1IDWSF2_1DST_1ERROR_1ITEM_1NOT_1FOUND_1get(JNIEnv *env, jclass clss
) {
   return LASSO_IDWSF2_DST_ERROR_ITEM_NOT_FOUND;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ASSERTION_1QUERY_1ERROR_1ATTRIBUTE_1REQUEST_1ALREADY_1EXIST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ASSERTION_QUERY_ERROR_ATTRIBUTE_REQUEST_ALREADY_EXIST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ASSERTION_1QUERY_1ERROR_1NOT_1AN_1ATTRIBUTE_1QUERY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ASSERTION_QUERY_ERROR_NOT_AN_ATTRIBUTE_QUERY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XMLENC_1ERROR_1INVALID_1ENCRYPTED_1DATA_1get(JNIEnv *env, jclass clss
) {
   return LASSO_XMLENC_ERROR_INVALID_ENCRYPTED_DATA;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PAOS_1ERROR_1MISSING_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PAOS_ERROR_MISSING_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PAOS_1ERROR_1MISSING_1RESPONSE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PAOS_ERROR_MISSING_RESPONSE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PAOS_1ERROR_1MISSING_1RESPONSE_1CONSUMER_1URL_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PAOS_ERROR_MISSING_RESPONSE_CONSUMER_URL;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ECP_1ERROR_1MISSING_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ECP_ERROR_MISSING_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ECP_1ERROR_1MISSING_1RESPONSE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ECP_ERROR_MISSING_RESPONSE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ECP_1ERROR_1MISSING_1RELAYSTATE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ECP_ERROR_MISSING_RELAYSTATE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ECP_1ERROR_1MISSING_1AUTHN_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ECP_ERROR_MISSING_AUTHN_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ECP_1ERROR_1MISSING_1SAML_1RESPONSE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ECP_ERROR_MISSING_SAML_RESPONSE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ECP_1ERROR_1ASSERTION_1CONSUMER_1URL_1MISMATCH_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ECP_ERROR_ASSERTION_CONSUMER_URL_MISMATCH;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_BACKWARD_1COMP_1H_1get(JNIEnv *env, jclass clss
) {
   return BACKWARD_COMP_H;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1CHECK_1VERSION_1EXACT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_CHECK_VERSION_EXACT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1CHECK_1VERSIONABI_1COMPATIBLE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_CHECK_VERSIONABI_COMPATIBLE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1CHECK_1VERSION_1NUMERIC_1get(JNIEnv *env, jclass clss
) {
   return LASSO_CHECK_VERSION_NUMERIC;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ASSERTION_1QUERY_1REQUEST_1TYPE_1UNSET_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ASSERTION_QUERY_REQUEST_TYPE_UNSET;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ASSERTION_1QUERY_1REQUEST_1TYPE_1ASSERTION_1ID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ASSERTION_QUERY_REQUEST_TYPE_ASSERTION_ID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ASSERTION_1QUERY_1REQUEST_1TYPE_1AUTHN_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ASSERTION_QUERY_REQUEST_TYPE_AUTHN;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ASSERTION_1QUERY_1REQUEST_1TYPE_1ATTRIBUTE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ASSERTION_QUERY_REQUEST_TYPE_ATTRIBUTE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ASSERTION_1QUERY_1REQUEST_1TYPE_1AUTHZ_1DECISION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ASSERTION_QUERY_REQUEST_TYPE_AUTHZ_DECISION;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ASSERTION_1QUERY_1REQUEST_1TYPE_1LAST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ASSERTION_QUERY_REQUEST_TYPE_LAST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ASSERTION_1VALID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SAML2_ASSERTION_VALID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ASSERTION_1INVALID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SAML2_ASSERTION_INVALID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ASSERTION_1INDETERMINATE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SAML2_ASSERTION_INDETERMINATE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DURATION_1MINUTE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DURATION_MINUTE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DURATION_1HOUR_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DURATION_HOUR;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DURATION_1DAY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DURATION_DAY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DURATION_1WEEK_1get(JNIEnv *env, jclass clss
) {
   return LASSO_DURATION_WEEK;
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1ENV_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SOAP_ENV_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1ENV_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SOAP_ENV_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1ENV_1ACTOR_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SOAP_ENV_ACTOR);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1FAULT_1CODE_1SERVER_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SOAP_FAULT_CODE_SERVER);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1FAULT_1CODE_1CLIENT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SOAP_FAULT_CODE_CLIENT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1FAULT_1CODE_1MUST_1UNDERSTAND_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SOAP_FAULT_CODE_MUST_UNDERSTAND);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SOAP_1FAULT_1CODE_1VERSION_1MISMATCH_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SOAP_FAULT_CODE_VERSION_MISMATCH);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PRIVATE_1STATUS_1CODE_1FAILED_1TO_1RESTORE_1ARTIFACT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_PRIVATE_STATUS_CODE_FAILED_TO_RESTORE_ARTIFACT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSUTIL1_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_WSUTIL1_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSUTIL1_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_WSUTIL1_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XMLENC_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_XMLENC_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XMLENC_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_XMLENC_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LASSO_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LASSO_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LASSO_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LASSO_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PYTHON_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_PYTHON_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1TYPE_1ATTRIBUTE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SIGNATURE_TYPE_ATTRIBUTE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1ATTRIBUTE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SIGNATURE_METHOD_ATTRIBUTE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PRIVATE_1KEY_1ATTRIBUTE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_PRIVATE_KEY_ATTRIBUTE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PRIVATE_1KEY_1PASSWORD_1ATTRIBUTE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_PRIVATE_KEY_PASSWORD_ATTRIBUTE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1CERTIFICATE_1ATTRIBUTE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_CERTIFICATE_ATTRIBUTE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PREFIX);
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1MAJOR_1VERSION_1N_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LIB_MAJOR_VERSION_N;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1MINOR_1VERSION_1N_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LIB_MINOR_VERSION_N;
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1NAMEID_1POLICY_1TYPE_1NONE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_NAMEID_POLICY_TYPE_NONE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1NAMEID_1POLICY_1TYPE_1ONE_1TIME_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_NAMEID_POLICY_TYPE_ONE_TIME);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1NAMEID_1POLICY_1TYPE_1FEDERATED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_NAMEID_POLICY_TYPE_FEDERATED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1NAMEID_1POLICY_1TYPE_1ANY_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_NAMEID_POLICY_TYPE_ANY);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1INTERNET_1PROTOCOL_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_INTERNET_PROTOCOL);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1INTERNET_1PROTOCOL_1PASSWORD_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_INTERNET_PROTOCOL_PASSWORD);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1MOBILE_1ONE_1FACTOR_1UNREGISTERED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_MOBILE_ONE_FACTOR_UNREGISTERED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1MOBILE_1TWO_1FACTOR_1UNREGISTERED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_MOBILE_TWO_FACTOR_UNREGISTERED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1MOBILE_1ONE_1FACTOR_1CONTRACT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_MOBILE_ONE_FACTOR_CONTRACT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1MOBILE_1TWO_1FACTOR_1CONTRACT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_MOBILE_TWO_FACTOR_CONTRACT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1PASSWORD_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_PASSWORD);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1PASSWORD_1PROTECTED_1TRANSPORT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_PASSWORD_PROTECTED_TRANSPORT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1PREVIOUS_1SESSION_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_PREVIOUS_SESSION);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1SMARTCARD_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_SMARTCARD);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1SMARTCARD_1PKI_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_SMARTCARD_PKI);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1SOFTWARE_1PKI_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_SOFTWARE_PKI);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1CLASS_1REF_1TIME_1SYNC_1TOKEN_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_CLASS_REF_TIME_SYNC_TOKEN);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1COMPARISON_1EXACT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_COMPARISON_EXACT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1COMPARISON_1MINIMUM_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_COMPARISON_MINIMUM);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1COMPARISON_1MAXIMUM_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_COMPARISON_MAXIMUM);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1AUTHN_1CONTEXT_1COMPARISON_1BETTER_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_AUTHN_CONTEXT_COMPARISON_BETTER);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1FEDERATION_1DOES_1NOT_1EXIST_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_FEDERATION_DOES_NOT_EXIST);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1INVALID_1ASSERTION_1CONSUMER_1SERVICE_1INDEX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_INVALID_ASSERTION_CONSUMER_SERVICE_INDEX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1INVALID_1SIGNATURE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_INVALID_SIGNATURE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1NO_1AUTHN_1CONTEXT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_NO_AUTHN_CONTEXT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1NO_1AVAILABLEIDP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_NO_AVAILABLEIDP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1NO_1PASSIVE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_NO_PASSIVE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1NO_1SUPPORTEDIDP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_NO_SUPPORTEDIDP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1PROXY_1COUNT_1EXCEEDED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_PROXY_COUNT_EXCEEDED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1UNKNOWN_1PRINCIPAL_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_UNKNOWN_PRINCIPAL);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1UNSIGNED_1AUTHN_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_UNSIGNED_AUTHN_REQUEST);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1STATUS_1CODE_1UNSUPPORTED_1PROFILE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_STATUS_CODE_UNSUPPORTED_PROFILE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1BRWS_1ART_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_BRWS_ART);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1BRWS_1POST_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_BRWS_POST);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1BRWS_1LECP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_BRWS_LECP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1FED_1TERM_1IDP_1HTTP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_FED_TERM_IDP_HTTP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1FED_1TERM_1IDP_1SOAP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_FED_TERM_IDP_SOAP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1FED_1TERM_1SP_1HTTP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_FED_TERM_SP_HTTP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1FED_1TERM_1SP_1SOAP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_FED_TERM_SP_SOAP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1NIM_1SP_1HTTP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_NIM_SP_HTTP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1RNI_1IDP_1HTTP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_RNI_IDP_HTTP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1RNI_1IDP_1SOAP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_RNI_IDP_SOAP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1RNI_1SP_1HTTP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_RNI_SP_HTTP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1RNI_1SP_1SOAP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_RNI_SP_SOAP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1SLO_1SP_1HTTP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_SLO_SP_HTTP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1SLO_1SP_1SOAP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_SLO_SP_SOAP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1SLO_1IDP_1HTTP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_SLO_IDP_HTTP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1PROTOCOL_1PROFILE_1SLO_1IDP_1SOAP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_PROTOCOL_PROFILE_SLO_IDP_SOAP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1NAME_1IDENTIFIER_1FORMAT_1FEDERATED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_NAME_IDENTIFIER_FORMAT_FEDERATED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1NAME_1IDENTIFIER_1FORMAT_1ONE_1TIME_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_NAME_IDENTIFIER_FORMAT_ONE_TIME);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1NAME_1IDENTIFIER_1FORMAT_1ENCRYPTED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_NAME_IDENTIFIER_FORMAT_ENCRYPTED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1NAME_1IDENTIFIER_1FORMAT_1ENTITYID_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_NAME_IDENTIFIER_FORMAT_ENTITYID);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1CONSENT_1OBTAINED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_CONSENT_OBTAINED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1CONSENT_1OBTAINED_1PRIOR_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_CONSENT_OBTAINED_PRIOR);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1CONSENT_1OBTAINED_1CURRENT_1IMPLICIT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_CONSENT_OBTAINED_CURRENT_IMPLICIT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1CONSENT_1OBTAINED_1CURRENT_1EXPLICIT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_CONSENT_OBTAINED_CURRENT_EXPLICIT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1CONSENT_1UNAVAILABLE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_CONSENT_UNAVAILABLE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LIB_1CONSENT_1INAPPLICABLE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_LIB_CONSENT_INAPPLICABLE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1METADATA_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_METADATA_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1METADATA_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_METADATA_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1ASSERTION_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_ASSERTION_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1ASSERTION_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_ASSERTION_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1PROTOCOL_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_PROTOCOL_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1PROTOCOL_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_PROTOCOL_PREFIX);
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1MAJOR_1VERSION_1N_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SAML_MAJOR_VERSION_N;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1MINOR_1VERSION_1N_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SAML_MINOR_VERSION_N;
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1STATUS_1CODE_1SUCCESS_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_STATUS_CODE_SUCCESS);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1STATUS_1CODE_1VERSION_1MISMATCH_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_STATUS_CODE_VERSION_MISMATCH);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1STATUS_1CODE_1REQUESTER_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_STATUS_CODE_REQUESTER);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1STATUS_1CODE_1RESPONDER_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_STATUS_CODE_RESPONDER);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1STATUS_1CODE_1REQUEST_1VERSION_1TOO_1HIGH_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_STATUS_CODE_REQUEST_VERSION_TOO_HIGH);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1STATUS_1CODE_1REQUEST_1VERSION_1TOO_1LOW_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_STATUS_CODE_REQUEST_VERSION_TOO_LOW);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1STATUS_1CODE_1REQUEST_1VERSION_1DEPRECATED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_STATUS_CODE_REQUEST_VERSION_DEPRECATED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1STATUS_1CODE_1TOO_1MANY_1RESPONSES_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_STATUS_CODE_TOO_MANY_RESPONSES);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1STATUS_1CODE_1RESOURCE_1NOT_1RECOGNIZED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_STATUS_CODE_RESOURCE_NOT_RECOGNIZED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1STATUS_1CODE_1REQUEST_1DENIED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_STATUS_CODE_REQUEST_DENIED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1PASSWORD_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_PASSWORD);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1KERBEROS_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_KERBEROS);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1SECURE_1REMOTE_1PASSWORD_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_SECURE_REMOTE_PASSWORD);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1HARDWARE_1TOKEN_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_HARDWARE_TOKEN);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1SMARTCARD_1PKI_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_SMARTCARD_PKI);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1SOFTWARE_1PKI_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_SOFTWARE_PKI);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1PGP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_PGP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHODS_1PKI_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHODS_PKI);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1XKMS_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_XKMS);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1XMLD_1SIG_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_XMLD_SIG);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1UNSPECIFIED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_UNSPECIFIED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1AUTHENTICATION_1METHOD_1LIBERTY_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_AUTHENTICATION_METHOD_LIBERTY);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1CONFIRMATION_1METHOD_1ARTIFACT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_CONFIRMATION_METHOD_ARTIFACT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1CONFIRMATION_1METHOD_1ARTIFACT01_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_CONFIRMATION_METHOD_ARTIFACT01);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1CONFIRMATION_1METHOD_1BEARER_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_CONFIRMATION_METHOD_BEARER);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1CONFIRMATION_1METHOD_1HOLDER_1OF_1KEY_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_CONFIRMATION_METHOD_HOLDER_OF_KEY);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1CONFIRMATION_1METHOD_1SENDER_1VOUCHES_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_CONFIRMATION_METHOD_SENDER_VOUCHES);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML_1EXT_1CHANNEL_1BINDING_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML_EXT_CHANNEL_BINDING);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PAOS_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_PAOS_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PAOS_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_PAOS_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ECP_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_ECP_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ECP_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_ECP_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XSI_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_XSI_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XSI_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_XSI_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_XML_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1XML_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_XML_PREFIX);
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ENCRYPTION_1SYM_1KEY_1TYPE_1DEFAULT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ENCRYPTION_SYM_KEY_TYPE_DEFAULT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ENCRYPTION_1SYM_1KEY_1TYPE_1AES_1256_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ENCRYPTION_SYM_KEY_TYPE_AES_256;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ENCRYPTION_1SYM_1KEY_1TYPE_1AES_1128_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ENCRYPTION_SYM_KEY_TYPE_AES_128;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ENCRYPTION_1SYM_1KEY_1TYPE_13DES_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ENCRYPTION_SYM_KEY_TYPE_3DES;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ENCRYTPION_1SYM_1KEY_1TYPE_1LAST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ENCRYTPION_SYM_KEY_TYPE_LAST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MESSAGE_1FORMAT_1XSCHEMA_1ERROR_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MESSAGE_FORMAT_XSCHEMA_ERROR;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MESSAGE_1FORMAT_1ERROR_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MESSAGE_FORMAT_ERROR;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MESSAGE_1FORMAT_1UNKNOWN_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MESSAGE_FORMAT_UNKNOWN;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MESSAGE_1FORMAT_1XML_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MESSAGE_FORMAT_XML;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MESSAGE_1FORMAT_1BASE64_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MESSAGE_FORMAT_BASE64;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MESSAGE_1FORMAT_1QUERY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MESSAGE_FORMAT_QUERY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MESSAGE_1FORMAT_1SOAP_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MESSAGE_FORMAT_SOAP;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1TYPE_1NONE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_TYPE_NONE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1TYPE_1SIMPLE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_TYPE_SIMPLE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1TYPE_1WITHX509_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_TYPE_WITHX509;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1TYPE_1LAST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_TYPE_LAST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1NONE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_NONE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1RSA_1SHA1_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_RSA_SHA1;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1DSA_1SHA1_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_DSA_SHA1;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1HMAC_1SHA1_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_HMAC_SHA1;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1RSA_1SHA256_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_RSA_SHA256;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1HMAC_1SHA256_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_HMAC_SHA256;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1RSA_1SHA384_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_RSA_SHA384;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1HMAC_1SHA384_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_HMAC_SHA384;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1RSA_1SHA512_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_RSA_SHA512;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1HMAC_1SHA512_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_HMAC_SHA512;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SIGNATURE_1METHOD_1LAST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SIGNATURE_METHOD_LAST;
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1METADATA_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_METADATA_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1METADATA_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_METADATA_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1PROTOCOL_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_PROTOCOL_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1PROTOCOL_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_PROTOCOL_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ASSERTION_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ASSERTION_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ASSERTION_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ASSERTION_PREFIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1METADATA_1BINDING_1SOAP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_METADATA_BINDING_SOAP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1METADATA_1BINDING_1REDIRECT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_METADATA_BINDING_REDIRECT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1METADATA_1BINDING_1POST_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_METADATA_BINDING_POST);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1METADATA_1BINDING_1ARTIFACT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_METADATA_BINDING_ARTIFACT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1METADATA_1BINDING_1PAOS_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_METADATA_BINDING_PAOS);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1METADATA_1BINDING_1URI_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_METADATA_BINDING_URI);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1DEFLATE_1ENCODING_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_DEFLATE_ENCODING);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1NAME_1IDENTIFIER_1FORMAT_1UNSPECIFIED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_NAME_IDENTIFIER_FORMAT_UNSPECIFIED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1NAME_1IDENTIFIER_1FORMAT_1EMAIL_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_NAME_IDENTIFIER_FORMAT_EMAIL);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1NAME_1IDENTIFIER_1FORMAT_1X509_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_NAME_IDENTIFIER_FORMAT_X509);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1NAME_1IDENTIFIER_1FORMAT_1WINDOWS_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_NAME_IDENTIFIER_FORMAT_WINDOWS);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1NAME_1IDENTIFIER_1FORMAT_1KERBEROS_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_NAME_IDENTIFIER_FORMAT_KERBEROS);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1NAME_1IDENTIFIER_1FORMAT_1ENTITY_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_NAME_IDENTIFIER_FORMAT_ENTITY);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1NAME_1IDENTIFIER_1FORMAT_1PERSISTENT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_NAME_IDENTIFIER_FORMAT_PERSISTENT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1NAME_1IDENTIFIER_1FORMAT_1TRANSIENT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_NAME_IDENTIFIER_FORMAT_TRANSIENT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1NAME_1IDENTIFIER_1FORMAT_1ENCRYPTED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_NAME_IDENTIFIER_FORMAT_ENCRYPTED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ATTRIBUTE_1NAME_1EPR_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ATTRIBUTE_NAME_EPR);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ATTRIBUTE_1NAME_1FORMAT_1UNSPECIFIED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ATTRIBUTE_NAME_FORMAT_UNSPECIFIED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ATTRIBUTE_1NAME_1FORMAT_1URI_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ATTRIBUTE_NAME_FORMAT_URI);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ATTRIBUTE_1NAME_1FORMAT_1BASIC_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ATTRIBUTE_NAME_FORMAT_BASIC);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1NAMESPACE_1RWEDC_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_NAMESPACE_RWEDC);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1NAMESPACE_1RWEDC_1NEGATION_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_NAMESPACE_RWEDC_NEGATION);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1NAMESPACE_1GHPP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_NAMESPACE_GHPP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1NAMESPACE_1UNIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_NAMESPACE_UNIX);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1RWEDC_1READ_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_RWEDC_READ);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1RWEDC_1WRITE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_RWEDC_WRITE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1RWEDC_1EXECUTE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_RWEDC_EXECUTE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1RWEDC_1DELETE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_RWEDC_DELETE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1RWEDC_1CONTROL_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_RWEDC_CONTROL);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1RWEDC_1NEGATION_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_RWEDC_NEGATION);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1GHPP_1GET_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_GHPP_GET);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1GHPP_1HEAD_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_GHPP_HEAD);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1GHPP_1PUT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_GHPP_PUT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ACTION_1GHPP_1POST_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ACTION_GHPP_POST);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1CONSENT_1OBTAINED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_CONSENT_OBTAINED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1CONSENT_1PRIOR_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_CONSENT_PRIOR);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1CONSENT_1IMPLICIT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_CONSENT_IMPLICIT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1CONSENT_1EXPLICIT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_CONSENT_EXPLICIT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1CONSENT_1UNAVAILABLE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_CONSENT_UNAVAILABLE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1CONSENT_1INAPPLICABLE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_CONSENT_INAPPLICABLE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1SUCCESS_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_SUCCESS);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1REQUESTER_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_REQUESTER);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1RESPONDER_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_RESPONDER);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1VERSION_1MISMATCH_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_VERSION_MISMATCH);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1AUTHN_1FAILED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_AUTHN_FAILED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1INVALID_1ATTR_1NAME_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_INVALID_ATTR_NAME);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1INVALID_1NAME_1ID_1POLICY_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_INVALID_NAME_ID_POLICY);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1NO_1AUTHN_1CONTEXT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_NO_AUTHN_CONTEXT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1NO_1AVAILABLE_1IDP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_NO_AVAILABLE_IDP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1NO_1PASSIVE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_NO_PASSIVE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1NO_1SUPPORTED_1IDP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_NO_SUPPORTED_IDP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1PARTIAL_1LOGOUT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_PARTIAL_LOGOUT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1PROXY_1COUNT_1EXCEEDED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_PROXY_COUNT_EXCEEDED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1REQUEST_1DENIED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_REQUEST_DENIED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1REQUEST_1UNSUPPORTED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_REQUEST_UNSUPPORTED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1REQUEST_1VERSION_1DEPRECATED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_REQUEST_VERSION_DEPRECATED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1REQUEST_1VERSION_1TOO_1HIGH_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_REQUEST_VERSION_TOO_HIGH);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1REQUEST_1VERSION_1TOO_1LOW_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_REQUEST_VERSION_TOO_LOW);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1RESOURCE_1NOT_1RECOGNIZED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_RESOURCE_NOT_RECOGNIZED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1TOO_1MANY_1RESPONSES_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_TOO_MANY_RESPONSES);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1UNKNOWN_1ATTR_1PROFILE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_UNKNOWN_ATTR_PROFILE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1UNKNOWN_1PRINCIPAL_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_UNKNOWN_PRINCIPAL);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1STATUS_1CODE_1UNSUPPORTED_1BINDING_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_STATUS_CODE_UNSUPPORTED_BINDING);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1AUTHENTICATED_1TELEPHONY_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_AUTHENTICATED_TELEPHONY);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1INTERNET_1PROTOCOL_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_INTERNET_PROTOCOL);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1INTERNET_1PROTOCOL_1PASSWORD_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_INTERNET_PROTOCOL_PASSWORD);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1KERBEROS_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_KERBEROS);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1MOBILE_1ONE_1FACTOR_1CONTRACT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_MOBILE_ONE_FACTOR_CONTRACT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1MOBILE_1ONE_1FACTOR_1UNREGISTERED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_MOBILE_ONE_FACTOR_UNREGISTERED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1MOBILE_1TWO_1FACTOR_1CONTRACT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_MOBILE_TWO_FACTOR_CONTRACT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1MOBILE_1TWO_1FACTOR_1UNREGISTERED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_MOBILE_TWO_FACTOR_UNREGISTERED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1NOMAD_1TELEPHONY_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_NOMAD_TELEPHONY);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1PERSONALIZED_1TELEPHONY_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_PERSONALIZED_TELEPHONY);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1PGP_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_PGP);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1PASSWORD_1PROTECTED_1TRANSPORT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_PASSWORD_PROTECTED_TRANSPORT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1PASSWORD_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_PASSWORD);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1PREVIOUS_1SESSION_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_PREVIOUS_SESSION);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1SMARTCARD_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_SMARTCARD);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1SMARTCARD_1PKI_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_SMARTCARD_PKI);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1SOFTWARE_1PKI_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_SOFTWARE_PKI);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1SPKI_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_SPKI);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1SECURE_1REMOTE_1PASSWORD_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_SECURE_REMOTE_PASSWORD);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1TLS_1CLIENT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_TLS_CLIENT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1X509_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_X509);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1TELEPHONY_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_TELEPHONY);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1TIME_1SYNC_1TOKEN_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_TIME_SYNC_TOKEN);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1XMLDSIG_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_XMLDSIG);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1AUTHN_1CONTEXT_1UNSPECIFIED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_AUTHN_CONTEXT_UNSPECIFIED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1CONFIRMATION_1METHOD_1BEARER_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_CONFIRMATION_METHOD_BEARER);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1CONFIRMATION_1METHOD_1HOLDER_1OF_1KEY_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_CONFIRMATION_METHOD_HOLDER_OF_KEY);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1FIELD_1ENCODING_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_FIELD_ENCODING);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1FIELD_1RESPONSE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_FIELD_RESPONSE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1FIELD_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_FIELD_REQUEST);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1FIELD_1ARTIFACT_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_FIELD_ARTIFACT);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1FIELD_1RELAYSTATE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_FIELD_RELAYSTATE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1FIELD_1SIGNATURE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_FIELD_SIGNATURE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1FIELD_1SIGALG_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_FIELD_SIGALG);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ATTRIBUTE_1PROFILE_1BASIC_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ATTRIBUTE_PROFILE_BASIC);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ATTRIBUTE_1PROFILE_1X500_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ATTRIBUTE_PROFILE_X500);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ATTRIBUTE_1PROFILE_1UUID_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ATTRIBUTE_PROFILE_UUID);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ATTRIBUTE_1PROFILE_1DCE_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ATTRIBUTE_PROFILE_DCE);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1ECP_1PROFILE_1WANT_1AUTHN_1SIGNED_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_ECP_PROFILE_WANT_AUTHN_SIGNED);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SAML2_1CONDITIONS_1DELEGATION_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_SAML2_CONDITIONS_DELEGATION);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1HREF_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_DS_HREF);
}
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1DS_1PREFIX_1get(JNIEnv *env, jclass clss
) {
   return (*env)->NewStringUTF(env, (char*) LASSO_DS_PREFIX);
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SERVER_1LOAD_1METADATA_1FLAG_1DEFAULT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SERVER_LOAD_METADATA_FLAG_DEFAULT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SERVER_1LOAD_1METADATA_1FLAG_1CHECK_1ENTITIES_1DESCRIPTOR_1SIGNATURE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SERVER_LOAD_METADATA_FLAG_CHECK_ENTITIES_DESCRIPTOR_SIGNATURE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SERVER_1LOAD_1METADATA_1FLAG_1CHECK_1ENTITY_1DESCRIPTOR_1SIGNATURE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SERVER_LOAD_METADATA_FLAG_CHECK_ENTITY_DESCRIPTOR_SIGNATURE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1SERVER_1LOAD_1METADATA_1FLAG_1INHERIT_1SIGNATURE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_SERVER_LOAD_METADATA_FLAG_INHERIT_SIGNATURE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1PROTOCOL_1PROFILE_1BRWS_1ART_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_PROTOCOL_PROFILE_BRWS_ART;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1PROTOCOL_1PROFILE_1BRWS_1POST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_PROTOCOL_PROFILE_BRWS_POST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1PROTOCOL_1PROFILE_1BRWS_1LECP_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_PROTOCOL_PROFILE_BRWS_LECP;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1LOGIN_1PROTOCOL_1PROFILE_1REDIRECT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_LOGIN_PROTOCOL_PROFILE_REDIRECT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1INVALID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_INVALID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1LOGIN_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_LOGIN;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1LOGOUT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_LOGOUT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1DEFEDERATION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_DEFEDERATION;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1NAME_1REGISTRATION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_NAME_REGISTRATION;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1NAME_1IDENTIFIER_1MAPPING_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_NAME_IDENTIFIER_MAPPING;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1LECP_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_LECP;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1DISCO_1QUERY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_DISCO_QUERY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1DISCO_1MODIFY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_DISCO_MODIFY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1DST_1QUERY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_DST_QUERY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1DST_1MODIFY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_DST_MODIFY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1SASL_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_SASL_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1NAME_1ID_1MANAGEMENT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_NAME_ID_MANAGEMENT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1IDWSF2_1DISCO_1SVCMD_1REGISTER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_IDWSF2_DISCO_SVCMD_REGISTER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1IDWSF2_1DISCO_1SVCMD_1ASSOCIATION_1ADD_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_IDWSF2_DISCO_SVCMD_ASSOCIATION_ADD;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1REQUEST_1TYPE_1IDWSF2_1DISCO_1QUERY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_REQUEST_TYPE_IDWSF2_DISCO_QUERY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1SIGNATURE_1HINT_1MAYBE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_SIGNATURE_HINT_MAYBE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1SIGNATURE_1HINT_1FORCE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_SIGNATURE_HINT_FORCE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1SIGNATURE_1HINT_1FORBID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_SIGNATURE_HINT_FORBID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1SIGNATURE_1VERIFY_1HINT_1MAYBE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_SIGNATURE_VERIFY_HINT_MAYBE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1SIGNATURE_1VERIFY_1HINT_1FORCE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_SIGNATURE_VERIFY_HINT_FORCE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1SIGNATURE_1VERIFY_1HINT_1IGNORE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_SIGNATURE_VERIFY_HINT_IGNORE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROFILE_1SIGNATURE_1VERIFY_1HINT_1LAST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROFILE_SIGNATURE_VERIFY_HINT_LAST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1NONE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_NONE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1ANY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_ANY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1IDP_1INITIATED_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_IDP_INITIATED;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1GET_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_GET;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1POST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_POST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1REDIRECT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_REDIRECT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1SOAP_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_SOAP;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1ARTIFACT_1GET_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_ARTIFACT_GET;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1ARTIFACT_1POST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_ARTIFACT_POST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1PAOS_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_PAOS;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1HTTP_1METHOD_1LAST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_HTTP_METHOD_LAST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1FEDERATION_1TERMINATION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_FEDERATION_TERMINATION;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1NAME_1IDENTIFIER_1MAPPING_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_NAME_IDENTIFIER_MAPPING;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1REGISTER_1NAME_1IDENTIFIER_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_REGISTER_NAME_IDENTIFIER;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1SINGLE_1LOGOUT_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_SINGLE_LOGOUT;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1SINGLE_1SIGN_1ON_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_SINGLE_SIGN_ON;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1ARTIFACT_1RESOLUTION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_ARTIFACT_RESOLUTION;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1MANAGE_1NAME_1ID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_MANAGE_NAME_ID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1ASSERTION_1ID_1REQUEST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_ASSERTION_ID_REQUEST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1AUTHN_1QUERY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_AUTHN_QUERY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1AUTHZ_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_AUTHZ;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1ATTRIBUTE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_ATTRIBUTE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1MD_1PROTOCOL_1TYPE_1LAST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_MD_PROTOCOL_TYPE_LAST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ROLE_1ANY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ROLE_ANY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ROLE_1NONE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ROLE_NONE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ROLE_1SP_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ROLE_SP;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ROLE_1IDP_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ROLE_IDP;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ROLE_1BOTH_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ROLE_BOTH;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ROLE_1AUTHN_1AUTHORITY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ROLE_AUTHN_AUTHORITY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ROLE_1AUTHZ_1AUTHORITY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ROLE_AUTHZ_AUTHORITY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ROLE_1ATTRIBUTE_1AUTHORITY_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ROLE_ATTRIBUTE_AUTHORITY;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ROLE_1LAST_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ROLE_LAST;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROVIDER_1ROLE_1ALL_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROVIDER_ROLE_ALL;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROTOCOL_1NONE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROTOCOL_NONE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROTOCOL_1LIBERTY_11_10_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROTOCOL_LIBERTY_1_0;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROTOCOL_1LIBERTY_11_11_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROTOCOL_LIBERTY_1_1;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROTOCOL_1LIBERTY_11_12_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROTOCOL_LIBERTY_1_2;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1PROTOCOL_1SAML_12_10_1get(JNIEnv *env, jclass clss
) {
   return LASSO_PROTOCOL_SAML_2_0;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ENCRYPTION_1MODE_1NONE_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ENCRYPTION_MODE_NONE;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ENCRYPTION_1MODE_1NAMEID_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ENCRYPTION_MODE_NAMEID;
}
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1ENCRYPTION_1MODE_1ASSERTION_1get(JNIEnv *env, jclass clss
) {
   return LASSO_ENCRYPTION_MODE_ASSERTION;
}
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_LASSO_1WSF_1ENABLED_1get(JNIEnv *env, jclass clss
) {
#ifdef LASSO_WSF_ENABLED
   return 1;
#else
   return 0;
#endif
}
/* End of declaration of constants */
/* Declaration of standalone functions */
/* Wrapper function for  const char* lasso_strerror( int error_code {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_strError(JNIEnv *env, jclass clss
,jint jarg1 )
  {
    jstring ret;
    int error_code;
    const char* return_value;
    error_code = (int)jarg1;
    return_value =  lasso_strerror(error_code);
    string_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  LassoKey* lasso_key_new_for_signature_from_base64_string( char* base64_string {}, char* password {}, LassoSignatureMethod signature_method {}, char* certificate {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_key_1new_1for_1signature_1from_1base64_1string(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jint jarg3 ,jstring jarg4 )
  {
    jobject ret;
    char* base64_string = NULL;
    char* password = NULL;
    LassoSignatureMethod signature_method;
    char* certificate = NULL;
    LassoKey* return_value;
    jstring_to_string(env, jarg1, (char**)&base64_string);
    jstring_to_string(env, jarg2, (char**)&password);
    signature_method = (LassoSignatureMethod)jarg3;
    jstring_to_string(env, jarg4, (char**)&certificate);
    return_value =  (LassoKey*) lasso_key_new_for_signature_from_base64_string(base64_string, password, signature_method, certificate);
    if (base64_string)
        g_free(base64_string);
    if (password)
        g_free(password);
    if (certificate)
        g_free(certificate);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoKey* lasso_key_new_for_signature_from_file( char* filename_or_buffer {}, char* password {}, LassoSignatureMethod signature_method {}, char* certificate {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_key_1new_1for_1signature_1from_1file(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jint jarg3 ,jstring jarg4 )
  {
    jobject ret;
    char* filename_or_buffer = NULL;
    char* password = NULL;
    LassoSignatureMethod signature_method;
    char* certificate = NULL;
    LassoKey* return_value;
    jstring_to_string(env, jarg1, (char**)&filename_or_buffer);
    jstring_to_string(env, jarg2, (char**)&password);
    signature_method = (LassoSignatureMethod)jarg3;
    jstring_to_string(env, jarg4, (char**)&certificate);
    return_value =  (LassoKey*) lasso_key_new_for_signature_from_file(filename_or_buffer, password, signature_method, certificate);
    if (filename_or_buffer)
        g_free(filename_or_buffer);
    if (password)
        g_free(password);
    if (certificate)
        g_free(certificate);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_init( ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_init(JNIEnv *env, jclass clss
)
  {
    jint ret;
    lasso_error_t return_value;
    return_value =  lasso_init();
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_shutdown( ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_shutdown(JNIEnv *env, jclass clss
)
  {
    jint ret;
    lasso_error_t return_value;
    return_value =  lasso_shutdown();
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  int lasso_check_version( int major {}, int minor {}, int subminor {}, LassoCheckVersionMode mode {'optional': True, 'default': 'c:LASSO_CHECK_VERSION_NUMERIC'}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_check_1version(JNIEnv *env, jclass clss
,jint jarg1 ,jint jarg2 ,jint jarg3 ,jint jarg4 )
  {
    jint ret;
    int major;
    int minor;
    int subminor;
    LassoCheckVersionMode mode;
    int return_value;
    major = (int)jarg1;
    minor = (int)jarg2;
    subminor = (int)jarg3;
    mode = (LassoCheckVersionMode)jarg4;
    return_value =  lasso_check_version(major, minor, subminor, mode);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  void lasso_set_flag( char* flag {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_set_1flag(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    char* flag = NULL;
    jstring_to_string(env, jarg1, (char**)&flag);
    lasso_set_flag(flag);
    if (flag)
        g_free(flag);
  }
/* Wrapper function for  gboolean lasso_profile_is_saml_query( const gchar* query {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_isSamlQuery(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jboolean ret;
    gchar* query = NULL;
    gboolean return_value;
    jstring_to_string(env, jarg1, (char**)&query);
    return_value =  lasso_profile_is_saml_query((const gchar*) query);
    if (query)
        g_free(query);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  LassoNameIdManagement* lasso_name_id_management_new( LassoServer* server {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1id_1management_1new(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jlong ret;
    LassoServer* server = NULL;
    LassoNameIdManagement* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    return_value =  (LassoNameIdManagement*) lasso_name_id_management_new(server);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNameIdManagement* lasso_name_id_management_new_from_dump( LassoServer* server {}, const char* dump {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1id_1management_1new_1from_1dump(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobject ret;
    LassoServer* server = NULL;
    char* dump = NULL;
    LassoNameIdManagement* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jstring_to_string(env, jarg2, (char**)&dump);
    return_value =  (LassoNameIdManagement*) lasso_name_id_management_new_from_dump(server, (const char*) dump);
    if (dump)
        g_free(dump);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoAssertionQuery* lasso_assertion_query_new( LassoServer* server {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_assertion_1query_1new(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jlong ret;
    LassoServer* server = NULL;
    LassoAssertionQuery* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    return_value =  (LassoAssertionQuery*) lasso_assertion_query_new(server);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoEcp* lasso_ecp_new( LassoServer* server {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1new(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jlong ret;
    LassoServer* server = NULL;
    LassoEcp* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    return_value =  (LassoEcp*) lasso_ecp_new(server);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSaml2NameID* lasso_saml2_name_id_build_persistent( const char* id {}, const char* idpID {}, const char* providerID {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1name_1id_1build_1persistent(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    jobject ret;
    char* id = NULL;
    char* idpID = NULL;
    char* providerID = NULL;
    LassoSaml2NameID* return_value;
    jstring_to_string(env, jarg1, (char**)&id);
    jstring_to_string(env, jarg2, (char**)&idpID);
    jstring_to_string(env, jarg3, (char**)&providerID);
    return_value =  lasso_saml2_name_id_build_persistent((const char*) id, (const char*) idpID, (const char*) providerID);
    if (id)
        g_free(id);
    if (idpID)
        g_free(idpID);
    if (providerID)
        g_free(providerID);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSaml2EncryptedElement* lasso_saml2_encrypted_element_build_encrypted_persistent_name_id( const char* id {}, const char* idpID {}, const LassoProvider* provider {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1encrypted_1element_1build_1encrypted_1persistent_1name_1id(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jobject jarg3 )
  {
    jobject ret;
    char* id = NULL;
    char* idpID = NULL;
    LassoProvider* provider = NULL;
    LassoSaml2EncryptedElement* return_value;
    jstring_to_string(env, jarg1, (char**)&id);
    jstring_to_string(env, jarg2, (char**)&idpID);
    jobject_to_gobject_noref(env, jarg3, (GObject**)&provider);
    return_value =  lasso_saml2_encrypted_element_build_encrypted_persistent_name_id((const char*) id, (const char*) idpID, (const LassoProvider*) provider);
    if (id)
        g_free(id);
    if (idpID)
        g_free(idpID);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSaml2NameID* lasso_saml2_name_id_new_with_persistent_format( const char* id {}, const char* idpID {}, const char* providerID {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1name_1id_1new_1with_1persistent_1format(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    jobject ret;
    char* id = NULL;
    char* idpID = NULL;
    char* providerID = NULL;
    LassoSaml2NameID* return_value;
    jstring_to_string(env, jarg1, (char**)&id);
    jstring_to_string(env, jarg2, (char**)&idpID);
    jstring_to_string(env, jarg3, (char**)&providerID);
    return_value =  (LassoSaml2NameID*) lasso_saml2_name_id_new_with_persistent_format((const char*) id, (const char*) idpID, (const char*) providerID);
    if (id)
        g_free(id);
    if (idpID)
        g_free(idpID);
    if (providerID)
        g_free(providerID);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml_authentication_statement_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1authentication_1statement_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml_authentication_statement_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_logout_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1logout_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_logout_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_logout_response_new_full( char* providerID {}, const char* statusCodeValue {}, LassoLibLogoutRequest* request {}, LassoSignatureType sign_type {}, LassoSignatureMethod sign_method {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1logout_1response_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jobject jarg3 ,jint jarg4 ,jint jarg5 )
  {
    jobject ret;
    char* providerID = NULL;
    char* statusCodeValue = NULL;
    LassoLibLogoutRequest* request = NULL;
    LassoSignatureType sign_type;
    LassoSignatureMethod sign_method;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&providerID);
    jstring_to_string(env, jarg2, (char**)&statusCodeValue);
    jobject_to_gobject_noref(env, jarg3, (GObject**)&request);
    sign_type = (LassoSignatureType)jarg4;
    sign_method = (LassoSignatureMethod)jarg5;
    return_value =  (LassoNode*) lasso_lib_logout_response_new_full(providerID, (const char*) statusCodeValue, request, sign_type, sign_method);
    if (providerID)
        g_free(providerID);
    if (statusCodeValue)
        g_free(statusCodeValue);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoLibAuthnRequestEnvelope* lasso_lib_authn_request_envelope_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1authn_1request_1envelope_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoLibAuthnRequestEnvelope* return_value;
    return_value =  (LassoLibAuthnRequestEnvelope*) lasso_lib_authn_request_envelope_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoLibAuthnRequestEnvelope* lasso_lib_authn_request_envelope_new_full( LassoLibAuthnRequest* authnRequest {}, char* providerID {}, char* assertionConsumerServiceURL {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1authn_1request_1envelope_1new_1full(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    jobject ret;
    LassoLibAuthnRequest* authnRequest = NULL;
    char* providerID = NULL;
    char* assertionConsumerServiceURL = NULL;
    LassoLibAuthnRequestEnvelope* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&authnRequest);
    jstring_to_string(env, jarg2, (char**)&providerID);
    jstring_to_string(env, jarg3, (char**)&assertionConsumerServiceURL);
    return_value =  (LassoLibAuthnRequestEnvelope*) lasso_lib_authn_request_envelope_new_full(authnRequest, providerID, assertionConsumerServiceURL);
    if (providerID)
        g_free(providerID);
    if (assertionConsumerServiceURL)
        g_free(assertionConsumerServiceURL);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSamlSubjectConfirmation* lasso_saml_subject_confirmation_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1subject_1confirmation_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSamlSubjectConfirmation* return_value;
    return_value =  (LassoSamlSubjectConfirmation*) lasso_saml_subject_confirmation_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoLibAuthnRequest* lasso_lib_authn_request_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1authn_1request_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoLibAuthnRequest* return_value;
    return_value =  (LassoLibAuthnRequest*) lasso_lib_authn_request_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_status_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1status_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_status_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml_subject_statement_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1subject_1statement_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml_subject_statement_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_register_name_identifier_request_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1register_1name_1identifier_1request_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_register_name_identifier_request_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_register_name_identifier_request_new_full( const char* providerID {}, LassoSamlNameIdentifier* idpNameIdentifier {}, LassoSamlNameIdentifier* spNameIdentifier {}, LassoSamlNameIdentifier* oldNameIdentifier {}, LassoSignatureType sign_type {}, LassoSignatureMethod sign_method {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1register_1name_1identifier_1request_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 ,jobject jarg2 ,jobject jarg3 ,jobject jarg4 ,jint jarg5 ,jint jarg6 )
  {
    jobject ret;
    char* providerID = NULL;
    LassoSamlNameIdentifier* idpNameIdentifier = NULL;
    LassoSamlNameIdentifier* spNameIdentifier = NULL;
    LassoSamlNameIdentifier* oldNameIdentifier = NULL;
    LassoSignatureType sign_type;
    LassoSignatureMethod sign_method;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&providerID);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&idpNameIdentifier);
    jobject_to_gobject_noref(env, jarg3, (GObject**)&spNameIdentifier);
    jobject_to_gobject_noref(env, jarg4, (GObject**)&oldNameIdentifier);
    sign_type = (LassoSignatureType)jarg5;
    sign_method = (LassoSignatureMethod)jarg6;
    return_value =  (LassoNode*) lasso_lib_register_name_identifier_request_new_full((const char*) providerID, idpNameIdentifier, spNameIdentifier, oldNameIdentifier, sign_type, sign_method);
    if (providerID)
        g_free(providerID);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSamlConditions* lasso_saml_conditions_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1conditions_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSamlConditions* return_value;
    return_value =  (LassoSamlConditions*) lasso_saml_conditions_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSamlNameIdentifier* lasso_saml_name_identifier_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1name_1identifier_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSamlNameIdentifier* return_value;
    return_value =  (LassoSamlNameIdentifier*) lasso_saml_name_identifier_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSamlNameIdentifier* lasso_saml_name_identifier_new_from_xmlNode( xmlNode* xmlnode {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1name_1identifier_1new_1from_1xmlNode(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    xmlNode* xmlnode = NULL;
    LassoSamlNameIdentifier* return_value;
    jstring_to_xml_node(env, jarg1, &xmlnode);
    return_value =  (LassoSamlNameIdentifier*) lasso_saml_name_identifier_new_from_xmlNode(xmlnode);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_misc_text_node_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_misc_1text_1node_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_misc_text_node_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoMiscTextNode* lasso_misc_text_node_new_with_string( const char* content {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_misc_1text_1node_1new_1with_1string(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    char* content = NULL;
    LassoMiscTextNode* return_value;
    jstring_to_string(env, jarg1, (char**)&content);
    return_value =  (LassoMiscTextNode*) lasso_misc_text_node_new_with_string((const char*) content);
    if (content)
        g_free(content);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoMiscTextNode* lasso_misc_text_node_new_with_xml_node( xmlNode* xml_node {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_misc_1text_1node_1new_1with_1xml_1node(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    xmlNode* xml_node = NULL;
    LassoMiscTextNode* return_value;
    jstring_to_xml_node(env, jarg1, &xml_node);
    return_value =  (LassoMiscTextNode*) lasso_misc_text_node_new_with_xml_node(xml_node);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml_advice_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1advice_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml_advice_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_authn_context_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1authn_1context_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_authn_context_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_federation_termination_notification_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1federation_1termination_1notification_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_federation_termination_notification_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_federation_termination_notification_new_full( char* providerID {}, LassoSamlNameIdentifier* nameIdentifier {}, LassoSignatureType sign_type {}, LassoSignatureMethod sign_method {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1federation_1termination_1notification_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 ,jobject jarg2 ,jint jarg3 ,jint jarg4 )
  {
    jobject ret;
    char* providerID = NULL;
    LassoSamlNameIdentifier* nameIdentifier = NULL;
    LassoSignatureType sign_type;
    LassoSignatureMethod sign_method;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&providerID);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&nameIdentifier);
    sign_type = (LassoSignatureType)jarg3;
    sign_method = (LassoSignatureMethod)jarg4;
    return_value =  (LassoNode*) lasso_lib_federation_termination_notification_new_full(providerID, nameIdentifier, sign_type, sign_method);
    if (providerID)
        g_free(providerID);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_paos_response_new( const gchar* refToMessageID {'optional': True}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_paos_1response_1new(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jlong ret;
    gchar* refToMessageID = NULL;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&refToMessageID);
    return_value =  (LassoNode*) lasso_paos_response_new((const gchar*) refToMessageID);
    if (refToMessageID)
        g_free(refToMessageID);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSamlAttributeValue* lasso_saml_attribute_value_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1attribute_1value_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSamlAttributeValue* return_value;
    return_value =  (LassoSamlAttributeValue*) lasso_saml_attribute_value_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSamlAssertion* lasso_saml_assertion_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1assertion_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSamlAssertion* return_value;
    return_value =  (LassoSamlAssertion*) lasso_saml_assertion_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_paos_request_new( const gchar* responseConsumerURL {'optional': True}, const gchar* messageID {'optional': True}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_paos_1request_1new(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 )
  {
    jlong ret;
    gchar* responseConsumerURL = NULL;
    gchar* messageID = NULL;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&responseConsumerURL);
    jstring_to_string(env, jarg2, (char**)&messageID);
    return_value =  (LassoNode*) lasso_paos_request_new((const gchar*) responseConsumerURL, (const gchar*) messageID);
    if (responseConsumerURL)
        g_free(responseConsumerURL);
    if (messageID)
        g_free(messageID);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSamlAttribute* lasso_saml_attribute_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1attribute_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSamlAttribute* return_value;
    return_value =  (LassoSamlAttribute*) lasso_saml_attribute_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  char* lasso_build_unique_id( unsigned int size {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_build_1unique_1id(JNIEnv *env, jclass clss
,jint jarg1 )
  {
    jstring ret;
    unsigned int size;
    char* return_value;
    size = (unsigned int)jarg1;
    return_value =  lasso_build_unique_id(size);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  LassoLibSubject* lasso_lib_subject_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1subject_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoLibSubject* return_value;
    return_value =  (LassoLibSubject*) lasso_lib_subject_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_register_name_identifier_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1register_1name_1identifier_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_register_name_identifier_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_register_name_identifier_response_new_full( const char* providerID {}, const char* statusCodeValue {}, LassoLibRegisterNameIdentifierRequest* request {}, LassoSignatureType sign_type {}, LassoSignatureMethod sign_method {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1register_1name_1identifier_1response_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jobject jarg3 ,jint jarg4 ,jint jarg5 )
  {
    jobject ret;
    char* providerID = NULL;
    char* statusCodeValue = NULL;
    LassoLibRegisterNameIdentifierRequest* request = NULL;
    LassoSignatureType sign_type;
    LassoSignatureMethod sign_method;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&providerID);
    jstring_to_string(env, jarg2, (char**)&statusCodeValue);
    jobject_to_gobject_noref(env, jarg3, (GObject**)&request);
    sign_type = (LassoSignatureType)jarg4;
    sign_method = (LassoSignatureMethod)jarg5;
    return_value =  (LassoNode*) lasso_lib_register_name_identifier_response_new_full((const char*) providerID, (const char*) statusCodeValue, request, sign_type, sign_method);
    if (providerID)
        g_free(providerID);
    if (statusCodeValue)
        g_free(statusCodeValue);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSamlpStatusCode* lasso_samlp_status_code_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp_1status_1code_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSamlpStatusCode* return_value;
    return_value =  (LassoSamlpStatusCode*) lasso_samlp_status_code_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_authn_response_new( char* providerID {}, LassoLibAuthnRequest* request {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1authn_1response_1new(JNIEnv *env, jclass clss
,jstring jarg1 ,jobject jarg2 )
  {
    jlong ret;
    char* providerID = NULL;
    LassoLibAuthnRequest* request = NULL;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&providerID);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&request);
    return_value =  (LassoNode*) lasso_lib_authn_response_new(providerID, request);
    if (providerID)
        g_free(providerID);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoLibAssertion* lasso_lib_assertion_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1assertion_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoLibAssertion* return_value;
    return_value =  (LassoLibAssertion*) lasso_lib_assertion_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoLibAssertion* lasso_lib_assertion_new_full( const char* issuer {}, const char* requestID {'optional': True}, const char* audience {'optional': True}, const char* notBefore {}, const char* notOnOrAfter {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1assertion_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jstring jarg3 ,jstring jarg4 ,jstring jarg5 )
  {
    jobject ret;
    char* issuer = NULL;
    char* requestID = NULL;
    char* audience = NULL;
    char* notBefore = NULL;
    char* notOnOrAfter = NULL;
    LassoLibAssertion* return_value;
    jstring_to_string(env, jarg1, (char**)&issuer);
    jstring_to_string(env, jarg2, (char**)&requestID);
    jstring_to_string(env, jarg3, (char**)&audience);
    jstring_to_string(env, jarg4, (char**)&notBefore);
    jstring_to_string(env, jarg5, (char**)&notOnOrAfter);
    return_value =  (LassoLibAssertion*) lasso_lib_assertion_new_full((const char*) issuer, (const char*) requestID, (const char*) audience, (const char*) notBefore, (const char*) notOnOrAfter);
    if (issuer)
        g_free(issuer);
    if (requestID)
        g_free(requestID);
    if (audience)
        g_free(audience);
    if (notBefore)
        g_free(notBefore);
    if (notOnOrAfter)
        g_free(notOnOrAfter);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoLibRequestAuthnContext* lasso_lib_request_authn_context_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1request_1authn_1context_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoLibRequestAuthnContext* return_value;
    return_value =  (LassoLibRequestAuthnContext*) lasso_lib_request_authn_context_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp_request_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp_1request_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp_request_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml_attribute_designator_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1attribute_1designator_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml_attribute_designator_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml_subject_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1subject_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml_subject_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_logout_request_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1logout_1request_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_logout_request_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_logout_request_new_full( char* providerID {}, LassoSamlNameIdentifier* nameIdentifier {}, LassoSignatureType sign_type {}, LassoSignatureMethod sign_method {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1logout_1request_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 ,jobject jarg2 ,jint jarg3 ,jint jarg4 )
  {
    jobject ret;
    char* providerID = NULL;
    LassoSamlNameIdentifier* nameIdentifier = NULL;
    LassoSignatureType sign_type;
    LassoSignatureMethod sign_method;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&providerID);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&nameIdentifier);
    sign_type = (LassoSignatureType)jarg3;
    sign_method = (LassoSignatureMethod)jarg4;
    return_value =  (LassoNode*) lasso_lib_logout_request_new_full(providerID, nameIdentifier, sign_type, sign_method);
    if (providerID)
        g_free(providerID);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoLibAuthnResponseEnvelope* lasso_lib_authn_response_envelope_new( LassoLibAuthnResponse* response {}, char* assertionConsumerServiceURL {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1authn_1response_1envelope_1new(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jlong ret;
    LassoLibAuthnResponse* response = NULL;
    char* assertionConsumerServiceURL = NULL;
    LassoLibAuthnResponseEnvelope* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&response);
    jstring_to_string(env, jarg2, (char**)&assertionConsumerServiceURL);
    return_value =  (LassoLibAuthnResponseEnvelope*) lasso_lib_authn_response_envelope_new(response, assertionConsumerServiceURL);
    if (assertionConsumerServiceURL)
        g_free(assertionConsumerServiceURL);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml_authority_binding_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1authority_1binding_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml_authority_binding_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_name_identifier_mapping_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1name_1identifier_1mapping_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_name_identifier_mapping_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_name_identifier_mapping_response_new_full( char* provideRID {}, const char* statusCodeValue {}, LassoLibNameIdentifierMappingRequest* request {}, LassoSignatureType sign_type {}, LassoSignatureMethod sign_method {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1name_1identifier_1mapping_1response_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jobject jarg3 ,jint jarg4 ,jint jarg5 )
  {
    jobject ret;
    char* provideRID = NULL;
    char* statusCodeValue = NULL;
    LassoLibNameIdentifierMappingRequest* request = NULL;
    LassoSignatureType sign_type;
    LassoSignatureMethod sign_method;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&provideRID);
    jstring_to_string(env, jarg2, (char**)&statusCodeValue);
    jobject_to_gobject_noref(env, jarg3, (GObject**)&request);
    sign_type = (LassoSignatureType)jarg4;
    sign_method = (LassoSignatureMethod)jarg5;
    return_value =  (LassoNode*) lasso_lib_name_identifier_mapping_response_new_full(provideRID, (const char*) statusCodeValue, request, sign_type, sign_method);
    if (provideRID)
        g_free(provideRID);
    if (statusCodeValue)
        g_free(statusCodeValue);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_idp_list_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1idp_1list_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_idp_list_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoLibAuthenticationStatement* lasso_lib_authentication_statement_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1authentication_1statement_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoLibAuthenticationStatement* return_value;
    return_value =  (LassoLibAuthenticationStatement*) lasso_lib_authentication_statement_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoLibAuthenticationStatement* lasso_lib_authentication_statement_new_full( const char* authenticationMethod {}, const char* authenticationInstant {'optional': True}, const char* reauthenticateOnOrAfter {'optional': True}, LassoSamlNameIdentifier* sp_identifier {}, LassoSamlNameIdentifier* idp_identifier {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1authentication_1statement_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jstring jarg3 ,jobject jarg4 ,jobject jarg5 )
  {
    jobject ret;
    char* authenticationMethod = NULL;
    char* authenticationInstant = NULL;
    char* reauthenticateOnOrAfter = NULL;
    LassoSamlNameIdentifier* sp_identifier = NULL;
    LassoSamlNameIdentifier* idp_identifier = NULL;
    LassoLibAuthenticationStatement* return_value;
    jstring_to_string(env, jarg1, (char**)&authenticationMethod);
    jstring_to_string(env, jarg2, (char**)&authenticationInstant);
    jstring_to_string(env, jarg3, (char**)&reauthenticateOnOrAfter);
    jobject_to_gobject_noref(env, jarg4, (GObject**)&sp_identifier);
    jobject_to_gobject_noref(env, jarg5, (GObject**)&idp_identifier);
    return_value =  (LassoLibAuthenticationStatement*) lasso_lib_authentication_statement_new_full((const char*) authenticationMethod, (const char*) authenticationInstant, (const char*) reauthenticateOnOrAfter, sp_identifier, idp_identifier);
    if (authenticationMethod)
        g_free(authenticationMethod);
    if (authenticationInstant)
        g_free(authenticationInstant);
    if (reauthenticateOnOrAfter)
        g_free(reauthenticateOnOrAfter);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_name_identifier_mapping_request_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1name_1identifier_1mapping_1request_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_name_identifier_mapping_request_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_name_identifier_mapping_request_new_full( char* providerID {}, LassoSamlNameIdentifier* nameIdentifier {}, const char* targetNamespace {}, LassoSignatureType sign_type {}, LassoSignatureMethod sign_method {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1name_1identifier_1mapping_1request_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 ,jobject jarg2 ,jstring jarg3 ,jint jarg4 ,jint jarg5 )
  {
    jobject ret;
    char* providerID = NULL;
    LassoSamlNameIdentifier* nameIdentifier = NULL;
    char* targetNamespace = NULL;
    LassoSignatureType sign_type;
    LassoSignatureMethod sign_method;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&providerID);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&nameIdentifier);
    jstring_to_string(env, jarg3, (char**)&targetNamespace);
    sign_type = (LassoSignatureType)jarg4;
    sign_method = (LassoSignatureMethod)jarg5;
    return_value =  (LassoNode*) lasso_lib_name_identifier_mapping_request_new_full(providerID, nameIdentifier, (const char*) targetNamespace, sign_type, sign_method);
    if (providerID)
        g_free(providerID);
    if (targetNamespace)
        g_free(targetNamespace);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSamlAttributeStatement* lasso_saml_attribute_statement_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1attribute_1statement_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSamlAttributeStatement* return_value;
    return_value =  (LassoSamlAttributeStatement*) lasso_saml_attribute_statement_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_idp_entry_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1idp_1entry_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_idp_entry_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSamlAudienceRestrictionCondition* lasso_saml_audience_restriction_condition_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1audience_1restriction_1condition_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSamlAudienceRestrictionCondition* return_value;
    return_value =  (LassoSamlAudienceRestrictionCondition*) lasso_saml_audience_restriction_condition_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSamlAudienceRestrictionCondition* lasso_saml_audience_restriction_condition_new_full( const char* audience {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1audience_1restriction_1condition_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    char* audience = NULL;
    LassoSamlAudienceRestrictionCondition* return_value;
    jstring_to_string(env, jarg1, (char**)&audience);
    return_value =  (LassoSamlAudienceRestrictionCondition*) lasso_saml_audience_restriction_condition_new_full((const char*) audience);
    if (audience)
        g_free(audience);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_lib_idp_entries_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1idp_1entries_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_lib_idp_entries_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_node_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_node_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  void lasso_register_dst_service( const char* prefix {}, const char* href {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_register_1dst_1service(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 )
  {
    char* prefix = NULL;
    char* href = NULL;
    jstring_to_string(env, jarg1, (char**)&prefix);
    jstring_to_string(env, jarg2, (char**)&href);
    lasso_register_dst_service((const char*) prefix, (const char*) href);
    if (prefix)
        g_free(prefix);
    if (href)
        g_free(href);
  }
/* Wrapper function for  char* lasso_get_prefix_for_dst_service_href( const char* href {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_get_1prefix_1for_1dst_1service_1href(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jstring ret;
    char* href = NULL;
    char* return_value;
    jstring_to_string(env, jarg1, (char**)&href);
    return_value =  lasso_get_prefix_for_dst_service_href((const char*) href);
    if (href)
        g_free(href);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  void lasso_register_idwsf2_dst_service( const gchar* prefix {}, const gchar* href {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_register_1idwsf2_1dst_1service(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 )
  {
    gchar* prefix = NULL;
    gchar* href = NULL;
    jstring_to_string(env, jarg1, (char**)&prefix);
    jstring_to_string(env, jarg2, (char**)&href);
    lasso_register_idwsf2_dst_service((const gchar*) prefix, (const gchar*) href);
    if (prefix)
        g_free(prefix);
    if (href)
        g_free(href);
  }
/* Wrapper function for  gchar* lasso_get_prefix_for_idwsf2_dst_service_href( const gchar* href {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_get_1prefix_1for_1idwsf2_1dst_1service_1href(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jstring ret;
    gchar* href = NULL;
    gchar* return_value;
    jstring_to_string(env, jarg1, (char**)&href);
    return_value =  lasso_get_prefix_for_idwsf2_dst_service_href((const gchar*) href);
    if (href)
        g_free(href);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  LassoLibScoping* lasso_lib_scoping_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1scoping_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoLibScoping* return_value;
    return_value =  (LassoLibScoping*) lasso_lib_scoping_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml_subject_locality_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1subject_1locality_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml_subject_locality_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSamlpStatus* lasso_samlp_status_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp_1status_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSamlpStatus* return_value;
    return_value =  (LassoSamlpStatus*) lasso_samlp_status_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_name_id_policy_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1name_1id_1policy_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_name_id_policy_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_name_id_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1name_1id_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_name_id_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_name_id_new_with_string( char* content {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1name_1id_1new_1with_1string(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    char* content = NULL;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&content);
    return_value =  (LassoNode*) lasso_saml2_name_id_new_with_string(content);
    if (content)
        g_free(content);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_requested_authn_context_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1requested_1authn_1context_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_requested_authn_context_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_subject_locality_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1subject_1locality_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_subject_locality_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_attribute_statement_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1attribute_1statement_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_attribute_statement_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_audience_restriction_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1audience_1restriction_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_audience_restriction_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_base_idabstract_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1base_1idabstract_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_base_idabstract_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_condition_abstract_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1condition_1abstract_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_condition_abstract_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSaml2AttributeValue* lasso_saml2_attribute_value_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1attribute_1value_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSaml2AttributeValue* return_value;
    return_value =  (LassoSaml2AttributeValue*) lasso_saml2_attribute_value_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_artifact_resolve_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1artifact_1resolve_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_artifact_resolve_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_name_id_mapping_request_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1name_1id_1mapping_1request_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_name_id_mapping_request_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_assertion_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_assertion_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_subject_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1subject_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_subject_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_manage_name_id_request_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1manage_1name_1id_1request_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_manage_name_id_request_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_status_detail_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1status_1detail_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_status_detail_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_statement_abstract_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1statement_1abstract_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_statement_abstract_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_advice_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1advice_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_advice_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_logout_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1logout_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_logout_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_key_info_confirmation_data_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1key_1info_1confirmation_1data_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_key_info_confirmation_data_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_status_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1status_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_status_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_attribute_query_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1attribute_1query_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_attribute_query_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_status_code_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1status_1code_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_status_code_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_encrypted_element_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1encrypted_1element_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_encrypted_element_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_action_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1action_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_action_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_action_new_with_string( char* content {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1action_1new_1with_1string(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    char* content = NULL;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&content);
    return_value =  (LassoNode*) lasso_saml2_action_new_with_string(content);
    if (content)
        g_free(content);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_key_info_confirmation_data_type_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1key_1info_1confirmation_1data_1type_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_key_info_confirmation_data_type_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_scoping_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1scoping_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_scoping_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_authn_query_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1authn_1query_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_authn_query_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_request_abstract_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1request_1abstract_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_request_abstract_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_conditions_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1conditions_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_conditions_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_assertion_id_request_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1assertion_1id_1request_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_assertion_id_request_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_authn_statement_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1authn_1statement_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_authn_statement_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_authz_decision_statement_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1authz_1decision_1statement_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_authz_decision_statement_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_authn_request_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1authn_1request_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_authn_request_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_terminate_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1terminate_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_terminate_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_proxy_restriction_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1proxy_1restriction_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_proxy_restriction_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_artifact_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1artifact_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_artifact_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_authn_context_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1authn_1context_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_authn_context_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_one_time_use_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1one_1time_1use_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_one_time_use_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_idp_list_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1idp_1list_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_idp_list_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_name_id_mapping_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1name_1id_1mapping_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_name_id_mapping_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_authz_decision_query_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1authz_1decision_1query_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_authz_decision_query_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_extensions_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1extensions_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_extensions_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_evidence_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1evidence_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_evidence_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_attribute_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1attribute_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_attribute_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_idp_entry_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1idp_1entry_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_idp_entry_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_subject_confirmation_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1subject_1confirmation_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_subject_confirmation_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_manage_name_id_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1manage_1name_1id_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_manage_name_id_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_subject_query_abstract_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1subject_1query_1abstract_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_subject_query_abstract_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_logout_request_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1logout_1request_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_logout_request_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_saml2_subject_confirmation_data_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1subject_1confirmation_1data_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_saml2_subject_confirmation_data_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_samlp2_status_response_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1status_1response_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoNode* return_value;
    return_value =  (LassoNode*) lasso_samlp2_status_response_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_ecp_request_new( const gchar* Issuer {}, gboolean IsPassive {}, const gchar* ProviderName {}, LassoSamlp2IDPList* IDPList {'optional': True}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1request_1new(JNIEnv *env, jclass clss
,jstring jarg1 ,jboolean jarg2 ,jstring jarg3 ,jobject jarg4 )
  {
    jlong ret;
    gchar* Issuer = NULL;
    gboolean IsPassive;
    gchar* ProviderName = NULL;
    LassoSamlp2IDPList* IDPList = NULL;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&Issuer);
    IsPassive = (gboolean)jarg2;
    jstring_to_string(env, jarg3, (char**)&ProviderName);
    jobject_to_gobject_noref(env, jarg4, (GObject**)&IDPList);
    return_value =  (LassoNode*) lasso_ecp_request_new((const gchar*) Issuer, IsPassive, (const gchar*) ProviderName, IDPList);
    if (Issuer)
        g_free(Issuer);
    if (ProviderName)
        g_free(ProviderName);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_ecp_response_new( const gchar* AssertionConsumerServiceURL {'optional': True}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1response_1new(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jlong ret;
    gchar* AssertionConsumerServiceURL = NULL;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&AssertionConsumerServiceURL);
    return_value =  (LassoNode*) lasso_ecp_response_new((const gchar*) AssertionConsumerServiceURL);
    if (AssertionConsumerServiceURL)
        g_free(AssertionConsumerServiceURL);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_ecp_relay_state_new( const gchar* RelayState {'optional': True}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1relay_1state_1new(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jlong ret;
    gchar* RelayState = NULL;
    LassoNode* return_value;
    jstring_to_string(env, jarg1, (char**)&RelayState);
    return_value =  (LassoNode*) lasso_ecp_relay_state_new((const gchar*) RelayState);
    if (RelayState)
        g_free(RelayState);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSoapDetail* lasso_soap_detail_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1detail_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSoapDetail* return_value;
    return_value =  (LassoSoapDetail*) lasso_soap_detail_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSoapDetail* lasso_soap_detail_new_from_message( const gchar* message {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1detail_1new_1from_1message(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    gchar* message = NULL;
    LassoSoapDetail* return_value;
    jstring_to_string(env, jarg1, (char**)&message);
    return_value =  (LassoSoapDetail*) lasso_soap_detail_new_from_message((const gchar*) message);
    if (message)
        g_free(message);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSoapBody* lasso_soap_body_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1body_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSoapBody* return_value;
    return_value =  (LassoSoapBody*) lasso_soap_body_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSoapBody* lasso_soap_body_new_from_message( const gchar* message {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1body_1new_1from_1message(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    gchar* message = NULL;
    LassoSoapBody* return_value;
    jstring_to_string(env, jarg1, (char**)&message);
    return_value =  (LassoSoapBody*) lasso_soap_body_new_from_message((const gchar*) message);
    if (message)
        g_free(message);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSoapEnvelope* lasso_soap_envelope_new( LassoSoapBody* body {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1envelope_1new(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jlong ret;
    LassoSoapBody* body = NULL;
    LassoSoapEnvelope* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&body);
    return_value =  (LassoSoapEnvelope*) lasso_soap_envelope_new(body);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSoapEnvelope* lasso_soap_envelope_new_from_message( const gchar* message {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1envelope_1new_1from_1message(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    gchar* message = NULL;
    LassoSoapEnvelope* return_value;
    jstring_to_string(env, jarg1, (char**)&message);
    return_value =  (LassoSoapEnvelope*) lasso_soap_envelope_new_from_message((const gchar*) message);
    if (message)
        g_free(message);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSoapEnvelope* lasso_soap_envelope_new_full( ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1envelope_1new_1full(JNIEnv *env, jclass clss
)
  {
    jobject ret;
    LassoSoapEnvelope* return_value;
    return_value =  (LassoSoapEnvelope*) lasso_soap_envelope_new_full();
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSoapFault* lasso_soap_fault_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1fault_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSoapFault* return_value;
    return_value =  (LassoSoapFault*) lasso_soap_fault_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSoapFault* lasso_soap_fault_new_from_message( const gchar* message {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1fault_1new_1from_1message(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    gchar* message = NULL;
    LassoSoapFault* return_value;
    jstring_to_string(env, jarg1, (char**)&message);
    return_value =  (LassoSoapFault*) lasso_soap_fault_new_from_message((const gchar*) message);
    if (message)
        g_free(message);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSoapFault* lasso_soap_fault_new_full( const char* faultcode {}, const char* faultstring {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1fault_1new_1full(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 )
  {
    jobject ret;
    char* faultcode = NULL;
    char* faultstring = NULL;
    LassoSoapFault* return_value;
    jstring_to_string(env, jarg1, (char**)&faultcode);
    jstring_to_string(env, jarg2, (char**)&faultstring);
    return_value =  (LassoSoapFault*) lasso_soap_fault_new_full((const char*) faultcode, (const char*) faultstring);
    if (faultcode)
        g_free(faultcode);
    if (faultstring)
        g_free(faultstring);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSoapHeader* lasso_soap_header_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1header_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSoapHeader* return_value;
    return_value =  (LassoSoapHeader*) lasso_soap_header_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSoapHeader* lasso_soap_header_new_from_message( const gchar* message {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_soap_1header_1new_1from_1message(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    gchar* message = NULL;
    LassoSoapHeader* return_value;
    jstring_to_string(env, jarg1, (char**)&message);
    return_value =  (LassoSoapHeader*) lasso_soap_header_new_from_message((const gchar*) message);
    if (message)
        g_free(message);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoDsKeyInfo* lasso_ds_key_info_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1key_1info_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoDsKeyInfo* return_value;
    return_value =  (LassoDsKeyInfo*) lasso_ds_key_info_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoDsKeyValue* lasso_ds_key_value_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1key_1value_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoDsKeyValue* return_value;
    return_value =  (LassoDsKeyValue*) lasso_ds_key_value_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoDsRsaKeyValue* lasso_ds_rsa_key_value_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1rsa_1key_1value_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoDsRsaKeyValue* return_value;
    return_value =  (LassoDsRsaKeyValue*) lasso_ds_rsa_key_value_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoDsX509Data* lasso_ds_x509_data_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1x509_1data_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoDsX509Data* return_value;
    return_value =  (LassoDsX509Data*) lasso_ds_x509_data_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoServer* lasso_server_new( const gchar* metadata {'optional': True}, const gchar* private_key {'optional': True}, const gchar* private_key_password {'optional': True}, const gchar* certificate {'optional': True}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1new(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jstring jarg3 ,jstring jarg4 )
  {
    jlong ret;
    gchar* metadata = NULL;
    gchar* private_key = NULL;
    gchar* private_key_password = NULL;
    gchar* certificate = NULL;
    LassoServer* return_value;
    jstring_to_string(env, jarg1, (char**)&metadata);
    jstring_to_string(env, jarg2, (char**)&private_key);
    jstring_to_string(env, jarg3, (char**)&private_key_password);
    jstring_to_string(env, jarg4, (char**)&certificate);
    return_value =  (LassoServer*) lasso_server_new((const gchar*) metadata, (const gchar*) private_key, (const gchar*) private_key_password, (const gchar*) certificate);
    if (metadata)
        g_free(metadata);
    if (private_key)
        g_free(private_key);
    if (private_key_password)
        g_free(private_key_password);
    if (certificate)
        g_free(certificate);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoServer* lasso_server_new_from_buffers( const gchar* metadata {}, const gchar* private_key_content {'optional': True}, const gchar* private_key_password {'optional': True}, const gchar* certificate_content {'optional': True}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1new_1from_1buffers(JNIEnv *env, jclass clss
,jstring jarg1 ,jstring jarg2 ,jstring jarg3 ,jstring jarg4 )
  {
    jobject ret;
    gchar* metadata = NULL;
    gchar* private_key_content = NULL;
    gchar* private_key_password = NULL;
    gchar* certificate_content = NULL;
    LassoServer* return_value;
    jstring_to_string(env, jarg1, (char**)&metadata);
    jstring_to_string(env, jarg2, (char**)&private_key_content);
    jstring_to_string(env, jarg3, (char**)&private_key_password);
    jstring_to_string(env, jarg4, (char**)&certificate_content);
    return_value =  (LassoServer*) lasso_server_new_from_buffers((const gchar*) metadata, (const gchar*) private_key_content, (const gchar*) private_key_password, (const gchar*) certificate_content);
    if (metadata)
        g_free(metadata);
    if (private_key_content)
        g_free(private_key_content);
    if (private_key_password)
        g_free(private_key_password);
    if (certificate_content)
        g_free(certificate_content);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoServer* lasso_server_new_from_dump( const gchar* dump {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1new_1from_1dump(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    gchar* dump = NULL;
    LassoServer* return_value;
    jstring_to_string(env, jarg1, (char**)&dump);
    return_value =  (LassoServer*) lasso_server_new_from_dump((const gchar*) dump);
    if (dump)
        g_free(dump);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoFederation* lasso_federation_new( const gchar* remote_providerID {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_federation_1new(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jlong ret;
    gchar* remote_providerID = NULL;
    LassoFederation* return_value;
    jstring_to_string(env, jarg1, (char**)&remote_providerID);
    return_value =  (LassoFederation*) lasso_federation_new((const gchar*) remote_providerID);
    if (remote_providerID)
        g_free(remote_providerID);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoLogin* lasso_login_new( LassoServer* server {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1new(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jlong ret;
    LassoServer* server = NULL;
    LassoLogin* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    return_value =  (LassoLogin*) lasso_login_new(server);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoLogin* lasso_login_new_from_dump( LassoServer* server {}, const gchar* dump {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1new_1from_1dump(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobject ret;
    LassoServer* server = NULL;
    gchar* dump = NULL;
    LassoLogin* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jstring_to_string(env, jarg2, (char**)&dump);
    return_value =  (LassoLogin*) lasso_login_new_from_dump(server, (const gchar*) dump);
    if (dump)
        g_free(dump);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoRequestType lasso_profile_get_request_type_from_soap_msg( const gchar* soap {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_lasso_1get_1request_1type_1from_1soap_1msg(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jint ret;
    gchar* soap = NULL;
    LassoRequestType return_value;
    jstring_to_string(env, jarg1, (char**)&soap);
    return_value =  lasso_profile_get_request_type_from_soap_msg((const gchar*) soap);
    if (soap)
        g_free(soap);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_profile_is_liberty_query( const gchar* query {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_isLibertyQuery(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jboolean ret;
    gchar* query = NULL;
    gboolean return_value;
    jstring_to_string(env, jarg1, (char**)&query);
    return_value =  lasso_profile_is_liberty_query((const gchar*) query);
    if (query)
        g_free(query);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  char* lasso_profile_get_issuer( const char* message {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1issuer(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jstring ret;
    char* message = NULL;
    char* return_value;
    jstring_to_string(env, jarg1, (char**)&message);
    return_value =  lasso_profile_get_issuer((const char*) message);
    if (message)
        g_free(message);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_profile_get_in_response_to( const char* message {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1in_1response_1to(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jstring ret;
    char* message = NULL;
    char* return_value;
    jstring_to_string(env, jarg1, (char**)&message);
    return_value =  lasso_profile_get_in_response_to((const char*) message);
    if (message)
        g_free(message);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  LassoNameRegistration* lasso_name_registration_new( LassoServer* server {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1registration_1new(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jlong ret;
    LassoServer* server = NULL;
    LassoNameRegistration* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    return_value =  (LassoNameRegistration*) lasso_name_registration_new(server);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoNameRegistration* lasso_name_registration_new_from_dump( LassoServer* server {}, const char* dump {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1registration_1new_1from_1dump(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobject ret;
    LassoServer* server = NULL;
    char* dump = NULL;
    LassoNameRegistration* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jstring_to_string(env, jarg2, (char**)&dump);
    return_value =  (LassoNameRegistration*) lasso_name_registration_new_from_dump(server, (const char*) dump);
    if (dump)
        g_free(dump);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoDefederation* lasso_defederation_new( LassoServer* server {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_defederation_1new(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jlong ret;
    LassoServer* server = NULL;
    LassoDefederation* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    return_value =  (LassoDefederation*) lasso_defederation_new(server);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoProvider* lasso_provider_new( LassoProviderRole role {}, const char* metadata {}, const char* public_key {'optional': True}, const char* ca_cert_chain {'optional': True}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1new(JNIEnv *env, jclass clss
,jint jarg1 ,jstring jarg2 ,jstring jarg3 ,jstring jarg4 )
  {
    jlong ret;
    LassoProviderRole role;
    char* metadata = NULL;
    char* public_key = NULL;
    char* ca_cert_chain = NULL;
    LassoProvider* return_value;
    role = (LassoProviderRole)jarg1;
    jstring_to_string(env, jarg2, (char**)&metadata);
    jstring_to_string(env, jarg3, (char**)&public_key);
    jstring_to_string(env, jarg4, (char**)&ca_cert_chain);
    return_value =  (LassoProvider*) lasso_provider_new(role, (const char*) metadata, (const char*) public_key, (const char*) ca_cert_chain);
    if (metadata)
        g_free(metadata);
    if (public_key)
        g_free(public_key);
    if (ca_cert_chain)
        g_free(ca_cert_chain);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoProvider* lasso_provider_new_from_buffer( LassoProviderRole role {}, const char* metadata {}, const char* public_key {'optional': True}, const char* ca_cert_chain {'optional': True}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1new_1from_1buffer(JNIEnv *env, jclass clss
,jint jarg1 ,jstring jarg2 ,jstring jarg3 ,jstring jarg4 )
  {
    jobject ret;
    LassoProviderRole role;
    char* metadata = NULL;
    char* public_key = NULL;
    char* ca_cert_chain = NULL;
    LassoProvider* return_value;
    role = (LassoProviderRole)jarg1;
    jstring_to_string(env, jarg2, (char**)&metadata);
    jstring_to_string(env, jarg3, (char**)&public_key);
    jstring_to_string(env, jarg4, (char**)&ca_cert_chain);
    return_value =  (LassoProvider*) lasso_provider_new_from_buffer(role, (const char*) metadata, (const char*) public_key, (const char*) ca_cert_chain);
    if (metadata)
        g_free(metadata);
    if (public_key)
        g_free(public_key);
    if (ca_cert_chain)
        g_free(ca_cert_chain);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSession* lasso_session_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoSession* return_value;
    return_value =  (LassoSession*) lasso_session_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoSession* lasso_session_new_from_dump( const gchar* dump {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1new_1from_1dump(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    gchar* dump = NULL;
    LassoSession* return_value;
    jstring_to_string(env, jarg1, (char**)&dump);
    return_value =  (LassoSession*) lasso_session_new_from_dump((const gchar*) dump);
    if (dump)
        g_free(dump);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoLogout* lasso_logout_new( LassoServer* server {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1new(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jlong ret;
    LassoServer* server = NULL;
    LassoLogout* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    return_value =  (LassoLogout*) lasso_logout_new(server);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoLogout* lasso_logout_new_from_dump( LassoServer* server {}, const gchar* dump {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1new_1from_1dump(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobject ret;
    LassoServer* server = NULL;
    gchar* dump = NULL;
    LassoLogout* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jstring_to_string(env, jarg2, (char**)&dump);
    return_value =  (LassoLogout*) lasso_logout_new_from_dump(server, (const gchar*) dump);
    if (dump)
        g_free(dump);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoNameIdentifierMapping* lasso_name_identifier_mapping_new( LassoServer* server {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1identifier_1mapping_1new(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jlong ret;
    LassoServer* server = NULL;
    LassoNameIdentifierMapping* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    return_value =  (LassoNameIdentifierMapping*) lasso_name_identifier_mapping_new(server);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoIdentity* lasso_identity_new( ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_identity_1new(JNIEnv *env, jclass clss
)
  {
    jlong ret;
    LassoIdentity* return_value;
    return_value =  (LassoIdentity*) lasso_identity_new();
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* Wrapper function for  LassoIdentity* lasso_identity_new_from_dump( const gchar* dump {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_identity_1new_1from_1dump(JNIEnv *env, jclass clss
,jstring jarg1 )
  {
    jobject ret;
    gchar* dump = NULL;
    LassoIdentity* return_value;
    jstring_to_string(env, jarg1, (char**)&dump);
    return_value =  (LassoIdentity*) lasso_identity_new_from_dump((const gchar*) dump);
    if (dump)
        g_free(dump);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoLecp* lasso_lecp_new( LassoServer* server {}, ) */
JNIEXPORT jlong JNICALL Java_com_entrouvert_lasso_LassoJNI_lecp_1new(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jlong ret;
    LassoServer* server = NULL;
    LassoLecp* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    return_value =  (LassoLecp*) lasso_lecp_new(server);
    ret = (jlong)(ptrdiff_t) return_value;
    return ret;
  }
/* End of declaration of standalone functions */
/* Declaration of getter/setter methods */

/* Getter for GList* LassoLibAuthnRequestEnvelope.Extension */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1extension_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->Extension, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibAuthnRequestEnvelope.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1extension_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->Extension, value);
}
/* Adder for GList*<xmlNode> LassoLibAuthnRequestEnvelope.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1extension_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->Extension, value);
}

/* Getter for LassoLibAuthnRequest* LassoLibAuthnRequestEnvelope.AuthnRequest */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1authnRequest_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->AuthnRequest, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLibAuthnRequest* LassoLibAuthnRequestEnvelope.AuthnRequest */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1authnRequest_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->AuthnRequest);
}

/* Getter for char* LassoLibAuthnRequestEnvelope.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnRequestEnvelope.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for char* LassoLibAuthnRequestEnvelope.ProviderName */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1providerName_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderName, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnRequestEnvelope.ProviderName */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1providerName_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderName);
}

/* Getter for char* LassoLibAuthnRequestEnvelope.AssertionConsumerServiceURL */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1assertionConsumerServiceURL_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AssertionConsumerServiceURL, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnRequestEnvelope.AssertionConsumerServiceURL */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1assertionConsumerServiceURL_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AssertionConsumerServiceURL);
}

/* Getter for LassoLibIDPList* LassoLibAuthnRequestEnvelope.IDPList */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1iDPList_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->IDPList, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLibIDPList* LassoLibAuthnRequestEnvelope.IDPList */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1iDPList_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->IDPList);
}

/* Getter for gboolean LassoLibAuthnRequestEnvelope.IsPassive */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1isPassive_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->IsPassive;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoLibAuthnRequestEnvelope.IsPassive */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequestEnvelope_1isPassive_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoLibAuthnRequestEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->IsPassive = (gboolean)value;
}

/* Getter for GList* LassoSamlSubjectConfirmation.ConfirmationMethod */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectConfirmation_1confirmationMethod_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlSubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_strings(env, gobj->ConfirmationMethod, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlSubjectConfirmation.ConfirmationMethod */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectConfirmation_1confirmationMethod_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlSubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_strings(env, &gobj->ConfirmationMethod,value);
}
/* Adder for GList*<strings> LassoSamlSubjectConfirmation.ConfirmationMethod */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectConfirmation_1confirmationMethod_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlSubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_strings(env, &gobj->ConfirmationMethod, value);
}
/* Remover for GList*<strings> LassoSamlSubjectConfirmation.ConfirmationMethod */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectConfirmation_1confirmationMethod_1remove(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlSubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_strings(env, &gobj->ConfirmationMethod,value);
}


/* Getter for char* LassoSamlSubjectConfirmation.SubjectConfirmationData */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectConfirmation_1subjectConfirmationData_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlSubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SubjectConfirmationData, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlSubjectConfirmation.SubjectConfirmationData */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectConfirmation_1subjectConfirmationData_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlSubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SubjectConfirmationData);
}

/* Getter for LassoDsKeyInfo* LassoSamlSubjectConfirmation.KeyInfo */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectConfirmation_1keyInfo_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlSubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->KeyInfo, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoDsKeyInfo* LassoSamlSubjectConfirmation.KeyInfo */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectConfirmation_1keyInfo_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlSubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->KeyInfo);
}

/* Getter for GList* LassoSamlConditions.Condition */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1condition_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Condition, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlConditions.Condition */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1condition_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Condition, value);
}
/* Adder for GList*<LassoNode> LassoSamlConditions.Condition */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1condition_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Condition, value);
}
/* Remover for GList*<LassoNode> LassoSamlConditions.Condition */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1condition_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Condition,value);
}


/* Getter for GList* LassoSamlConditions.AudienceRestrictionCondition */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1audienceRestrictionCondition_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AudienceRestrictionCondition, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlConditions.AudienceRestrictionCondition */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1audienceRestrictionCondition_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AudienceRestrictionCondition, value);
}
/* Adder for GList*<LassoSamlAudienceRestrictionCondition> LassoSamlConditions.AudienceRestrictionCondition */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1audienceRestrictionCondition_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AudienceRestrictionCondition, value);
}
/* Remover for GList*<LassoSamlAudienceRestrictionCondition> LassoSamlConditions.AudienceRestrictionCondition */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1audienceRestrictionCondition_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AudienceRestrictionCondition,value);
}


/* Getter for char* LassoSamlConditions.NotBefore */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1notBefore_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NotBefore, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlConditions.NotBefore */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1notBefore_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NotBefore);
}

/* Getter for char* LassoSamlConditions.NotOnOrAfter */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1notOnOrAfter_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NotOnOrAfter, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlConditions.NotOnOrAfter */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlConditions_1notOnOrAfter_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlConditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NotOnOrAfter);
}

/* Getter for char* LassoSamlNameIdentifier.NameQualifier */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlNameIdentifier_1nameQualifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlNameIdentifier *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NameQualifier, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlNameIdentifier.NameQualifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlNameIdentifier_1nameQualifier_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlNameIdentifier *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NameQualifier);
}

/* Getter for char* LassoSamlNameIdentifier.Format */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlNameIdentifier_1format_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlNameIdentifier *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Format, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlNameIdentifier.Format */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlNameIdentifier_1format_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlNameIdentifier *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Format);
}

/* Getter for char* LassoSamlNameIdentifier.content */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlNameIdentifier_1content_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlNameIdentifier *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->content, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlNameIdentifier.content */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlNameIdentifier_1content_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlNameIdentifier *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->content);
}

/* Getter for char* LassoMiscTextNode.content */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_MiscTextNode_1content_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoMiscTextNode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->content, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoMiscTextNode.content */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_MiscTextNode_1content_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoMiscTextNode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->content);
}

/* Getter for char* LassoMiscTextNode.name */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_MiscTextNode_1name_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoMiscTextNode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->name, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoMiscTextNode.name */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_MiscTextNode_1name_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoMiscTextNode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->name);
}

/* Getter for char* LassoMiscTextNode.ns_href */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_MiscTextNode_1nsHref_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoMiscTextNode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ns_href, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoMiscTextNode.ns_href */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_MiscTextNode_1nsHref_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoMiscTextNode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ns_href);
}

/* Getter for char* LassoMiscTextNode.ns_prefix */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_MiscTextNode_1nsPrefix_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoMiscTextNode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ns_prefix, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoMiscTextNode.ns_prefix */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_MiscTextNode_1nsPrefix_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoMiscTextNode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ns_prefix);
}

/* Getter for gboolean LassoMiscTextNode.text_child */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_MiscTextNode_1textChild_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoMiscTextNode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->text_child;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoMiscTextNode.text_child */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_MiscTextNode_1textChild_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoMiscTextNode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->text_child = (gboolean)value;
}

/* Getter for GList* LassoSamlAdvice.AssertionIDReference */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAdvice_1assertionIdReference_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAdvice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AssertionIDReference, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlAdvice.AssertionIDReference */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAdvice_1assertionIdReference_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlAdvice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AssertionIDReference, value);
}
/* Adder for GList*<LassoNode> LassoSamlAdvice.AssertionIDReference */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAdvice_1assertionIdReference_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAdvice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AssertionIDReference, value);
}
/* Remover for GList*<LassoNode> LassoSamlAdvice.AssertionIDReference */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAdvice_1assertionIdReference_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAdvice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AssertionIDReference,value);
}


/* Getter for LassoSamlAssertion* LassoSamlAdvice.Assertion */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAdvice_1assertion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAdvice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Assertion, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlAssertion* LassoSamlAdvice.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAdvice_1assertion_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAdvice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Assertion);
}

/* Getter for char* LassoLibAuthnContext.AuthnContextClassRef */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnContext_1authnContextClassRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AuthnContextClassRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnContext.AuthnContextClassRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnContext_1authnContextClassRef_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AuthnContextClassRef);
}

/* Getter for char* LassoLibAuthnContext.AuthnContextStatementRef */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnContext_1authnContextStatementRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AuthnContextStatementRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnContext.AuthnContextStatementRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnContext_1authnContextStatementRef_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AuthnContextStatementRef);
}

/* Getter for gchar* LassoPaosResponse.refToMessageID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosResponse_1refToMessageId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoPaosResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->refToMessageID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoPaosResponse.refToMessageID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosResponse_1refToMessageId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoPaosResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->refToMessageID);
}

/* Getter for gboolean LassoPaosResponse.mustUnderstand */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosResponse_1mustUnderstand_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoPaosResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->mustUnderstand;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoPaosResponse.mustUnderstand */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosResponse_1mustUnderstand_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoPaosResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->mustUnderstand = (gboolean)value;
}

/* Getter for gchar* LassoPaosResponse.actor */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosResponse_1actor_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoPaosResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->actor, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoPaosResponse.actor */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosResponse_1actor_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoPaosResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->actor);
}

/* Getter for GList* LassoSamlAttributeValue.any */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeValue_1any_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAttributeValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->any, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlAttributeValue.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeValue_1any_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlAttributeValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->any, value);
}
/* Adder for GList*<LassoNode> LassoSamlAttributeValue.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeValue_1any_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAttributeValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->any, value);
}
/* Remover for GList*<LassoNode> LassoSamlAttributeValue.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeValue_1any_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAttributeValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->any,value);
}


/* Getter for LassoSamlConditions* LassoSamlAssertion.Conditions */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1conditions_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Conditions, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlConditions* LassoSamlAssertion.Conditions */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1conditions_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Conditions);
}

/* Getter for LassoSamlAdvice* LassoSamlAssertion.Advice */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1advice_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Advice, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlAdvice* LassoSamlAssertion.Advice */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1advice_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Advice);
}

/* Getter for LassoSamlSubjectStatement* LassoSamlAssertion.SubjectStatement */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1subjectStatement_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->SubjectStatement, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlSubjectStatement* LassoSamlAssertion.SubjectStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1subjectStatement_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->SubjectStatement);
}

/* Getter for LassoSamlAuthenticationStatement* LassoSamlAssertion.AuthenticationStatement */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1authenticationStatement_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->AuthenticationStatement, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlAuthenticationStatement* LassoSamlAssertion.AuthenticationStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1authenticationStatement_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->AuthenticationStatement);
}

/* Getter for LassoSamlAttributeStatement* LassoSamlAssertion.AttributeStatement */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1attributeStatement_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->AttributeStatement, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlAttributeStatement* LassoSamlAssertion.AttributeStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1attributeStatement_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->AttributeStatement);
}

/* Getter for int LassoSamlAssertion.MajorVersion */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1majorVersion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->MajorVersion;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for int LassoSamlAssertion.MajorVersion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1majorVersion_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->MajorVersion = (int)value;
}

/* Getter for int LassoSamlAssertion.MinorVersion */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1minorVersion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->MinorVersion;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for int LassoSamlAssertion.MinorVersion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1minorVersion_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->MinorVersion = (int)value;
}

/* Getter for char* LassoSamlAssertion.AssertionID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1assertionId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AssertionID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAssertion.AssertionID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1assertionId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AssertionID);
}

/* Getter for char* LassoSamlAssertion.Issuer */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1issuer_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Issuer, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAssertion.Issuer */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1issuer_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Issuer);
}

/* Getter for char* LassoSamlAssertion.IssueInstant */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1issueInstant_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->IssueInstant, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAssertion.IssueInstant */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1issueInstant_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->IssueInstant);
}

/* Getter for LassoSignatureType LassoSamlAssertion.sign_type */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1signType_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->sign_type;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSignatureType LassoSamlAssertion.sign_type */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1signType_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->sign_type = (LassoSignatureType)value;
}

/* Getter for LassoSignatureMethod LassoSamlAssertion.sign_method */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1signMethod_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->sign_method;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSignatureMethod LassoSamlAssertion.sign_method */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1signMethod_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->sign_method = (LassoSignatureMethod)value;
}

/* Getter for char* LassoSamlAssertion.private_key_file */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1privateKeyFile_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->private_key_file, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAssertion.private_key_file */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1privateKeyFile_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->private_key_file);
}

/* Getter for char* LassoSamlAssertion.certificate_file */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1certificateFile_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->certificate_file, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAssertion.certificate_file */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAssertion_1certificateFile_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->certificate_file);
}

/* Getter for gchar* LassoPaosRequest.responseConsumerURL */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosRequest_1responseConsumerURL_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoPaosRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->responseConsumerURL, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoPaosRequest.responseConsumerURL */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosRequest_1responseConsumerURL_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoPaosRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->responseConsumerURL);
}

/* Getter for gchar* LassoPaosRequest.messageID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosRequest_1messageId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoPaosRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->messageID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoPaosRequest.messageID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosRequest_1messageId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoPaosRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->messageID);
}

/* Getter for gchar* LassoPaosRequest.service */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosRequest_1service_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoPaosRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->service, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoPaosRequest.service */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosRequest_1service_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoPaosRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->service);
}

/* Getter for gboolean LassoPaosRequest.mustUnderstand */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosRequest_1mustUnderstand_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoPaosRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->mustUnderstand;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoPaosRequest.mustUnderstand */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosRequest_1mustUnderstand_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoPaosRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->mustUnderstand = (gboolean)value;
}

/* Getter for gchar* LassoPaosRequest.actor */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosRequest_1actor_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoPaosRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->actor, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoPaosRequest.actor */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_PaosRequest_1actor_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoPaosRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->actor);
}

/* Getter for LassoSamlSubject* LassoSamlSubjectStatementAbstract.Subject */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectStatementAbstract_1subject_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlSubjectStatementAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Subject, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlSubject* LassoSamlSubjectStatementAbstract.Subject */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectStatementAbstract_1subject_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlSubjectStatementAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Subject);
}

/* Getter for LassoSamlSubjectLocality* LassoSamlAuthenticationStatement.SubjectLocality */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthenticationStatement_1subjectLocality_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->SubjectLocality, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlSubjectLocality* LassoSamlAuthenticationStatement.SubjectLocality */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthenticationStatement_1subjectLocality_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->SubjectLocality);
}

/* Getter for GList* LassoSamlAuthenticationStatement.AuthorityBinding */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthenticationStatement_1authorityBinding_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AuthorityBinding, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlAuthenticationStatement.AuthorityBinding */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthenticationStatement_1authorityBinding_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AuthorityBinding, value);
}
/* Adder for GList*<LassoNode> LassoSamlAuthenticationStatement.AuthorityBinding */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthenticationStatement_1authorityBinding_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AuthorityBinding, value);
}
/* Remover for GList*<LassoNode> LassoSamlAuthenticationStatement.AuthorityBinding */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthenticationStatement_1authorityBinding_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AuthorityBinding,value);
}


/* Getter for char* LassoSamlAuthenticationStatement.AuthenticationMethod */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthenticationStatement_1authenticationMethod_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AuthenticationMethod, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAuthenticationStatement.AuthenticationMethod */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthenticationStatement_1authenticationMethod_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AuthenticationMethod);
}

/* Getter for char* LassoSamlAuthenticationStatement.AuthenticationInstant */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthenticationStatement_1authenticationInstant_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AuthenticationInstant, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAuthenticationStatement.AuthenticationInstant */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthenticationStatement_1authenticationInstant_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AuthenticationInstant);
}

/* Getter for char* LassoSamlpResponseAbstract.ResponseID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1responseId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ResponseID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpResponseAbstract.ResponseID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1responseId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ResponseID);
}

/* Getter for char* LassoSamlpResponseAbstract.InResponseTo */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1inResponseTo_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->InResponseTo, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpResponseAbstract.InResponseTo */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1inResponseTo_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->InResponseTo);
}

/* Getter for int LassoSamlpResponseAbstract.MajorVersion */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1majorVersion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->MajorVersion;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for int LassoSamlpResponseAbstract.MajorVersion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1majorVersion_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->MajorVersion = (int)value;
}

/* Getter for int LassoSamlpResponseAbstract.MinorVersion */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1minorVersion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->MinorVersion;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for int LassoSamlpResponseAbstract.MinorVersion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1minorVersion_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->MinorVersion = (int)value;
}

/* Getter for char* LassoSamlpResponseAbstract.IssueInstant */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1issueInstant_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->IssueInstant, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpResponseAbstract.IssueInstant */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1issueInstant_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->IssueInstant);
}

/* Getter for char* LassoSamlpResponseAbstract.Recipient */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1recipient_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Recipient, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpResponseAbstract.Recipient */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1recipient_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Recipient);
}

/* Getter for LassoSignatureType LassoSamlpResponseAbstract.sign_type */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1signType_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->sign_type;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSignatureType LassoSamlpResponseAbstract.sign_type */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1signType_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->sign_type = (LassoSignatureType)value;
}

/* Getter for LassoSignatureMethod LassoSamlpResponseAbstract.sign_method */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1signMethod_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->sign_method;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSignatureMethod LassoSamlpResponseAbstract.sign_method */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1signMethod_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->sign_method = (LassoSignatureMethod)value;
}

/* Getter for char* LassoSamlpResponseAbstract.private_key_file */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1privateKeyFile_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->private_key_file, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpResponseAbstract.private_key_file */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1privateKeyFile_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->private_key_file);
}

/* Getter for char* LassoSamlpResponseAbstract.certificate_file */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1certificateFile_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->certificate_file, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpResponseAbstract.certificate_file */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponseAbstract_1certificateFile_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpResponseAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->certificate_file);
}

/* Getter for GList* LassoLibStatusResponse.Extension */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibStatusResponse_1extension_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibStatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->Extension, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibStatusResponse.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibStatusResponse_1extension_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibStatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->Extension, value);
}
/* Adder for GList*<xmlNode> LassoLibStatusResponse.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibStatusResponse_1extension_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibStatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->Extension, value);
}

/* Getter for char* LassoLibStatusResponse.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibStatusResponse_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibStatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibStatusResponse.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibStatusResponse_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibStatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for LassoSamlpStatus* LassoLibStatusResponse.Status */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibStatusResponse_1status_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibStatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Status, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlpStatus* LassoLibStatusResponse.Status */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibStatusResponse_1status_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibStatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Status);
}

/* Getter for char* LassoLibStatusResponse.RelayState */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibStatusResponse_1relayState_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibStatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->RelayState, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibStatusResponse.RelayState */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibStatusResponse_1relayState_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibStatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->RelayState);
}

/* Getter for LassoSamlpStatusCode* LassoSamlpStatusCode.StatusCode */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpStatusCode_1statusCode_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpStatusCode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->StatusCode, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlpStatusCode* LassoSamlpStatusCode.StatusCode */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpStatusCode_1statusCode_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlpStatusCode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->StatusCode);
}

/* Getter for char* LassoSamlpStatusCode.Value */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpStatusCode_1value_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpStatusCode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Value, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpStatusCode.Value */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpStatusCode_1value_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpStatusCode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Value);
}

/* Getter for char* LassoLibAssertion.InResponseTo */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAssertion_1inResponseTo_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->InResponseTo, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAssertion.InResponseTo */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAssertion_1inResponseTo_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAssertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->InResponseTo);
}

/* Getter for GList* LassoLibRequestAuthnContext.AuthnContextClassRef */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRequestAuthnContext_1authnContextClassRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibRequestAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_strings(env, gobj->AuthnContextClassRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibRequestAuthnContext.AuthnContextClassRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRequestAuthnContext_1authnContextClassRef_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibRequestAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_strings(env, &gobj->AuthnContextClassRef,value);
}
/* Adder for GList*<strings> LassoLibRequestAuthnContext.AuthnContextClassRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRequestAuthnContext_1authnContextClassRef_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibRequestAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_strings(env, &gobj->AuthnContextClassRef, value);
}
/* Remover for GList*<strings> LassoLibRequestAuthnContext.AuthnContextClassRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRequestAuthnContext_1authnContextClassRef_1remove(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibRequestAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_strings(env, &gobj->AuthnContextClassRef,value);
}


/* Getter for GList* LassoLibRequestAuthnContext.AuthnContextStatementRef */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRequestAuthnContext_1authnContextStatementRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibRequestAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_strings(env, gobj->AuthnContextStatementRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibRequestAuthnContext.AuthnContextStatementRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRequestAuthnContext_1authnContextStatementRef_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibRequestAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_strings(env, &gobj->AuthnContextStatementRef,value);
}
/* Adder for GList*<strings> LassoLibRequestAuthnContext.AuthnContextStatementRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRequestAuthnContext_1authnContextStatementRef_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibRequestAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_strings(env, &gobj->AuthnContextStatementRef, value);
}
/* Remover for GList*<strings> LassoLibRequestAuthnContext.AuthnContextStatementRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRequestAuthnContext_1authnContextStatementRef_1remove(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibRequestAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_strings(env, &gobj->AuthnContextStatementRef,value);
}


/* Getter for char* LassoLibRequestAuthnContext.AuthnContextComparison */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRequestAuthnContext_1authnContextComparison_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibRequestAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AuthnContextComparison, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibRequestAuthnContext.AuthnContextComparison */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRequestAuthnContext_1authnContextComparison_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibRequestAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AuthnContextComparison);
}

/* Getter for char* LassoSamlAttributeDesignator.AttributeName */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeDesignator_1attributeName_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAttributeDesignator *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AttributeName, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAttributeDesignator.AttributeName */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeDesignator_1attributeName_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAttributeDesignator *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AttributeName);
}

/* Getter for char* LassoSamlAttributeDesignator.AttributeNamespace */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeDesignator_1attributeNamespace_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAttributeDesignator *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AttributeNamespace, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAttributeDesignator.AttributeNamespace */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeDesignator_1attributeNamespace_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAttributeDesignator *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AttributeNamespace);
}

/* Getter for gchar* LassoSamlAttribute.attributeName */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttribute_1attributeName_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAttribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->attributeName, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoSamlAttribute.attributeName */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttribute_1attributeName_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAttribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->attributeName);
}

/* Getter for gchar* LassoSamlAttribute.attributeNameSpace */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttribute_1attributeNameSpace_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAttribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->attributeNameSpace, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoSamlAttribute.attributeNameSpace */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttribute_1attributeNameSpace_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAttribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->attributeNameSpace);
}

/* Getter for GList* LassoSamlAttribute.AttributeValue */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttribute_1attributeValue_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAttribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AttributeValue, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlAttribute.AttributeValue */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttribute_1attributeValue_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlAttribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AttributeValue, value);
}
/* Adder for GList*<LassoNode> LassoSamlAttribute.AttributeValue */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttribute_1attributeValue_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAttribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AttributeValue, value);
}
/* Remover for GList*<LassoNode> LassoSamlAttribute.AttributeValue */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttribute_1attributeValue_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAttribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AttributeValue,value);
}


/* Getter for LassoSamlNameIdentifier* LassoSamlSubject.NameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubject_1nameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlSubject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlNameIdentifier* LassoSamlSubject.NameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubject_1nameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlSubject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameIdentifier);
}

/* Getter for LassoSamlSubjectConfirmation* LassoSamlSubject.SubjectConfirmation */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubject_1subjectConfirmation_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlSubject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->SubjectConfirmation, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlSubjectConfirmation* LassoSamlSubject.SubjectConfirmation */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubject_1subjectConfirmation_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlSubject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->SubjectConfirmation);
}

/* Getter for LassoSaml2EncryptedElement* LassoSamlSubject.EncryptedNameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubject_1encryptedNameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlSubject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->EncryptedNameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2EncryptedElement* LassoSamlSubject.EncryptedNameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubject_1encryptedNameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlSubject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->EncryptedNameIdentifier);
}

/* Getter for LassoSamlNameIdentifier* LassoLibSubject.IDPProvidedNameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibSubject_1iDPProvidedNameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibSubject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->IDPProvidedNameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlNameIdentifier* LassoLibSubject.IDPProvidedNameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibSubject_1iDPProvidedNameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibSubject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->IDPProvidedNameIdentifier);
}

/* Getter for GList* LassoLibAuthnResponseEnvelope.Extension */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponseEnvelope_1extension_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnResponseEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->Extension, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibAuthnResponseEnvelope.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponseEnvelope_1extension_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibAuthnResponseEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->Extension, value);
}
/* Adder for GList*<xmlNode> LassoLibAuthnResponseEnvelope.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponseEnvelope_1extension_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnResponseEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->Extension, value);
}

/* Getter for LassoLibAuthnResponse* LassoLibAuthnResponseEnvelope.AuthnResponse */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponseEnvelope_1authnResponse_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnResponseEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->AuthnResponse, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLibAuthnResponse* LassoLibAuthnResponseEnvelope.AuthnResponse */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponseEnvelope_1authnResponse_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibAuthnResponseEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->AuthnResponse);
}

/* Getter for char* LassoLibAuthnResponseEnvelope.AssertionConsumerServiceURL */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponseEnvelope_1assertionConsumerServiceURL_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnResponseEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AssertionConsumerServiceURL, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnResponseEnvelope.AssertionConsumerServiceURL */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponseEnvelope_1assertionConsumerServiceURL_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnResponseEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AssertionConsumerServiceURL);
}

/* Getter for char* LassoSamlAuthorityBinding.AuthorityKind */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthorityBinding_1authorityKind_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAuthorityBinding *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AuthorityKind, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAuthorityBinding.AuthorityKind */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthorityBinding_1authorityKind_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAuthorityBinding *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AuthorityKind);
}

/* Getter for char* LassoSamlAuthorityBinding.Location */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthorityBinding_1location_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAuthorityBinding *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Location, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAuthorityBinding.Location */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthorityBinding_1location_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAuthorityBinding *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Location);
}

/* Getter for char* LassoSamlAuthorityBinding.Binding */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthorityBinding_1binding_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAuthorityBinding *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Binding, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlAuthorityBinding.Binding */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAuthorityBinding_1binding_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAuthorityBinding *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Binding);
}

/* Getter for GList* LassoLibNameIdentifierMappingResponse.Extension */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingResponse_1extension_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibNameIdentifierMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->Extension, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibNameIdentifierMappingResponse.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingResponse_1extension_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibNameIdentifierMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->Extension, value);
}
/* Adder for GList*<xmlNode> LassoLibNameIdentifierMappingResponse.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingResponse_1extension_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibNameIdentifierMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->Extension, value);
}

/* Getter for char* LassoLibNameIdentifierMappingResponse.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingResponse_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibNameIdentifierMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibNameIdentifierMappingResponse.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingResponse_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibNameIdentifierMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for LassoSamlpStatus* LassoLibNameIdentifierMappingResponse.Status */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingResponse_1status_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibNameIdentifierMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Status, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlpStatus* LassoLibNameIdentifierMappingResponse.Status */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingResponse_1status_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibNameIdentifierMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Status);
}

/* Getter for LassoSamlNameIdentifier* LassoLibNameIdentifierMappingResponse.NameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingResponse_1nameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibNameIdentifierMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlNameIdentifier* LassoLibNameIdentifierMappingResponse.NameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingResponse_1nameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibNameIdentifierMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameIdentifier);
}

/* Getter for LassoLibIDPEntries* LassoLibIDPList.IDPEntries */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPList_1iDPEntries_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibIDPList *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->IDPEntries, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLibIDPEntries* LassoLibIDPList.IDPEntries */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPList_1iDPEntries_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibIDPList *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->IDPEntries);
}

/* Getter for char* LassoLibIDPList.GetComplete */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPList_1getComplete_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibIDPList *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->GetComplete, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibIDPList.GetComplete */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPList_1getComplete_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibIDPList *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->GetComplete);
}

/* Getter for LassoLibAuthnContext* LassoLibAuthenticationStatement.AuthnContext */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthenticationStatement_1authnContext_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->AuthnContext, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLibAuthnContext* LassoLibAuthenticationStatement.AuthnContext */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthenticationStatement_1authnContext_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->AuthnContext);
}

/* Getter for char* LassoLibAuthenticationStatement.ReauthenticateOnOrAfter */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthenticationStatement_1reauthenticateOnOrAfter_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ReauthenticateOnOrAfter, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthenticationStatement.ReauthenticateOnOrAfter */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthenticationStatement_1reauthenticateOnOrAfter_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ReauthenticateOnOrAfter);
}

/* Getter for char* LassoLibAuthenticationStatement.SessionIndex */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthenticationStatement_1sessionIndex_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SessionIndex, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthenticationStatement.SessionIndex */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthenticationStatement_1sessionIndex_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthenticationStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SessionIndex);
}

/* Getter for GList* LassoSamlAttributeStatement.Attribute */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeStatement_1attribute_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Attribute, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlAttributeStatement.Attribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeStatement_1attribute_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlAttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Attribute, value);
}
/* Adder for GList*<LassoNode> LassoSamlAttributeStatement.Attribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeStatement_1attribute_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Attribute, value);
}
/* Remover for GList*<LassoNode> LassoSamlAttributeStatement.Attribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAttributeStatement_1attribute_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlAttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Attribute,value);
}


/* Getter for char* LassoLibIDPEntry.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPEntry_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibIDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibIDPEntry.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPEntry_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibIDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for char* LassoLibIDPEntry.ProviderName */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPEntry_1providerName_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibIDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderName, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibIDPEntry.ProviderName */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPEntry_1providerName_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibIDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderName);
}

/* Getter for char* LassoLibIDPEntry.Loc */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPEntry_1loc_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibIDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Loc, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibIDPEntry.Loc */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPEntry_1loc_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibIDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Loc);
}

/* Getter for GList* LassoSamlAudienceRestrictionCondition.Audience */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAudienceRestrictionCondition_1audience_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlAudienceRestrictionCondition *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_strings(env, gobj->Audience, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlAudienceRestrictionCondition.Audience */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAudienceRestrictionCondition_1audience_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlAudienceRestrictionCondition *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_strings(env, &gobj->Audience,value);
}
/* Adder for GList*<strings> LassoSamlAudienceRestrictionCondition.Audience */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAudienceRestrictionCondition_1audience_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAudienceRestrictionCondition *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_strings(env, &gobj->Audience, value);
}
/* Remover for GList*<strings> LassoSamlAudienceRestrictionCondition.Audience */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlAudienceRestrictionCondition_1audience_1remove(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlAudienceRestrictionCondition *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_strings(env, &gobj->Audience,value);
}


/* Getter for GList* LassoLibIDPEntries.IDPEntry */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPEntries_1iDPEntry_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibIDPEntries *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->IDPEntry, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibIDPEntries.IDPEntry */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPEntries_1iDPEntry_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibIDPEntries *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->IDPEntry, value);
}
/* Adder for GList*<LassoLibIDPEntry> LassoLibIDPEntries.IDPEntry */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPEntries_1iDPEntry_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibIDPEntries *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->IDPEntry, value);
}
/* Remover for GList*<LassoLibIDPEntry> LassoLibIDPEntries.IDPEntry */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibIDPEntries_1iDPEntry_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibIDPEntries *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->IDPEntry,value);
}


/* Getter for int LassoLibScoping.ProxyCount */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_LibScoping_1proxyCount_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibScoping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->ProxyCount;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for int LassoLibScoping.ProxyCount */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibScoping_1proxyCount_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoLibScoping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->ProxyCount = (int)value;
}

/* Getter for LassoLibIDPList* LassoLibScoping.IDPList */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibScoping_1iDPList_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibScoping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->IDPList, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLibIDPList* LassoLibScoping.IDPList */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibScoping_1iDPList_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibScoping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->IDPList);
}

/* Getter for char* LassoSamlSubjectLocality.IPAddress */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectLocality_1iPAddress_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlSubjectLocality *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->IPAddress, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlSubjectLocality.IPAddress */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectLocality_1iPAddress_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlSubjectLocality *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->IPAddress);
}

/* Getter for char* LassoSamlSubjectLocality.DNSAddress */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectLocality_1dNSAddress_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlSubjectLocality *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->DNSAddress, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlSubjectLocality.DNSAddress */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlSubjectLocality_1dNSAddress_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlSubjectLocality *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->DNSAddress);
}

/* Getter for GList* LassoSamlpRequestAbstract.RespondWith */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1respondWith_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_strings(env, gobj->RespondWith, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlpRequestAbstract.RespondWith */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1respondWith_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_strings(env, &gobj->RespondWith,value);
}
/* Adder for GList*<strings> LassoSamlpRequestAbstract.RespondWith */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1respondWith_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_strings(env, &gobj->RespondWith, value);
}
/* Remover for GList*<strings> LassoSamlpRequestAbstract.RespondWith */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1respondWith_1remove(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_strings(env, &gobj->RespondWith,value);
}


/* Getter for char* LassoSamlpRequestAbstract.RequestID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1requestId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->RequestID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpRequestAbstract.RequestID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1requestId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->RequestID);
}

/* Getter for int LassoSamlpRequestAbstract.MajorVersion */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1majorVersion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->MajorVersion;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for int LassoSamlpRequestAbstract.MajorVersion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1majorVersion_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->MajorVersion = (int)value;
}

/* Getter for int LassoSamlpRequestAbstract.MinorVersion */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1minorVersion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->MinorVersion;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for int LassoSamlpRequestAbstract.MinorVersion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1minorVersion_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->MinorVersion = (int)value;
}

/* Getter for char* LassoSamlpRequestAbstract.IssueInstant */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1issueInstant_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->IssueInstant, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpRequestAbstract.IssueInstant */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1issueInstant_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->IssueInstant);
}

/* Getter for LassoSignatureType LassoSamlpRequestAbstract.sign_type */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1signType_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->sign_type;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSignatureType LassoSamlpRequestAbstract.sign_type */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1signType_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->sign_type = (LassoSignatureType)value;
}

/* Getter for LassoSignatureMethod LassoSamlpRequestAbstract.sign_method */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1signMethod_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->sign_method;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSignatureMethod LassoSamlpRequestAbstract.sign_method */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1signMethod_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->sign_method = (LassoSignatureMethod)value;
}

/* Getter for char* LassoSamlpRequestAbstract.private_key_file */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1privateKeyFile_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->private_key_file, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpRequestAbstract.private_key_file */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1privateKeyFile_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->private_key_file);
}

/* Getter for char* LassoSamlpRequestAbstract.certificate_file */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1certificateFile_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->certificate_file, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpRequestAbstract.certificate_file */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequestAbstract_1certificateFile_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpRequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->certificate_file);
}

/* Getter for GList* LassoLibAuthnRequest.Extension */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1extension_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->Extension, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibAuthnRequest.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1extension_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->Extension, value);
}
/* Adder for GList*<xmlNode> LassoLibAuthnRequest.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1extension_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->Extension, value);
}

/* Getter for char* LassoLibAuthnRequest.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnRequest.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for char* LassoLibAuthnRequest.AffiliationID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1affiliationId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AffiliationID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnRequest.AffiliationID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1affiliationId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AffiliationID);
}

/* Getter for char* LassoLibAuthnRequest.NameIDPolicy */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1nameIdPolicy_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NameIDPolicy, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnRequest.NameIDPolicy */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1nameIdPolicy_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NameIDPolicy);
}

/* Getter for gboolean LassoLibAuthnRequest.ForceAuthn */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1forceAuthn_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->ForceAuthn;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoLibAuthnRequest.ForceAuthn */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1forceAuthn_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->ForceAuthn = (gboolean)value;
}

/* Getter for gboolean LassoLibAuthnRequest.IsPassive */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1isPassive_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->IsPassive;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoLibAuthnRequest.IsPassive */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1isPassive_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->IsPassive = (gboolean)value;
}

/* Getter for char* LassoLibAuthnRequest.ProtocolProfile */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1protocolProfile_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProtocolProfile, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnRequest.ProtocolProfile */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1protocolProfile_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProtocolProfile);
}

/* Getter for char* LassoLibAuthnRequest.AssertionConsumerServiceID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1assertionConsumerServiceId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AssertionConsumerServiceID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnRequest.AssertionConsumerServiceID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1assertionConsumerServiceId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AssertionConsumerServiceID);
}

/* Getter for LassoLibRequestAuthnContext* LassoLibAuthnRequest.RequestAuthnContext */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1requestAuthnContext_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->RequestAuthnContext, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLibRequestAuthnContext* LassoLibAuthnRequest.RequestAuthnContext */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1requestAuthnContext_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->RequestAuthnContext);
}

/* Getter for char* LassoLibAuthnRequest.RelayState */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1relayState_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->RelayState, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnRequest.RelayState */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1relayState_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->RelayState);
}

/* Getter for LassoLibScoping* LassoLibAuthnRequest.Scoping */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1scoping_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Scoping, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLibScoping* LassoLibAuthnRequest.Scoping */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1scoping_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Scoping);
}

/* Getter for char* LassoLibAuthnRequest.consent */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1consent_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->consent, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnRequest.consent */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnRequest_1consent_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->consent);
}

/* Getter for GList* LassoLibRegisterNameIdentifierRequest.Extension */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1extension_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->Extension, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibRegisterNameIdentifierRequest.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1extension_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->Extension, value);
}
/* Adder for GList*<xmlNode> LassoLibRegisterNameIdentifierRequest.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1extension_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->Extension, value);
}

/* Getter for char* LassoLibRegisterNameIdentifierRequest.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibRegisterNameIdentifierRequest.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for LassoSamlNameIdentifier* LassoLibRegisterNameIdentifierRequest.IDPProvidedNameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1iDPProvidedNameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->IDPProvidedNameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlNameIdentifier* LassoLibRegisterNameIdentifierRequest.IDPProvidedNameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1iDPProvidedNameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->IDPProvidedNameIdentifier);
}

/* Getter for LassoSamlNameIdentifier* LassoLibRegisterNameIdentifierRequest.SPProvidedNameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1sPProvidedNameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->SPProvidedNameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlNameIdentifier* LassoLibRegisterNameIdentifierRequest.SPProvidedNameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1sPProvidedNameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->SPProvidedNameIdentifier);
}

/* Getter for LassoSamlNameIdentifier* LassoLibRegisterNameIdentifierRequest.OldProvidedNameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1oldProvidedNameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->OldProvidedNameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlNameIdentifier* LassoLibRegisterNameIdentifierRequest.OldProvidedNameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1oldProvidedNameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->OldProvidedNameIdentifier);
}

/* Getter for char* LassoLibRegisterNameIdentifierRequest.RelayState */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1relayState_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->RelayState, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibRegisterNameIdentifierRequest.RelayState */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibRegisterNameIdentifierRequest_1relayState_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibRegisterNameIdentifierRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->RelayState);
}

/* Getter for GList* LassoLibFederationTerminationNotification.Extension */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1extension_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->Extension, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibFederationTerminationNotification.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1extension_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->Extension, value);
}
/* Adder for GList*<xmlNode> LassoLibFederationTerminationNotification.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1extension_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->Extension, value);
}

/* Getter for char* LassoLibFederationTerminationNotification.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibFederationTerminationNotification.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for LassoSamlNameIdentifier* LassoLibFederationTerminationNotification.NameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1nameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlNameIdentifier* LassoLibFederationTerminationNotification.NameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1nameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameIdentifier);
}

/* Getter for char* LassoLibFederationTerminationNotification.consent */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1consent_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->consent, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibFederationTerminationNotification.consent */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1consent_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->consent);
}

/* Getter for char* LassoLibFederationTerminationNotification.RelayState */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1relayState_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->RelayState, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibFederationTerminationNotification.RelayState */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibFederationTerminationNotification_1relayState_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibFederationTerminationNotification *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->RelayState);
}

/* Getter for char* LassoSamlpRequest.AssertionArtifact */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequest_1assertionArtifact_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AssertionArtifact, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpRequest.AssertionArtifact */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpRequest_1assertionArtifact_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AssertionArtifact);
}

/* Getter for GList* LassoLibLogoutRequest.Extension */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1extension_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->Extension, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibLogoutRequest.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1extension_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->Extension, value);
}
/* Adder for GList*<xmlNode> LassoLibLogoutRequest.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1extension_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->Extension, value);
}

/* Getter for char* LassoLibLogoutRequest.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibLogoutRequest.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for LassoSamlNameIdentifier* LassoLibLogoutRequest.NameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1nameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlNameIdentifier* LassoLibLogoutRequest.NameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1nameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameIdentifier);
}

/* Getter for char* LassoLibLogoutRequest.SessionIndex */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1sessionIndex_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SessionIndex, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibLogoutRequest.SessionIndex */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1sessionIndex_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SessionIndex);
}

/* Getter for char* LassoLibLogoutRequest.RelayState */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1relayState_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->RelayState, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibLogoutRequest.RelayState */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1relayState_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->RelayState);
}

/* Getter for char* LassoLibLogoutRequest.consent */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1consent_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->consent, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibLogoutRequest.consent */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1consent_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->consent);
}

/* Getter for char* LassoLibLogoutRequest.NotOnOrAfter */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1notOnOrAfter_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NotOnOrAfter, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibLogoutRequest.NotOnOrAfter */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibLogoutRequest_1notOnOrAfter_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibLogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NotOnOrAfter);
}

/* Getter for GList* LassoLibNameIdentifierMappingRequest.Extension */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1extension_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->Extension, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibNameIdentifierMappingRequest.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1extension_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->Extension, value);
}
/* Adder for GList*<xmlNode> LassoLibNameIdentifierMappingRequest.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1extension_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->Extension, value);
}

/* Getter for char* LassoLibNameIdentifierMappingRequest.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibNameIdentifierMappingRequest.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for LassoSamlNameIdentifier* LassoLibNameIdentifierMappingRequest.NameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1nameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlNameIdentifier* LassoLibNameIdentifierMappingRequest.NameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1nameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameIdentifier);
}

/* Getter for char* LassoLibNameIdentifierMappingRequest.TargetNamespace */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1targetNamespace_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->TargetNamespace, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibNameIdentifierMappingRequest.TargetNamespace */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1targetNamespace_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->TargetNamespace);
}

/* Getter for char* LassoLibNameIdentifierMappingRequest.consent */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1consent_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->consent, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibNameIdentifierMappingRequest.consent */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibNameIdentifierMappingRequest_1consent_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibNameIdentifierMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->consent);
}

/* Getter for LassoSamlpStatus* LassoSamlpResponse.Status */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponse_1status_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Status, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlpStatus* LassoSamlpResponse.Status */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponse_1status_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Status);
}

/* Getter for GList* LassoSamlpResponse.Assertion */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponse_1assertion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Assertion, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlpResponse.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponse_1assertion_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Assertion, value);
}
/* Adder for GList*<LassoSamlAssertion> LassoSamlpResponse.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponse_1assertion_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Assertion, value);
}
/* Remover for GList*<LassoSamlAssertion> LassoSamlpResponse.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpResponse_1assertion_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Assertion,value);
}


/* Getter for GList* LassoLibAuthnResponse.Extension */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponse_1extension_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->Extension, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoLibAuthnResponse.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponse_1extension_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoLibAuthnResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->Extension, value);
}
/* Adder for GList*<xmlNode> LassoLibAuthnResponse.Extension */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponse_1extension_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->Extension, value);
}

/* Getter for char* LassoLibAuthnResponse.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponse_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnResponse.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponse_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for char* LassoLibAuthnResponse.RelayState */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponse_1relayState_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->RelayState, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnResponse.RelayState */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponse_1relayState_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->RelayState);
}

/* Getter for char* LassoLibAuthnResponse.consent */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponse_1consent_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLibAuthnResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->consent, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLibAuthnResponse.consent */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_LibAuthnResponse_1consent_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLibAuthnResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->consent);
}

/* Getter for LassoSamlpStatusCode* LassoSamlpStatus.StatusCode */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpStatus_1statusCode_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpStatus *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->StatusCode, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlpStatusCode* LassoSamlpStatus.StatusCode */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpStatus_1statusCode_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlpStatus *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->StatusCode);
}

/* Getter for char* LassoSamlpStatus.StatusMessage */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpStatus_1statusMessage_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlpStatus *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->StatusMessage, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlpStatus.StatusMessage */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SamlpStatus_1statusMessage_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlpStatus *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->StatusMessage);
}

/* Getter for char* LassoSamlp2NameIDPolicy.Format */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDPolicy_1format_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2NameIDPolicy *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Format, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2NameIDPolicy.Format */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDPolicy_1format_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2NameIDPolicy *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Format);
}

/* Getter for char* LassoSamlp2NameIDPolicy.SPNameQualifier */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDPolicy_1sPNameQualifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2NameIDPolicy *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SPNameQualifier, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2NameIDPolicy.SPNameQualifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDPolicy_1sPNameQualifier_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2NameIDPolicy *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SPNameQualifier);
}

/* Getter for gboolean LassoSamlp2NameIDPolicy.AllowCreate */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDPolicy_1allowCreate_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2NameIDPolicy *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->AllowCreate;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoSamlp2NameIDPolicy.AllowCreate */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDPolicy_1allowCreate_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoSamlp2NameIDPolicy *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->AllowCreate = (gboolean)value;
}

/* Getter for char* LassoSaml2NameID.content */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2NameID_1content_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2NameID *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->content, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2NameID.content */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2NameID_1content_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2NameID *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->content);
}

/* Getter for char* LassoSaml2NameID.Format */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2NameID_1format_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2NameID *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Format, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2NameID.Format */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2NameID_1format_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2NameID *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Format);
}

/* Getter for char* LassoSaml2NameID.SPProvidedID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2NameID_1sPProvidedId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2NameID *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SPProvidedID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2NameID.SPProvidedID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2NameID_1sPProvidedId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2NameID *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SPProvidedID);
}

/* Getter for char* LassoSaml2NameID.NameQualifier */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2NameID_1nameQualifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2NameID *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NameQualifier, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2NameID.NameQualifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2NameID_1nameQualifier_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2NameID *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NameQualifier);
}

/* Getter for char* LassoSaml2NameID.SPNameQualifier */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2NameID_1sPNameQualifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2NameID *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SPNameQualifier, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2NameID.SPNameQualifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2NameID_1sPNameQualifier_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2NameID *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SPNameQualifier);
}

/* Getter for GList* LassoSamlp2RequestedAuthnContext.AuthnContextClassRef */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestedAuthnContext_1authnContextClassRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2RequestedAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_strings(env, gobj->AuthnContextClassRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlp2RequestedAuthnContext.AuthnContextClassRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestedAuthnContext_1authnContextClassRef_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlp2RequestedAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_strings(env, &gobj->AuthnContextClassRef,value);
}
/* Adder for GList*<strings> LassoSamlp2RequestedAuthnContext.AuthnContextClassRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestedAuthnContext_1authnContextClassRef_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2RequestedAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_strings(env, &gobj->AuthnContextClassRef, value);
}
/* Remover for GList*<strings> LassoSamlp2RequestedAuthnContext.AuthnContextClassRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestedAuthnContext_1authnContextClassRef_1remove(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2RequestedAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_strings(env, &gobj->AuthnContextClassRef,value);
}


/* Getter for GList* LassoSamlp2RequestedAuthnContext.AuthnContextDeclRef */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestedAuthnContext_1authnContextDeclRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2RequestedAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_strings(env, gobj->AuthnContextDeclRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlp2RequestedAuthnContext.AuthnContextDeclRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestedAuthnContext_1authnContextDeclRef_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlp2RequestedAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_strings(env, &gobj->AuthnContextDeclRef,value);
}
/* Adder for GList*<strings> LassoSamlp2RequestedAuthnContext.AuthnContextDeclRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestedAuthnContext_1authnContextDeclRef_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2RequestedAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_strings(env, &gobj->AuthnContextDeclRef, value);
}
/* Remover for GList*<strings> LassoSamlp2RequestedAuthnContext.AuthnContextDeclRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestedAuthnContext_1authnContextDeclRef_1remove(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2RequestedAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_strings(env, &gobj->AuthnContextDeclRef,value);
}


/* Getter for char* LassoSamlp2RequestedAuthnContext.Comparison */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestedAuthnContext_1comparison_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2RequestedAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Comparison, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2RequestedAuthnContext.Comparison */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestedAuthnContext_1comparison_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2RequestedAuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Comparison);
}

/* Getter for char* LassoSaml2SubjectLocality.Address */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectLocality_1address_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectLocality *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Address, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2SubjectLocality.Address */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectLocality_1address_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2SubjectLocality *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Address);
}

/* Getter for char* LassoSaml2SubjectLocality.DNSName */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectLocality_1dNSName_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectLocality *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->DNSName, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2SubjectLocality.DNSName */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectLocality_1dNSName_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2SubjectLocality *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->DNSName);
}

/* Getter for char* LassoSaml2BaseIDAbstract.NameQualifier */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2BaseIDAbstract_1nameQualifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2BaseIDAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NameQualifier, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2BaseIDAbstract.NameQualifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2BaseIDAbstract_1nameQualifier_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2BaseIDAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NameQualifier);
}

/* Getter for char* LassoSaml2BaseIDAbstract.SPNameQualifier */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2BaseIDAbstract_1sPNameQualifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2BaseIDAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SPNameQualifier, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2BaseIDAbstract.SPNameQualifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2BaseIDAbstract_1sPNameQualifier_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2BaseIDAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SPNameQualifier);
}

/* Getter for char* LassoSaml2AudienceRestriction.Audience */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AudienceRestriction_1audience_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AudienceRestriction *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Audience, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2AudienceRestriction.Audience */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AudienceRestriction_1audience_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2AudienceRestriction *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Audience);
}

/* Getter for GList* LassoSaml2AttributeValue.any */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeValue_1any_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AttributeValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->any, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2AttributeValue.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeValue_1any_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2AttributeValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->any, value);
}
/* Adder for GList*<LassoNode> LassoSaml2AttributeValue.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeValue_1any_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2AttributeValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->any, value);
}
/* Remover for GList*<LassoNode> LassoSaml2AttributeValue.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeValue_1any_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2AttributeValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->any,value);
}


/* Getter for LassoSaml2NameID* LassoSaml2Assertion.Issuer */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1issuer_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Issuer, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoSaml2Assertion.Issuer */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1issuer_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Issuer);
}

/* Getter for LassoSaml2Subject* LassoSaml2Assertion.Subject */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1subject_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Subject, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2Subject* LassoSaml2Assertion.Subject */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1subject_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Subject);
}

/* Getter for LassoSaml2Conditions* LassoSaml2Assertion.Conditions */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1conditions_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Conditions, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2Conditions* LassoSaml2Assertion.Conditions */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1conditions_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Conditions);
}

/* Getter for LassoSaml2Advice* LassoSaml2Assertion.Advice */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1advice_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Advice, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2Advice* LassoSaml2Assertion.Advice */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1advice_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Advice);
}

/* Getter for GList* LassoSaml2Assertion.Statement */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1statement_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Statement, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Assertion.Statement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1statement_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Statement, value);
}
/* Adder for GList*<LassoSaml2StatementAbstract> LassoSaml2Assertion.Statement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1statement_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Statement, value);
}
/* Remover for GList*<LassoSaml2StatementAbstract> LassoSaml2Assertion.Statement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1statement_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Statement,value);
}


/* Getter for GList* LassoSaml2Assertion.AuthnStatement */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1authnStatement_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AuthnStatement, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Assertion.AuthnStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1authnStatement_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AuthnStatement, value);
}
/* Adder for GList*<LassoSaml2AuthnStatement> LassoSaml2Assertion.AuthnStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1authnStatement_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AuthnStatement, value);
}
/* Remover for GList*<LassoSaml2AuthnStatement> LassoSaml2Assertion.AuthnStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1authnStatement_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AuthnStatement,value);
}


/* Getter for GList* LassoSaml2Assertion.AuthzDecisionStatement */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1authzDecisionStatement_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AuthzDecisionStatement, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Assertion.AuthzDecisionStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1authzDecisionStatement_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AuthzDecisionStatement, value);
}
/* Adder for GList*<LassoSaml2AuthzDecisionStatement> LassoSaml2Assertion.AuthzDecisionStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1authzDecisionStatement_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AuthzDecisionStatement, value);
}
/* Remover for GList*<LassoSaml2AuthzDecisionStatement> LassoSaml2Assertion.AuthzDecisionStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1authzDecisionStatement_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AuthzDecisionStatement,value);
}


/* Getter for GList* LassoSaml2Assertion.AttributeStatement */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1attributeStatement_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AttributeStatement, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Assertion.AttributeStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1attributeStatement_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AttributeStatement, value);
}
/* Adder for GList*<LassoSaml2AttributeStatement> LassoSaml2Assertion.AttributeStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1attributeStatement_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AttributeStatement, value);
}
/* Remover for GList*<LassoSaml2AttributeStatement> LassoSaml2Assertion.AttributeStatement */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1attributeStatement_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AttributeStatement,value);
}


/* Getter for char* LassoSaml2Assertion.Version */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1version_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Version, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2Assertion.Version */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1version_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Version);
}

/* Getter for char* LassoSaml2Assertion.ID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1iD_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2Assertion.ID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1iD_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ID);
}

/* Getter for char* LassoSaml2Assertion.IssueInstant */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1issueInstant_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->IssueInstant, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2Assertion.IssueInstant */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Assertion_1issueInstant_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2Assertion *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->IssueInstant);
}

/* Getter for LassoSaml2BaseIDAbstract* LassoSaml2Subject.BaseID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Subject_1baseId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Subject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->BaseID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2BaseIDAbstract* LassoSaml2Subject.BaseID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Subject_1baseId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Subject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->BaseID);
}

/* Getter for LassoSaml2NameID* LassoSaml2Subject.NameID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Subject_1nameId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Subject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoSaml2Subject.NameID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Subject_1nameId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Subject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameID);
}

/* Getter for LassoSaml2EncryptedElement* LassoSaml2Subject.EncryptedID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Subject_1encryptedId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Subject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->EncryptedID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2EncryptedElement* LassoSaml2Subject.EncryptedID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Subject_1encryptedId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Subject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->EncryptedID);
}

/* Getter for LassoSaml2SubjectConfirmation* LassoSaml2Subject.SubjectConfirmation */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Subject_1subjectConfirmation_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Subject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->SubjectConfirmation, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2SubjectConfirmation* LassoSaml2Subject.SubjectConfirmation */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Subject_1subjectConfirmation_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Subject *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->SubjectConfirmation);
}

/* Getter for GList* LassoSaml2AttributeStatement.Attribute */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeStatement_1attribute_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Attribute, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2AttributeStatement.Attribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeStatement_1attribute_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2AttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Attribute, value);
}
/* Adder for GList*<LassoSaml2Attribute> LassoSaml2AttributeStatement.Attribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeStatement_1attribute_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2AttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Attribute, value);
}
/* Remover for GList*<LassoSaml2Attribute> LassoSaml2AttributeStatement.Attribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeStatement_1attribute_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2AttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Attribute,value);
}


/* Getter for GList* LassoSaml2AttributeStatement.EncryptedAttribute */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeStatement_1encryptedAttribute_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->EncryptedAttribute, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2AttributeStatement.EncryptedAttribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeStatement_1encryptedAttribute_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2AttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->EncryptedAttribute, value);
}
/* Adder for GList*<LassoSaml2EncryptedElement> LassoSaml2AttributeStatement.EncryptedAttribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeStatement_1encryptedAttribute_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2AttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->EncryptedAttribute, value);
}
/* Remover for GList*<LassoSaml2EncryptedElement> LassoSaml2AttributeStatement.EncryptedAttribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AttributeStatement_1encryptedAttribute_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2AttributeStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->EncryptedAttribute,value);
}


/* Getter for GList* LassoSaml2Advice.AssertionIDRef */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertionIdRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AssertionIDRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Advice.AssertionIDRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertionIdRef_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AssertionIDRef, value);
}
/* Adder for GList*<LassoNode> LassoSaml2Advice.AssertionIDRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertionIdRef_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AssertionIDRef, value);
}
/* Remover for GList*<LassoNode> LassoSaml2Advice.AssertionIDRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertionIdRef_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AssertionIDRef,value);
}


/* Getter for GList* LassoSaml2Advice.AssertionURIRef */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertionURIRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AssertionURIRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Advice.AssertionURIRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertionURIRef_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AssertionURIRef, value);
}
/* Adder for GList*<LassoNode> LassoSaml2Advice.AssertionURIRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertionURIRef_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AssertionURIRef, value);
}
/* Remover for GList*<LassoNode> LassoSaml2Advice.AssertionURIRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertionURIRef_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AssertionURIRef,value);
}


/* Getter for GList* LassoSaml2Advice.Assertion */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Assertion, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Advice.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertion_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Assertion, value);
}
/* Adder for GList*<LassoSaml2Assertion> LassoSaml2Advice.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertion_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Assertion, value);
}
/* Remover for GList*<LassoSaml2Assertion> LassoSaml2Advice.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1assertion_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Assertion,value);
}


/* Getter for GList* LassoSaml2Advice.EncryptedAssertion */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1encryptedAssertion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->EncryptedAssertion, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Advice.EncryptedAssertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1encryptedAssertion_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->EncryptedAssertion, value);
}
/* Adder for GList*<LassoSaml2EncryptedElement> LassoSaml2Advice.EncryptedAssertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1encryptedAssertion_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->EncryptedAssertion, value);
}
/* Remover for GList*<LassoSaml2EncryptedElement> LassoSaml2Advice.EncryptedAssertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Advice_1encryptedAssertion_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Advice *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->EncryptedAssertion,value);
}


/* Getter for LassoSamlp2StatusCode* LassoSamlp2Status.StatusCode */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Status_1statusCode_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2Status *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->StatusCode, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2StatusCode* LassoSamlp2Status.StatusCode */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Status_1statusCode_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2Status *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->StatusCode);
}

/* Getter for char* LassoSamlp2Status.StatusMessage */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Status_1statusMessage_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2Status *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->StatusMessage, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2Status.StatusMessage */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Status_1statusMessage_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2Status *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->StatusMessage);
}

/* Getter for LassoSamlp2StatusDetail* LassoSamlp2Status.StatusDetail */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Status_1statusDetail_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2Status *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->StatusDetail, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2StatusDetail* LassoSamlp2Status.StatusDetail */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Status_1statusDetail_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2Status *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->StatusDetail);
}

/* Getter for LassoSamlp2StatusCode* LassoSamlp2StatusCode.StatusCode */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusCode_1statusCode_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusCode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->StatusCode, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2StatusCode* LassoSamlp2StatusCode.StatusCode */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusCode_1statusCode_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2StatusCode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->StatusCode);
}

/* Getter for char* LassoSamlp2StatusCode.Value */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusCode_1value_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusCode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Value, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2StatusCode.Value */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusCode_1value_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2StatusCode *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Value);
}

/* Getter for xmlNode* LassoSaml2EncryptedElement.EncryptedData */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2EncryptedElement_1encryptedData_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2EncryptedElement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         xml_node_to_jstring(env, gobj->EncryptedData, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for xmlNode* LassoSaml2EncryptedElement.EncryptedData */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2EncryptedElement_1encryptedData_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2EncryptedElement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_xml_node(env, value, &gobj->EncryptedData);
}

/* Getter for GList* LassoSaml2EncryptedElement.EncryptedKey */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2EncryptedElement_1encryptedKey_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2EncryptedElement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_xml_nodes(env, gobj->EncryptedKey, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2EncryptedElement.EncryptedKey */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2EncryptedElement_1encryptedKey_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2EncryptedElement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_xml_nodes(env, &gobj->EncryptedKey, value);
}
/* Adder for GList*<xmlNode> LassoSaml2EncryptedElement.EncryptedKey */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2EncryptedElement_1encryptedKey_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2EncryptedElement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_xml_nodes(env, &gobj->EncryptedKey, value);
}

/* Getter for LassoNode* LassoSaml2EncryptedElement.original_data */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2EncryptedElement_1originalData_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2EncryptedElement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->original_data, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoNode* LassoSaml2EncryptedElement.original_data */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2EncryptedElement_1originalData_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2EncryptedElement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->original_data);
}

/* Getter for char* LassoSaml2Action.content */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Action_1content_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Action *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->content, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2Action.content */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Action_1content_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2Action *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->content);
}

/* Getter for char* LassoSaml2Action.Namespace */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Action_1namespace_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Action *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Namespace, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2Action.Namespace */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Action_1namespace_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2Action *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Namespace);
}

/* Getter for LassoSamlp2IDPList* LassoSamlp2Scoping.IDPList */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Scoping_1iDPList_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2Scoping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->IDPList, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2IDPList* LassoSamlp2Scoping.IDPList */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Scoping_1iDPList_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2Scoping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->IDPList);
}

/* Getter for char* LassoSamlp2Scoping.RequesterID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Scoping_1requesterId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2Scoping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->RequesterID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2Scoping.RequesterID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Scoping_1requesterId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2Scoping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->RequesterID);
}

/* Getter for char* LassoSamlp2Scoping.ProxyCount */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Scoping_1proxyCount_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2Scoping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProxyCount, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2Scoping.ProxyCount */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Scoping_1proxyCount_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2Scoping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProxyCount);
}

/* Getter for LassoSaml2NameID* LassoSamlp2RequestAbstract.Issuer */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1issuer_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Issuer, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoSamlp2RequestAbstract.Issuer */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1issuer_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Issuer);
}

/* Getter for LassoSamlp2Extensions* LassoSamlp2RequestAbstract.Extensions */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1extensions_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Extensions, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2Extensions* LassoSamlp2RequestAbstract.Extensions */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1extensions_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Extensions);
}

/* Getter for char* LassoSamlp2RequestAbstract.ID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1iD_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2RequestAbstract.ID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1iD_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ID);
}

/* Getter for char* LassoSamlp2RequestAbstract.Version */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1version_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Version, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2RequestAbstract.Version */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1version_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Version);
}

/* Getter for char* LassoSamlp2RequestAbstract.IssueInstant */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1issueInstant_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->IssueInstant, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2RequestAbstract.IssueInstant */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1issueInstant_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->IssueInstant);
}

/* Getter for char* LassoSamlp2RequestAbstract.Destination */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1destination_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Destination, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2RequestAbstract.Destination */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1destination_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Destination);
}

/* Getter for char* LassoSamlp2RequestAbstract.Consent */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1consent_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Consent, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2RequestAbstract.Consent */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2RequestAbstract_1consent_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2RequestAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Consent);
}

/* Getter for char* LassoSamlp2ArtifactResolve.Artifact */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ArtifactResolve_1artifact_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2ArtifactResolve *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Artifact, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2ArtifactResolve.Artifact */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ArtifactResolve_1artifact_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2ArtifactResolve *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Artifact);
}

/* Getter for LassoSaml2BaseIDAbstract* LassoSamlp2NameIDMappingRequest.BaseID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingRequest_1baseId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2NameIDMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->BaseID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2BaseIDAbstract* LassoSamlp2NameIDMappingRequest.BaseID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingRequest_1baseId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2NameIDMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->BaseID);
}

/* Getter for LassoSaml2NameID* LassoSamlp2NameIDMappingRequest.NameID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingRequest_1nameId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2NameIDMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoSamlp2NameIDMappingRequest.NameID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingRequest_1nameId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2NameIDMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameID);
}

/* Getter for LassoSaml2EncryptedElement* LassoSamlp2NameIDMappingRequest.EncryptedID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingRequest_1encryptedId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2NameIDMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->EncryptedID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2EncryptedElement* LassoSamlp2NameIDMappingRequest.EncryptedID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingRequest_1encryptedId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2NameIDMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->EncryptedID);
}

/* Getter for LassoSamlp2NameIDPolicy* LassoSamlp2NameIDMappingRequest.NameIDPolicy */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingRequest_1nameIdPolicy_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2NameIDMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameIDPolicy, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2NameIDPolicy* LassoSamlp2NameIDMappingRequest.NameIDPolicy */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingRequest_1nameIdPolicy_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2NameIDMappingRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameIDPolicy);
}

/* Getter for LassoSaml2NameID* LassoSamlp2ManageNameIDRequest.NameID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ManageNameIDRequest_1nameId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2ManageNameIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoSamlp2ManageNameIDRequest.NameID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ManageNameIDRequest_1nameId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2ManageNameIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameID);
}

/* Getter for LassoSaml2EncryptedElement* LassoSamlp2ManageNameIDRequest.EncryptedID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ManageNameIDRequest_1encryptedId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2ManageNameIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->EncryptedID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2EncryptedElement* LassoSamlp2ManageNameIDRequest.EncryptedID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ManageNameIDRequest_1encryptedId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2ManageNameIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->EncryptedID);
}

/* Getter for char* LassoSamlp2ManageNameIDRequest.NewID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ManageNameIDRequest_1newId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2ManageNameIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NewID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2ManageNameIDRequest.NewID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ManageNameIDRequest_1newId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2ManageNameIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NewID);
}

/* Getter for LassoSaml2EncryptedElement* LassoSamlp2ManageNameIDRequest.NewEncryptedID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ManageNameIDRequest_1newEncryptedId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2ManageNameIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NewEncryptedID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2EncryptedElement* LassoSamlp2ManageNameIDRequest.NewEncryptedID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ManageNameIDRequest_1newEncryptedId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2ManageNameIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NewEncryptedID);
}

/* Getter for LassoSamlp2Terminate* LassoSamlp2ManageNameIDRequest.Terminate */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ManageNameIDRequest_1terminate_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2ManageNameIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Terminate, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2Terminate* LassoSamlp2ManageNameIDRequest.Terminate */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ManageNameIDRequest_1terminate_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2ManageNameIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Terminate);
}

/* Getter for GList* LassoSaml2Conditions.Condition */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1condition_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Condition, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Conditions.Condition */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1condition_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Condition, value);
}
/* Adder for GList*<LassoSaml2ConditionAbstract> LassoSaml2Conditions.Condition */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1condition_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Condition, value);
}
/* Remover for GList*<LassoSaml2ConditionAbstract> LassoSaml2Conditions.Condition */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1condition_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Condition,value);
}


/* Getter for GList* LassoSaml2Conditions.AudienceRestriction */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1audienceRestriction_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AudienceRestriction, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Conditions.AudienceRestriction */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1audienceRestriction_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AudienceRestriction, value);
}
/* Adder for GList*<LassoSaml2AudienceRestriction> LassoSaml2Conditions.AudienceRestriction */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1audienceRestriction_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AudienceRestriction, value);
}
/* Remover for GList*<LassoSaml2AudienceRestriction> LassoSaml2Conditions.AudienceRestriction */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1audienceRestriction_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AudienceRestriction,value);
}


/* Getter for GList* LassoSaml2Conditions.OneTimeUse */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1oneTimeUse_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->OneTimeUse, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Conditions.OneTimeUse */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1oneTimeUse_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->OneTimeUse, value);
}
/* Adder for GList*<LassoSaml2OneTimeUse> LassoSaml2Conditions.OneTimeUse */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1oneTimeUse_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->OneTimeUse, value);
}
/* Remover for GList*<LassoSaml2OneTimeUse> LassoSaml2Conditions.OneTimeUse */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1oneTimeUse_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->OneTimeUse,value);
}


/* Getter for GList* LassoSaml2Conditions.ProxyRestriction */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1proxyRestriction_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->ProxyRestriction, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Conditions.ProxyRestriction */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1proxyRestriction_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->ProxyRestriction, value);
}
/* Adder for GList*<LassoSaml2ProxyRestriction> LassoSaml2Conditions.ProxyRestriction */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1proxyRestriction_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->ProxyRestriction, value);
}
/* Remover for GList*<LassoSaml2ProxyRestriction> LassoSaml2Conditions.ProxyRestriction */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1proxyRestriction_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->ProxyRestriction,value);
}


/* Getter for char* LassoSaml2Conditions.NotBefore */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1notBefore_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NotBefore, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2Conditions.NotBefore */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1notBefore_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NotBefore);
}

/* Getter for char* LassoSaml2Conditions.NotOnOrAfter */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1notOnOrAfter_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NotOnOrAfter, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2Conditions.NotOnOrAfter */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Conditions_1notOnOrAfter_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2Conditions *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NotOnOrAfter);
}

/* Getter for char* LassoSamlp2AssertionIDRequest.AssertionIDRef */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AssertionIDRequest_1assertionIdRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AssertionIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AssertionIDRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2AssertionIDRequest.AssertionIDRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AssertionIDRequest_1assertionIdRef_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2AssertionIDRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AssertionIDRef);
}

/* Getter for LassoSaml2SubjectLocality* LassoSaml2AuthnStatement.SubjectLocality */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnStatement_1subjectLocality_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthnStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->SubjectLocality, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2SubjectLocality* LassoSaml2AuthnStatement.SubjectLocality */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnStatement_1subjectLocality_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2AuthnStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->SubjectLocality);
}

/* Getter for LassoSaml2AuthnContext* LassoSaml2AuthnStatement.AuthnContext */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnStatement_1authnContext_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthnStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->AuthnContext, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2AuthnContext* LassoSaml2AuthnStatement.AuthnContext */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnStatement_1authnContext_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2AuthnStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->AuthnContext);
}

/* Getter for char* LassoSaml2AuthnStatement.AuthnInstant */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnStatement_1authnInstant_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthnStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AuthnInstant, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2AuthnStatement.AuthnInstant */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnStatement_1authnInstant_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2AuthnStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AuthnInstant);
}

/* Getter for char* LassoSaml2AuthnStatement.SessionIndex */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnStatement_1sessionIndex_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthnStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SessionIndex, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2AuthnStatement.SessionIndex */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnStatement_1sessionIndex_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2AuthnStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SessionIndex);
}

/* Getter for char* LassoSaml2AuthnStatement.SessionNotOnOrAfter */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnStatement_1sessionNotOnOrAfter_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthnStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SessionNotOnOrAfter, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2AuthnStatement.SessionNotOnOrAfter */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnStatement_1sessionNotOnOrAfter_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2AuthnStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SessionNotOnOrAfter);
}

/* Getter for LassoSaml2Action* LassoSaml2AuthzDecisionStatement.Action */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthzDecisionStatement_1action_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthzDecisionStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Action, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2Action* LassoSaml2AuthzDecisionStatement.Action */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthzDecisionStatement_1action_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2AuthzDecisionStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Action);
}

/* Getter for LassoSaml2Evidence* LassoSaml2AuthzDecisionStatement.Evidence */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthzDecisionStatement_1evidence_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthzDecisionStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Evidence, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2Evidence* LassoSaml2AuthzDecisionStatement.Evidence */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthzDecisionStatement_1evidence_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2AuthzDecisionStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Evidence);
}

/* Getter for char* LassoSaml2AuthzDecisionStatement.Resource */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthzDecisionStatement_1resource_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthzDecisionStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Resource, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2AuthzDecisionStatement.Resource */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthzDecisionStatement_1resource_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2AuthzDecisionStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Resource);
}

/* Getter for char* LassoSaml2AuthzDecisionStatement.Decision */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthzDecisionStatement_1decision_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthzDecisionStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Decision, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2AuthzDecisionStatement.Decision */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthzDecisionStatement_1decision_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2AuthzDecisionStatement *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Decision);
}

/* Getter for LassoSaml2Subject* LassoSamlp2AuthnRequest.Subject */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1subject_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Subject, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2Subject* LassoSamlp2AuthnRequest.Subject */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1subject_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Subject);
}

/* Getter for LassoSamlp2NameIDPolicy* LassoSamlp2AuthnRequest.NameIDPolicy */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1nameIdPolicy_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameIDPolicy, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2NameIDPolicy* LassoSamlp2AuthnRequest.NameIDPolicy */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1nameIdPolicy_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameIDPolicy);
}

/* Getter for LassoSaml2Conditions* LassoSamlp2AuthnRequest.Conditions */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1conditions_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Conditions, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2Conditions* LassoSamlp2AuthnRequest.Conditions */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1conditions_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Conditions);
}

/* Getter for LassoSamlp2RequestedAuthnContext* LassoSamlp2AuthnRequest.RequestedAuthnContext */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1requestedAuthnContext_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->RequestedAuthnContext, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2RequestedAuthnContext* LassoSamlp2AuthnRequest.RequestedAuthnContext */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1requestedAuthnContext_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->RequestedAuthnContext);
}

/* Getter for LassoSamlp2Scoping* LassoSamlp2AuthnRequest.Scoping */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1scoping_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Scoping, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2Scoping* LassoSamlp2AuthnRequest.Scoping */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1scoping_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Scoping);
}

/* Getter for gboolean LassoSamlp2AuthnRequest.ForceAuthn */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1forceAuthn_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->ForceAuthn;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoSamlp2AuthnRequest.ForceAuthn */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1forceAuthn_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->ForceAuthn = (gboolean)value;
}

/* Getter for gboolean LassoSamlp2AuthnRequest.IsPassive */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1isPassive_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->IsPassive;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoSamlp2AuthnRequest.IsPassive */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1isPassive_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->IsPassive = (gboolean)value;
}

/* Getter for char* LassoSamlp2AuthnRequest.ProtocolBinding */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1protocolBinding_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProtocolBinding, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2AuthnRequest.ProtocolBinding */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1protocolBinding_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProtocolBinding);
}

/* Getter for int LassoSamlp2AuthnRequest.AssertionConsumerServiceIndex */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1assertionConsumerServiceIndex_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->AssertionConsumerServiceIndex;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for int LassoSamlp2AuthnRequest.AssertionConsumerServiceIndex */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1assertionConsumerServiceIndex_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->AssertionConsumerServiceIndex = (int)value;
}

/* Getter for char* LassoSamlp2AuthnRequest.AssertionConsumerServiceURL */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1assertionConsumerServiceURL_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AssertionConsumerServiceURL, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2AuthnRequest.AssertionConsumerServiceURL */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1assertionConsumerServiceURL_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AssertionConsumerServiceURL);
}

/* Getter for int LassoSamlp2AuthnRequest.AttributeConsumingServiceIndex */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1attributeConsumingServiceIndex_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->AttributeConsumingServiceIndex;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for int LassoSamlp2AuthnRequest.AttributeConsumingServiceIndex */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1attributeConsumingServiceIndex_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->AttributeConsumingServiceIndex = (int)value;
}

/* Getter for char* LassoSamlp2AuthnRequest.ProviderName */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1providerName_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderName, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2AuthnRequest.ProviderName */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnRequest_1providerName_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2AuthnRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderName);
}

/* Getter for char* LassoSaml2ProxyRestriction.Audience */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2ProxyRestriction_1audience_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2ProxyRestriction *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Audience, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2ProxyRestriction.Audience */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2ProxyRestriction_1audience_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2ProxyRestriction *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Audience);
}

/* Getter for char* LassoSaml2ProxyRestriction.Count */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2ProxyRestriction_1count_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2ProxyRestriction *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Count, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2ProxyRestriction.Count */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2ProxyRestriction_1count_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2ProxyRestriction *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Count);
}

/* Getter for char* LassoSaml2AuthnContext.AuthnContextClassRef */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnContext_1authnContextClassRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AuthnContextClassRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2AuthnContext.AuthnContextClassRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnContext_1authnContextClassRef_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2AuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AuthnContextClassRef);
}

/* Getter for char* LassoSaml2AuthnContext.AuthnContextDeclRef */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnContext_1authnContextDeclRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AuthnContextDeclRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2AuthnContext.AuthnContextDeclRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnContext_1authnContextDeclRef_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2AuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AuthnContextDeclRef);
}

/* Getter for char* LassoSaml2AuthnContext.AuthenticatingAuthority */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnContext_1authenticatingAuthority_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2AuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AuthenticatingAuthority, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2AuthnContext.AuthenticatingAuthority */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2AuthnContext_1authenticatingAuthority_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2AuthnContext *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AuthenticatingAuthority);
}

/* Getter for GList* LassoSamlp2IDPList.IDPEntry */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPList_1iDPEntry_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2IDPList *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->IDPEntry, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlp2IDPList.IDPEntry */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPList_1iDPEntry_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlp2IDPList *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->IDPEntry, value);
}
/* Adder for GList*<LassoSamlp2IDPEntry> LassoSamlp2IDPList.IDPEntry */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPList_1iDPEntry_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2IDPList *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->IDPEntry, value);
}
/* Remover for GList*<LassoSamlp2IDPEntry> LassoSamlp2IDPList.IDPEntry */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPList_1iDPEntry_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2IDPList *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->IDPEntry,value);
}


/* Getter for char* LassoSamlp2IDPList.GetComplete */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPList_1getComplete_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2IDPList *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->GetComplete, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2IDPList.GetComplete */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPList_1getComplete_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2IDPList *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->GetComplete);
}

/* Getter for GList* LassoSaml2Evidence.AssertionIDRef */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertionIdRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AssertionIDRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Evidence.AssertionIDRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertionIdRef_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AssertionIDRef, value);
}
/* Adder for GList*<LassoNode> LassoSaml2Evidence.AssertionIDRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertionIdRef_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AssertionIDRef, value);
}
/* Remover for GList*<LassoNode> LassoSaml2Evidence.AssertionIDRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertionIdRef_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AssertionIDRef,value);
}


/* Getter for GList* LassoSaml2Evidence.AssertionURIRef */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertionURIRef_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AssertionURIRef, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Evidence.AssertionURIRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertionURIRef_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AssertionURIRef, value);
}
/* Adder for GList*<LassoNode> LassoSaml2Evidence.AssertionURIRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertionURIRef_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AssertionURIRef, value);
}
/* Remover for GList*<LassoNode> LassoSaml2Evidence.AssertionURIRef */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertionURIRef_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AssertionURIRef,value);
}


/* Getter for GList* LassoSaml2Evidence.Assertion */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Assertion, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Evidence.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertion_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Assertion, value);
}
/* Adder for GList*<LassoSaml2Assertion> LassoSaml2Evidence.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertion_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Assertion, value);
}
/* Remover for GList*<LassoSaml2Assertion> LassoSaml2Evidence.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1assertion_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Assertion,value);
}


/* Getter for GList* LassoSaml2Evidence.EncryptedAssertion */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1encryptedAssertion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->EncryptedAssertion, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Evidence.EncryptedAssertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1encryptedAssertion_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->EncryptedAssertion, value);
}
/* Adder for GList*<LassoSaml2EncryptedElement> LassoSaml2Evidence.EncryptedAssertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1encryptedAssertion_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->EncryptedAssertion, value);
}
/* Remover for GList*<LassoSaml2EncryptedElement> LassoSaml2Evidence.EncryptedAssertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Evidence_1encryptedAssertion_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Evidence *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->EncryptedAssertion,value);
}


/* Getter for GList* LassoSaml2Attribute.AttributeValue */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Attribute_1attributeValue_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Attribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->AttributeValue, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSaml2Attribute.AttributeValue */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Attribute_1attributeValue_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSaml2Attribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->AttributeValue, value);
}
/* Adder for GList*<LassoNode> LassoSaml2Attribute.AttributeValue */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Attribute_1attributeValue_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Attribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->AttributeValue, value);
}
/* Remover for GList*<LassoNode> LassoSaml2Attribute.AttributeValue */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Attribute_1attributeValue_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2Attribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->AttributeValue,value);
}


/* Getter for char* LassoSaml2Attribute.Name */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Attribute_1name_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Attribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Name, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2Attribute.Name */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Attribute_1name_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2Attribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Name);
}

/* Getter for char* LassoSaml2Attribute.NameFormat */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Attribute_1nameFormat_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Attribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NameFormat, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2Attribute.NameFormat */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Attribute_1nameFormat_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2Attribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NameFormat);
}

/* Getter for char* LassoSaml2Attribute.FriendlyName */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Attribute_1friendlyName_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2Attribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->FriendlyName, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2Attribute.FriendlyName */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2Attribute_1friendlyName_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2Attribute *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->FriendlyName);
}

/* Getter for char* LassoSamlp2IDPEntry.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPEntry_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2IDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2IDPEntry.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPEntry_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2IDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for char* LassoSamlp2IDPEntry.Name */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPEntry_1name_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2IDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Name, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2IDPEntry.Name */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPEntry_1name_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2IDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Name);
}

/* Getter for char* LassoSamlp2IDPEntry.Loc */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPEntry_1loc_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2IDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Loc, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2IDPEntry.Loc */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2IDPEntry_1loc_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2IDPEntry *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Loc);
}

/* Getter for LassoSaml2BaseIDAbstract* LassoSaml2SubjectConfirmation.BaseID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmation_1baseId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->BaseID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2BaseIDAbstract* LassoSaml2SubjectConfirmation.BaseID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmation_1baseId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2SubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->BaseID);
}

/* Getter for LassoSaml2NameID* LassoSaml2SubjectConfirmation.NameID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmation_1nameId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoSaml2SubjectConfirmation.NameID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmation_1nameId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2SubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameID);
}

/* Getter for LassoSaml2EncryptedElement* LassoSaml2SubjectConfirmation.EncryptedID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmation_1encryptedId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->EncryptedID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2EncryptedElement* LassoSaml2SubjectConfirmation.EncryptedID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmation_1encryptedId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2SubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->EncryptedID);
}

/* Getter for LassoSaml2SubjectConfirmationData* LassoSaml2SubjectConfirmation.SubjectConfirmationData */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmation_1subjectConfirmationData_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->SubjectConfirmationData, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2SubjectConfirmationData* LassoSaml2SubjectConfirmation.SubjectConfirmationData */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmation_1subjectConfirmationData_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSaml2SubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->SubjectConfirmationData);
}

/* Getter for char* LassoSaml2SubjectConfirmation.Method */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmation_1method_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Method, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2SubjectConfirmation.Method */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmation_1method_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2SubjectConfirmation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Method);
}

/* Getter for LassoSaml2Subject* LassoSamlp2SubjectQueryAbstract.Subject */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2SubjectQueryAbstract_1subject_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2SubjectQueryAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Subject, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2Subject* LassoSamlp2SubjectQueryAbstract.Subject */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2SubjectQueryAbstract_1subject_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2SubjectQueryAbstract *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Subject);
}

/* Getter for GList* LassoSamlp2AttributeQuery.Attribute */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AttributeQuery_1attribute_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AttributeQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Attribute, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlp2AttributeQuery.Attribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AttributeQuery_1attribute_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlp2AttributeQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Attribute, value);
}
/* Adder for GList*<LassoSaml2Attribute> LassoSamlp2AttributeQuery.Attribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AttributeQuery_1attribute_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2AttributeQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Attribute, value);
}
/* Remover for GList*<LassoSaml2Attribute> LassoSamlp2AttributeQuery.Attribute */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AttributeQuery_1attribute_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2AttributeQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Attribute,value);
}


/* Getter for LassoSamlp2RequestedAuthnContext* LassoSamlp2AuthnQuery.RequestedAuthnContext */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnQuery_1requestedAuthnContext_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->RequestedAuthnContext, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2RequestedAuthnContext* LassoSamlp2AuthnQuery.RequestedAuthnContext */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnQuery_1requestedAuthnContext_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2AuthnQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->RequestedAuthnContext);
}

/* Getter for char* LassoSamlp2AuthnQuery.SessionIndex */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnQuery_1sessionIndex_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthnQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SessionIndex, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2AuthnQuery.SessionIndex */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthnQuery_1sessionIndex_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2AuthnQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SessionIndex);
}

/* Getter for LassoSaml2Action* LassoSamlp2AuthzDecisionQuery.Action */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthzDecisionQuery_1action_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthzDecisionQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Action, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2Action* LassoSamlp2AuthzDecisionQuery.Action */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthzDecisionQuery_1action_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2AuthzDecisionQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Action);
}

/* Getter for LassoSaml2Evidence* LassoSamlp2AuthzDecisionQuery.Evidence */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthzDecisionQuery_1evidence_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthzDecisionQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Evidence, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2Evidence* LassoSamlp2AuthzDecisionQuery.Evidence */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthzDecisionQuery_1evidence_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2AuthzDecisionQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Evidence);
}

/* Getter for char* LassoSamlp2AuthzDecisionQuery.Resource */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthzDecisionQuery_1resource_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2AuthzDecisionQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Resource, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2AuthzDecisionQuery.Resource */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2AuthzDecisionQuery_1resource_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2AuthzDecisionQuery *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Resource);
}

/* Getter for LassoSaml2BaseIDAbstract* LassoSamlp2LogoutRequest.BaseID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1baseId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->BaseID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2BaseIDAbstract* LassoSamlp2LogoutRequest.BaseID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1baseId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->BaseID);
}

/* Getter for LassoSaml2NameID* LassoSamlp2LogoutRequest.NameID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1nameId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoSamlp2LogoutRequest.NameID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1nameId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameID);
}

/* Getter for LassoSaml2EncryptedElement* LassoSamlp2LogoutRequest.EncryptedID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1encryptedId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->EncryptedID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2EncryptedElement* LassoSamlp2LogoutRequest.EncryptedID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1encryptedId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->EncryptedID);
}

/* Getter for char* LassoSamlp2LogoutRequest.SessionIndex */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1sessionIndex_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->SessionIndex, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2LogoutRequest.SessionIndex */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1sessionIndex_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->SessionIndex);
}

/* Getter for char* LassoSamlp2LogoutRequest.Reason */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1reason_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Reason, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2LogoutRequest.Reason */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1reason_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Reason);
}

/* Getter for char* LassoSamlp2LogoutRequest.NotOnOrAfter */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1notOnOrAfter_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NotOnOrAfter, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2LogoutRequest.NotOnOrAfter */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2LogoutRequest_1notOnOrAfter_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2LogoutRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NotOnOrAfter);
}

/* Getter for char* LassoSaml2SubjectConfirmationData.NotBefore */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmationData_1notBefore_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectConfirmationData *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NotBefore, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2SubjectConfirmationData.NotBefore */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmationData_1notBefore_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2SubjectConfirmationData *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NotBefore);
}

/* Getter for char* LassoSaml2SubjectConfirmationData.NotOnOrAfter */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmationData_1notOnOrAfter_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectConfirmationData *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->NotOnOrAfter, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2SubjectConfirmationData.NotOnOrAfter */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmationData_1notOnOrAfter_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2SubjectConfirmationData *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->NotOnOrAfter);
}

/* Getter for char* LassoSaml2SubjectConfirmationData.Recipient */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmationData_1recipient_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectConfirmationData *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Recipient, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2SubjectConfirmationData.Recipient */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmationData_1recipient_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2SubjectConfirmationData *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Recipient);
}

/* Getter for char* LassoSaml2SubjectConfirmationData.InResponseTo */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmationData_1inResponseTo_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectConfirmationData *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->InResponseTo, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2SubjectConfirmationData.InResponseTo */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmationData_1inResponseTo_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2SubjectConfirmationData *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->InResponseTo);
}

/* Getter for char* LassoSaml2SubjectConfirmationData.Address */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmationData_1address_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSaml2SubjectConfirmationData *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Address, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSaml2SubjectConfirmationData.Address */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Saml2SubjectConfirmationData_1address_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSaml2SubjectConfirmationData *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Address);
}

/* Getter for LassoSaml2NameID* LassoSamlp2StatusResponse.Issuer */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1issuer_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Issuer, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoSamlp2StatusResponse.Issuer */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1issuer_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Issuer);
}

/* Getter for LassoSamlp2Extensions* LassoSamlp2StatusResponse.Extensions */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1extensions_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Extensions, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2Extensions* LassoSamlp2StatusResponse.Extensions */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1extensions_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Extensions);
}

/* Getter for LassoSamlp2Status* LassoSamlp2StatusResponse.Status */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1status_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Status, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2Status* LassoSamlp2StatusResponse.Status */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1status_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Status);
}

/* Getter for char* LassoSamlp2StatusResponse.ID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1iD_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2StatusResponse.ID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1iD_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ID);
}

/* Getter for char* LassoSamlp2StatusResponse.InResponseTo */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1inResponseTo_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->InResponseTo, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2StatusResponse.InResponseTo */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1inResponseTo_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->InResponseTo);
}

/* Getter for char* LassoSamlp2StatusResponse.Version */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1version_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Version, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2StatusResponse.Version */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1version_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Version);
}

/* Getter for char* LassoSamlp2StatusResponse.IssueInstant */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1issueInstant_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->IssueInstant, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2StatusResponse.IssueInstant */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1issueInstant_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->IssueInstant);
}

/* Getter for char* LassoSamlp2StatusResponse.Destination */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1destination_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Destination, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2StatusResponse.Destination */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1destination_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Destination);
}

/* Getter for char* LassoSamlp2StatusResponse.Consent */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1consent_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Consent, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoSamlp2StatusResponse.Consent */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2StatusResponse_1consent_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSamlp2StatusResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Consent);
}

/* Getter for GList* LassoSamlp2Response.Assertion */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Response_1assertion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2Response *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Assertion, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlp2Response.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Response_1assertion_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlp2Response *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Assertion, value);
}
/* Adder for GList*<LassoSaml2Assertion> LassoSamlp2Response.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Response_1assertion_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2Response *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Assertion, value);
}
/* Remover for GList*<LassoSaml2Assertion> LassoSamlp2Response.Assertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Response_1assertion_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2Response *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Assertion,value);
}


/* Getter for GList* LassoSamlp2Response.EncryptedAssertion */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Response_1encryptedAssertion_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2Response *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->EncryptedAssertion, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSamlp2Response.EncryptedAssertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Response_1encryptedAssertion_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSamlp2Response *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->EncryptedAssertion, value);
}
/* Adder for GList*<LassoSaml2EncryptedElement> LassoSamlp2Response.EncryptedAssertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Response_1encryptedAssertion_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2Response *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->EncryptedAssertion, value);
}
/* Remover for GList*<LassoSaml2EncryptedElement> LassoSamlp2Response.EncryptedAssertion */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2Response_1encryptedAssertion_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2Response *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->EncryptedAssertion,value);
}


/* Getter for LassoNode* LassoSamlp2ArtifactResponse.any */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ArtifactResponse_1any_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2ArtifactResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->any, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoNode* LassoSamlp2ArtifactResponse.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2ArtifactResponse_1any_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2ArtifactResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->any);
}

/* Getter for LassoSaml2NameID* LassoSamlp2NameIDMappingResponse.NameID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingResponse_1nameId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2NameIDMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->NameID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoSamlp2NameIDMappingResponse.NameID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingResponse_1nameId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2NameIDMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->NameID);
}

/* Getter for LassoSaml2EncryptedElement* LassoSamlp2NameIDMappingResponse.EncryptedID */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingResponse_1encryptedId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSamlp2NameIDMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->EncryptedID, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2EncryptedElement* LassoSamlp2NameIDMappingResponse.EncryptedID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Samlp2NameIDMappingResponse_1encryptedId_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSamlp2NameIDMappingResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->EncryptedID);
}

/* Getter for LassoSaml2NameID* LassoEcpRequest.Issuer */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1issuer_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Issuer, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoEcpRequest.Issuer */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1issuer_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Issuer);
}

/* Getter for LassoSamlp2IDPList* LassoEcpRequest.IDPList */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1iDPList_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->IDPList, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2IDPList* LassoEcpRequest.IDPList */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1iDPList_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->IDPList);
}

/* Getter for gboolean LassoEcpRequest.mustUnderstand */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1mustUnderstand_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->mustUnderstand;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoEcpRequest.mustUnderstand */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1mustUnderstand_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->mustUnderstand = (gboolean)value;
}

/* Getter for gchar* LassoEcpRequest.actor */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1actor_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->actor, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcpRequest.actor */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1actor_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->actor);
}

/* Getter for gchar* LassoEcpRequest.ProviderName */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1providerName_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderName, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcpRequest.ProviderName */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1providerName_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderName);
}

/* Getter for gboolean LassoEcpRequest.IsPassive */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1isPassive_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->IsPassive;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoEcpRequest.IsPassive */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRequest_1isPassive_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoEcpRequest *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->IsPassive = (gboolean)value;
}

/* Getter for gboolean LassoEcpResponse.mustUnderstand */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpResponse_1mustUnderstand_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->mustUnderstand;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoEcpResponse.mustUnderstand */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpResponse_1mustUnderstand_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoEcpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->mustUnderstand = (gboolean)value;
}

/* Getter for gchar* LassoEcpResponse.actor */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpResponse_1actor_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->actor, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcpResponse.actor */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpResponse_1actor_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->actor);
}

/* Getter for gchar* LassoEcpResponse.AssertionConsumerServiceURL */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpResponse_1assertionConsumerServiceURL_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->AssertionConsumerServiceURL, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcpResponse.AssertionConsumerServiceURL */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpResponse_1assertionConsumerServiceURL_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcpResponse *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->AssertionConsumerServiceURL);
}

/* Getter for gchar* LassoEcpRelayState.RelayState */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRelayState_1relayState_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpRelayState *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->RelayState, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcpRelayState.RelayState */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRelayState_1relayState_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcpRelayState *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->RelayState);
}

/* Getter for gboolean LassoEcpRelayState.mustUnderstand */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRelayState_1mustUnderstand_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpRelayState *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->mustUnderstand;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoEcpRelayState.mustUnderstand */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRelayState_1mustUnderstand_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoEcpRelayState *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->mustUnderstand = (gboolean)value;
}

/* Getter for gchar* LassoEcpRelayState.actor */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRelayState_1actor_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcpRelayState *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->actor, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcpRelayState.actor */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_EcpRelayState_1actor_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcpRelayState *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->actor);
}

/* Getter for GList* LassoSoapDetail.any */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapDetail_1any_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSoapDetail *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->any, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSoapDetail.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapDetail_1any_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSoapDetail *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->any, value);
}
/* Adder for GList*<LassoNode> LassoSoapDetail.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapDetail_1any_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSoapDetail *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->any, value);
}
/* Remover for GList*<LassoNode> LassoSoapDetail.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapDetail_1any_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSoapDetail *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->any,value);
}


/* Getter for GList* LassoSoapBody.any */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapBody_1any_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSoapBody *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->any, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSoapBody.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapBody_1any_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSoapBody *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->any, value);
}
/* Adder for GList*<LassoNode> LassoSoapBody.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapBody_1any_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSoapBody *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->any, value);
}
/* Remover for GList*<LassoNode> LassoSoapBody.any */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapBody_1any_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSoapBody *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->any,value);
}


/* Getter for gchar* LassoSoapBody.Id */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapBody_1id_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSoapBody *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Id, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoSoapBody.Id */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapBody_1id_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSoapBody *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Id);
}

/* Getter for LassoSoapHeader* LassoSoapEnvelope.Header */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapEnvelope_1header_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSoapEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Header, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSoapHeader* LassoSoapEnvelope.Header */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapEnvelope_1header_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSoapEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Header);
}

/* Getter for LassoSoapBody* LassoSoapEnvelope.Body */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapEnvelope_1body_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSoapEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Body, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSoapBody* LassoSoapEnvelope.Body */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapEnvelope_1body_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSoapEnvelope *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Body);
}

/* Getter for gchar* LassoSoapFault.faultcode */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapFault_1faultcode_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSoapFault *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->faultcode, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoSoapFault.faultcode */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapFault_1faultcode_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSoapFault *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->faultcode);
}

/* Getter for gchar* LassoSoapFault.faultstring */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapFault_1faultstring_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSoapFault *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->faultstring, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoSoapFault.faultstring */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapFault_1faultstring_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSoapFault *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->faultstring);
}

/* Getter for GList* LassoSoapFault.faultactor */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapFault_1faultactor_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSoapFault *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_strings(env, gobj->faultactor, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSoapFault.faultactor */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapFault_1faultactor_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSoapFault *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_strings(env, &gobj->faultactor,value);
}
/* Adder for GList*<string> LassoSoapFault.faultactor */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapFault_1faultactor_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSoapFault *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_strings(env, &gobj->faultactor, value);
}
/* Remover for GList*<string> LassoSoapFault.faultactor */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapFault_1faultactor_1remove(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoSoapFault *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_strings(env, &gobj->faultactor,value);
}


/* Getter for LassoSoapDetail* LassoSoapFault.Detail */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapFault_1detail_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSoapFault *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->Detail, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSoapDetail* LassoSoapFault.Detail */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapFault_1detail_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSoapFault *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->Detail);
}

/* Getter for GList* LassoSoapHeader.Other */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapHeader_1other_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSoapHeader *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->Other, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoSoapHeader.Other */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapHeader_1other_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSoapHeader *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->Other, value);
}
/* Adder for GList*<LassoNode> LassoSoapHeader.Other */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapHeader_1other_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSoapHeader *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->Other, value);
}
/* Remover for GList*<LassoNode> LassoSoapHeader.Other */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_SoapHeader_1other_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoSoapHeader *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->Other,value);
}


/* Getter for LassoDsKeyValue* LassoDsKeyInfo.KeyValue */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_DsKeyInfo_1keyValue_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoDsKeyInfo *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->KeyValue, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoDsKeyValue* LassoDsKeyInfo.KeyValue */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_DsKeyInfo_1keyValue_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoDsKeyInfo *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->KeyValue);
}

/* Getter for LassoDsRsaKeyValue* LassoDsKeyValue.RSAKeyValue */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_DsKeyValue_1rSAKeyValue_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoDsKeyValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->RSAKeyValue, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoDsRsaKeyValue* LassoDsKeyValue.RSAKeyValue */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_DsKeyValue_1rSAKeyValue_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoDsKeyValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->RSAKeyValue);
}

/* Getter for char* LassoDsRsaKeyValue.Modulus */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_DsRsaKeyValue_1modulus_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoDsRsaKeyValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Modulus, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoDsRsaKeyValue.Modulus */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_DsRsaKeyValue_1modulus_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoDsRsaKeyValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Modulus);
}

/* Getter for char* LassoDsRsaKeyValue.Exponent */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_DsRsaKeyValue_1exponent_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoDsRsaKeyValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->Exponent, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoDsRsaKeyValue.Exponent */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_DsRsaKeyValue_1exponent_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoDsRsaKeyValue *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->Exponent);
}

/* Getter for gchar* LassoFederation.remote_providerID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Federation_1remoteProviderId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoFederation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->remote_providerID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoFederation.remote_providerID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Federation_1remoteProviderId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoFederation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->remote_providerID);
}

/* Getter for LassoNode* LassoFederation.local_nameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Federation_1localNameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoFederation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->local_nameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoNode* LassoFederation.local_nameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Federation_1localNameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoFederation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->local_nameIdentifier);
}

/* Getter for LassoNode* LassoFederation.remote_nameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Federation_1remoteNameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoFederation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->remote_nameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoNode* LassoFederation.remote_nameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Federation_1remoteNameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoFederation *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->remote_nameIdentifier);
}

/* Getter for LassoServer* LassoProfile.server */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1server_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->server, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoServer* LassoProfile.server */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1server_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->server);
}

/* Getter for LassoNode* LassoProfile.request */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1request_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->request, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoNode* LassoProfile.request */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1request_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->request);
}

/* Getter for LassoNode* LassoProfile.response */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1response_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->response, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoNode* LassoProfile.response */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1response_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->response);
}

/* Getter for LassoNode* LassoProfile.nameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1nameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->nameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoNode* LassoProfile.nameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1nameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->nameIdentifier);
}

/* Getter for gchar* LassoProfile.remote_providerID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1remoteProviderId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->remote_providerID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoProfile.remote_providerID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1remoteProviderId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->remote_providerID);
}

/* Getter for gchar* LassoProfile.msg_url */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1msgUrl_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->msg_url, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoProfile.msg_url */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1msgUrl_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->msg_url);
}

/* Getter for gchar* LassoProfile.msg_body */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1msgBody_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->msg_body, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoProfile.msg_body */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1msgBody_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->msg_body);
}

/* Getter for gchar* LassoProfile.msg_relayState */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1msgRelayState_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->msg_relayState, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoProfile.msg_relayState */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Profile_1msgRelayState_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoProfile *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->msg_relayState);
}

/* Getter for gchar* LassoEcp.assertion_consumer_url */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1assertionConsumerUrl_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->assertion_consumer_url, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcp.assertion_consumer_url */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1assertionConsumerUrl_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->assertion_consumer_url);
}

/* Getter for gchar* LassoEcp.message_id */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1messageId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->message_id, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcp.message_id */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1messageId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->message_id);
}

/* Getter for gchar* LassoEcp.response_consumer_url */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1responseConsumerUrl_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->response_consumer_url, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcp.response_consumer_url */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1responseConsumerUrl_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->response_consumer_url);
}

/* Getter for gchar* LassoEcp.relaystate */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1relaystate_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->relaystate, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcp.relaystate */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1relaystate_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->relaystate);
}

/* Getter for LassoSaml2NameID* LassoEcp.issuer */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1issuer_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->issuer, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSaml2NameID* LassoEcp.issuer */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1issuer_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->issuer);
}

/* Getter for gchar* LassoEcp.provider_name */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1providerName_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->provider_name, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoEcp.provider_name */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1providerName_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->provider_name);
}

/* Getter for gboolean LassoEcp.is_passive */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1isPassive_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->is_passive;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoEcp.is_passive */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1isPassive_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->is_passive = (gboolean)value;
}

/* Getter for LassoSamlp2IDPList* LassoEcp.sp_idp_list */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1spIdpList_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->sp_idp_list, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlp2IDPList* LassoEcp.sp_idp_list */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1spIdpList_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->sp_idp_list);
}

/* Getter for GList* LassoEcp.known_sp_provided_idp_entries_supporting_ecp */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1knownSpProvidedIdpEntriesSupportingEcp_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_objects(env, gobj->known_sp_provided_idp_entries_supporting_ecp, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoEcp.known_sp_provided_idp_entries_supporting_ecp */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1knownSpProvidedIdpEntriesSupportingEcp_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_objects(env, &gobj->known_sp_provided_idp_entries_supporting_ecp, value);
}
/* Adder for GList*<LassoSamlp2IDPEntry> LassoEcp.known_sp_provided_idp_entries_supporting_ecp */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1knownSpProvidedIdpEntriesSupportingEcp_1add(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_objects(env, &gobj->known_sp_provided_idp_entries_supporting_ecp, value);
}
/* Remover for GList*<LassoSamlp2IDPEntry> LassoEcp.known_sp_provided_idp_entries_supporting_ecp */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1knownSpProvidedIdpEntriesSupportingEcp_1remove(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_objects(env, &gobj->known_sp_provided_idp_entries_supporting_ecp,value);
}


/* Getter for GList* LassoEcp.known_idp_entity_ids_supporting_ecp */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1knownIdpEntityIdsSupportingEcp_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_list_of_strings(env, gobj->known_idp_entity_ids_supporting_ecp, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GList* LassoEcp.known_idp_entity_ids_supporting_ecp */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1knownIdpEntityIdsSupportingEcp_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_list_of_strings(env, &gobj->known_idp_entity_ids_supporting_ecp,value);
}
/* Adder for GList*<strings> LassoEcp.known_idp_entity_ids_supporting_ecp */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1knownIdpEntityIdsSupportingEcp_1add(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    add_to_list_of_strings(env, &gobj->known_idp_entity_ids_supporting_ecp, value);
}
/* Remover for GList*<strings> LassoEcp.known_idp_entity_ids_supporting_ecp */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Ecp_1knownIdpEntityIdsSupportingEcp_1remove(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoEcp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    remove_from_list_of_strings(env, &gobj->known_idp_entity_ids_supporting_ecp,value);
}


/* Getter for LassoLoginProtocolProfile LassoLogin.protocolProfile */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_Login_1protocolProfile_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLogin *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->protocolProfile;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLoginProtocolProfile LassoLogin.protocolProfile */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Login_1protocolProfile_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoLogin *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->protocolProfile = (LassoLoginProtocolProfile)value;
}

/* Getter for gchar* LassoLogin.assertionArtifact */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Login_1assertionArtifact_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLogin *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->assertionArtifact, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoLogin.assertionArtifact */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Login_1assertionArtifact_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLogin *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->assertionArtifact);
}

/* Getter for LassoSamlNameIdentifier* LassoNameRegistration.oldNameIdentifier */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_NameRegistration_1oldNameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoNameRegistration *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->oldNameIdentifier, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSamlNameIdentifier* LassoNameRegistration.oldNameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_NameRegistration_1oldNameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoNameRegistration *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->oldNameIdentifier);
}

/* Getter for gchar* LassoProvider.ProviderID */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Provider_1providerId_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProvider *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ProviderID, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoProvider.ProviderID */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Provider_1providerId_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoProvider *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ProviderID);
}

/* Getter for LassoProviderRole LassoProvider.role */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_Provider_1role_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProvider *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->role;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoProviderRole LassoProvider.role */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Provider_1role_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoProvider *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->role = (LassoProviderRole)value;
}

/* Getter for char* LassoProvider.metadata_filename */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Provider_1metadataFilename_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProvider *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->metadata_filename, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoProvider.metadata_filename */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Provider_1metadataFilename_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoProvider *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->metadata_filename);
}

/* Getter for gchar* LassoProvider.public_key */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Provider_1publicKey_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProvider *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->public_key, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoProvider.public_key */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Provider_1publicKey_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoProvider *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->public_key);
}

/* Getter for gchar* LassoProvider.ca_cert_chain */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Provider_1caCertChain_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoProvider *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->ca_cert_chain, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoProvider.ca_cert_chain */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Provider_1caCertChain_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoProvider *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->ca_cert_chain);
}

/* Getter for GHashTable* LassoServer.providers */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Server_1providers_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoServer *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_hash_of_objects(env, gobj->providers, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GHashTable* LassoServer.providers */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Server_1providers_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoServer *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_hash_of_objects(env, gobj->providers, value);
}

/* Getter for gchar* LassoServer.private_key */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Server_1privateKey_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoServer *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->private_key, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoServer.private_key */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Server_1privateKey_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoServer *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->private_key);
}

/* Getter for gchar* LassoServer.private_key_password */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Server_1privateKeyPassword_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoServer *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->private_key_password, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoServer.private_key_password */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Server_1privateKeyPassword_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoServer *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->private_key_password);
}

/* Getter for gchar* LassoServer.certificate */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Server_1certificate_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoServer *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->certificate, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoServer.certificate */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Server_1certificate_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoServer *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->certificate);
}

/* Getter for LassoSignatureMethod LassoServer.signature_method */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_Server_1signatureMethod_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoServer *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jint ret = 0;
    if (gobj) {
         ret = (jint)gobj->signature_method;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoSignatureMethod LassoServer.signature_method */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Server_1signatureMethod_1set(JNIEnv *env, jclass clss, jobject jobj, jint value)
  {
    LassoServer *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->signature_method = (LassoSignatureMethod)value;
}

/* Getter for GHashTable* LassoSession.assertions */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Session_1assertions_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSession *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_hash_of_objects(env, gobj->assertions, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GHashTable* LassoSession.assertions */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Session_1assertions_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoSession *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_hash_of_objects(env, gobj->assertions, value);
}

/* Getter for gboolean LassoSession.is_dirty */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_Session_1isDirty_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoSession *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->is_dirty;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoSession.is_dirty */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Session_1isDirty_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoSession *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->is_dirty = (gboolean)value;
}

/* Getter for gchar* LassoNameIdentifierMapping.targetNameIdentifier */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_NameIdentifierMapping_1targetNameIdentifier_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoNameIdentifierMapping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->targetNameIdentifier, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gchar* LassoNameIdentifierMapping.targetNameIdentifier */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_NameIdentifierMapping_1targetNameIdentifier_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoNameIdentifierMapping *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->targetNameIdentifier);
}

/* Getter for GHashTable* LassoIdentity.federations */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_Identity_1federations_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoIdentity *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobjectArray ret = 0;
    if (gobj) {
         get_hash_of_objects(env, gobj->federations, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for GHashTable* LassoIdentity.federations */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Identity_1federations_1set(JNIEnv *env, jclass clss, jobject jobj, jobjectArray value)
  {
    LassoIdentity *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    set_hash_of_objects(env, gobj->federations, value);
}

/* Getter for gboolean LassoIdentity.is_dirty */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_Identity_1isDirty_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoIdentity *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jboolean ret = 0;
    if (gobj) {
         ret = (jboolean)gobj->is_dirty;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for gboolean LassoIdentity.is_dirty */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Identity_1isDirty_1set(JNIEnv *env, jclass clss, jobject jobj, jboolean value)
  {
    LassoIdentity *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    gobj->is_dirty = (gboolean)value;
}

/* Getter for LassoLibAuthnRequestEnvelope* LassoLecp.authnRequestEnvelope */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Lecp_1authnRequestEnvelope_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLecp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->authnRequestEnvelope, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLibAuthnRequestEnvelope* LassoLecp.authnRequestEnvelope */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Lecp_1authnRequestEnvelope_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLecp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->authnRequestEnvelope);
}

/* Getter for LassoLibAuthnResponseEnvelope* LassoLecp.authnResponseEnvelope */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_Lecp_1authnResponseEnvelope_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLecp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jobject ret = 0;
    if (gobj) {
         gobject_to_jobject(env, (GObject*)gobj->authnResponseEnvelope, &ret);;
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for LassoLibAuthnResponseEnvelope* LassoLecp.authnResponseEnvelope */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Lecp_1authnResponseEnvelope_1set(JNIEnv *env, jclass clss, jobject jobj, jobject value)
  {
    LassoLecp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jobject_to_gobject(env, value, (GObject**)&gobj->authnResponseEnvelope);
}

/* Getter for char* LassoLecp.assertionConsumerServiceURL */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_Lecp_1assertionConsumerServiceURL_1get(JNIEnv *env, jclass clss, jobject jobj)  {
    LassoLecp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    jstring ret = 0;
    if (gobj) {
         string_to_jstring(env, gobj->assertionConsumerServiceURL, &ret);
    } else {
                 throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
            }
            return ret;
        }

/* Setter for char* LassoLecp.assertionConsumerServiceURL */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_Lecp_1assertionConsumerServiceURL_1set(JNIEnv *env, jclass clss, jobject jobj, jstring value)
  {
    LassoLecp *gobj = NULL;
    jobject_to_gobject_noref(env, jobj, (GObject**)&gobj);
    if (!gobj) {
        throw_by_name(env, "java/lang/NullPointerException", "no gobject correspond to the given object");
    }
    jstring_to_string(env, value, (char**)&gobj->assertionConsumerServiceURL);
}
/* End of declaration of getter/setter methods */
/* Wrapper function for  void lasso_node_cleanup_original_xmlnodes( LassoNode* node {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1cleanup_1original_1xmlnodes(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    LassoNode* node = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    lasso_node_cleanup_original_xmlnodes(node);
  }
/* Wrapper function for  char* lasso_node_dump( LassoNode* node {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1dump(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoNode* node = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    return_value =  lasso_node_dump(node);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_node_export_to_base64( LassoNode* node {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1export_1to_1base64(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoNode* node = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    return_value =  lasso_node_export_to_base64(node);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_node_export_to_query( LassoNode* node {}, LassoSignatureMethod sign_method {'default': 'c:1', 'optional': True}, const char* private_key_file {'optional': True}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1export_1to_1query(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jstring jarg3 )
  {
    jstring ret;
    LassoNode* node = NULL;
    LassoSignatureMethod sign_method;
    char* private_key_file = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    sign_method = (LassoSignatureMethod)jarg2;
    jstring_to_string(env, jarg3, (char**)&private_key_file);
    return_value =  lasso_node_export_to_query(node, sign_method, (const char*) private_key_file);
    if (private_key_file)
        g_free(private_key_file);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_node_export_to_query_with_password( LassoNode* node {}, LassoSignatureMethod sign_method {'default': 'c:1', 'optional': True}, const char* private_key_file {'optional': True}, const char* private_key_file_password {'optional': True}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1export_1to_1query_1with_1password(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jstring jarg3 ,jstring jarg4 )
  {
    jstring ret;
    LassoNode* node = NULL;
    LassoSignatureMethod sign_method;
    char* private_key_file = NULL;
    char* private_key_file_password = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    sign_method = (LassoSignatureMethod)jarg2;
    jstring_to_string(env, jarg3, (char**)&private_key_file);
    jstring_to_string(env, jarg4, (char**)&private_key_file_password);
    return_value =  lasso_node_export_to_query_with_password(node, sign_method, (const char*) private_key_file, (const char*) private_key_file_password);
    if (private_key_file)
        g_free(private_key_file);
    if (private_key_file_password)
        g_free(private_key_file_password);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_node_export_to_soap( LassoNode* node {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1export_1to_1soap(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoNode* node = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    return_value =  lasso_node_export_to_soap(node);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_node_export_to_soap_with_headers( LassoNode* node {}, GList* headers {'element-type': 'LassoNode*', 'optional': True}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1export_1to_1soap_1with_1headers(JNIEnv *env, jclass clss
,jobject jarg1 ,jobjectArray jarg2 )
  {
    jstring ret;
    LassoNode* node = NULL;
    GList* headers = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    set_list_of_objects(env, &headers, jarg2);
    return_value =  lasso_node_export_to_soap_with_headers(node, headers);
    free_glist(&headers, (GFunc)g_object_unref);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  gchar* lasso_node_export_to_xml( LassoNode* node {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1export_1to_1xml(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoNode* node = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    return_value =  lasso_node_export_to_xml(node);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_node_export_to_paos_request( LassoNode* node {}, const char* issuer {}, const char* responseConsumerURL {}, const char* relay_state {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1export_1to_1paos_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 ,jstring jarg4 )
  {
    jstring ret;
    LassoNode* node = NULL;
    char* issuer = NULL;
    char* responseConsumerURL = NULL;
    char* relay_state = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    jstring_to_string(env, jarg2, (char**)&issuer);
    jstring_to_string(env, jarg3, (char**)&responseConsumerURL);
    jstring_to_string(env, jarg4, (char**)&relay_state);
    return_value =  lasso_node_export_to_paos_request(node, (const char*) issuer, (const char*) responseConsumerURL, (const char*) relay_state);
    if (issuer)
        g_free(issuer);
    if (responseConsumerURL)
        g_free(responseConsumerURL);
    if (relay_state)
        g_free(relay_state);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_node_export_to_paos_request_full( LassoNode* node {}, const char* issuer {}, const char* responseConsumerURL {}, const char* message_id {'optional': True}, const char* relay_state {'optional': True}, gboolean is_passive {}, gchar* provider_name {'optional': True}, LassoSamlp2IDPList* idp_list {'optional': True}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1export_1to_1paos_1request_1full(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 ,jstring jarg4 ,jstring jarg5 ,jboolean jarg6 ,jstring jarg7 ,jobject jarg8 )
  {
    jstring ret;
    LassoNode* node = NULL;
    char* issuer = NULL;
    char* responseConsumerURL = NULL;
    char* message_id = NULL;
    char* relay_state = NULL;
    gboolean is_passive;
    gchar* provider_name = NULL;
    LassoSamlp2IDPList* idp_list = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    jstring_to_string(env, jarg2, (char**)&issuer);
    jstring_to_string(env, jarg3, (char**)&responseConsumerURL);
    jstring_to_string(env, jarg4, (char**)&message_id);
    jstring_to_string(env, jarg5, (char**)&relay_state);
    is_passive = (gboolean)jarg6;
    jstring_to_string(env, jarg7, (char**)&provider_name);
    jobject_to_gobject_noref(env, jarg8, (GObject**)&idp_list);
    return_value =  lasso_node_export_to_paos_request_full(node, (const char*) issuer, (const char*) responseConsumerURL, (const char*) message_id, (const char*) relay_state, is_passive, provider_name, idp_list);
    if (issuer)
        g_free(issuer);
    if (responseConsumerURL)
        g_free(responseConsumerURL);
    if (message_id)
        g_free(message_id);
    if (relay_state)
        g_free(relay_state);
    if (provider_name)
        g_free(provider_name);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_node_export_to_ecp_soap_response( LassoNode* node {}, const char* assertionConsumerURL {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1export_1to_1ecp_1soap_1response(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jstring ret;
    LassoNode* node = NULL;
    char* assertionConsumerURL = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    jstring_to_string(env, jarg2, (char**)&assertionConsumerURL);
    return_value =  lasso_node_export_to_ecp_soap_response(node, (const char*) assertionConsumerURL);
    if (assertionConsumerURL)
        g_free(assertionConsumerURL);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  xmlNode* lasso_node_get_xmlNode( LassoNode* node {}, gboolean lasso_dump {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1get_1xmlNode(JNIEnv *env, jclass clss
,jobject jarg1 ,jboolean jarg2 )
  {
    jstring ret;
    LassoNode* node = NULL;
    gboolean lasso_dump;
    xmlNode* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    lasso_dump = (gboolean)jarg2;
    return_value =  lasso_node_get_xmlNode(node, lasso_dump);
    xml_node_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  xmlNode* lasso_node_get_original_xmlnode( LassoNode* node {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1get_1original_1xmlnode(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoNode* node = NULL;
    xmlNode* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    return_value =  lasso_node_get_original_xmlnode(node);
    xml_node_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  void lasso_node_set_original_xmlnode( LassoNode* node {}, xmlNode* xmlnode {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1set_1original_1xmlnode(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    LassoNode* node = NULL;
    xmlNode* xmlnode = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    jstring_to_xml_node(env, jarg2, &xmlnode);
    lasso_node_set_original_xmlnode(node, xmlnode);
  }
/* Wrapper function for  void lasso_node_set_custom_namespace( LassoNode* node {}, const char* prefix {}, const char* href {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1set_1custom_1namespace(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    LassoNode* node = NULL;
    char* prefix = NULL;
    char* href = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    jstring_to_string(env, jarg2, (char**)&prefix);
    jstring_to_string(env, jarg3, (char**)&href);
    lasso_node_set_custom_namespace(node, (const char*) prefix, (const char*) href);
    if (prefix)
        g_free(prefix);
    if (href)
        g_free(href);
  }
/* Wrapper function for  void lasso_node_set_custom_nodename( LassoNode* node {}, const char* nodename {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1set_1custom_1nodename(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    LassoNode* node = NULL;
    char* nodename = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    jstring_to_string(env, jarg2, (char**)&nodename);
    lasso_node_set_custom_nodename(node, (const char*) nodename);
    if (nodename)
        g_free(nodename);
  }
/* Wrapper function for  const char* lasso_node_get_name( LassoNode* node {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1get_1name(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoNode* node = NULL;
    const char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    return_value =  lasso_node_get_name(node);
    string_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  const char* lasso_node_get_namespace( LassoNode* node {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1get_1namespace(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoNode* node = NULL;
    const char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    return_value =  lasso_node_get_namespace(node);
    string_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  LassoMessageFormat lasso_node_init_from_message( LassoNode* node {}, const char* message {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1init_1from_1message(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoNode* node = NULL;
    char* message = NULL;
    LassoMessageFormat return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    jstring_to_string(env, jarg2, (char**)&message);
    return_value =  lasso_node_init_from_message(node, (const char*) message);
    if (message)
        g_free(message);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_node_init_from_query( LassoNode* node {}, const char* query {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1init_1from_1query(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jboolean ret;
    LassoNode* node = NULL;
    char* query = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    jstring_to_string(env, jarg2, (char**)&query);
    return_value =  lasso_node_init_from_query(node, (const char*) query);
    if (query)
        g_free(query);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_node_init_from_xml( LassoNode* node {}, xmlNode* xmlnode {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1init_1from_1xml(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoNode* node = NULL;
    xmlNode* xmlnode = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    jstring_to_xml_node(env, jarg2, &xmlnode);
    return_value =  lasso_node_init_from_xml(node, xmlnode);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  char* lasso_node_debug( LassoNode* node {}, int level {'default': 'c:10', 'optional': True}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_node_1debug(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 )
  {
    jstring ret;
    LassoNode* node = NULL;
    int level;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    level = (int)jarg2;
    return_value =  lasso_node_debug(node, level);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_key_query_verify( LassoKey* key {}, const char* query {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_key_1query_1verify(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoKey* key = NULL;
    char* query = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&key);
    jstring_to_string(env, jarg2, (char**)&query);
    return_value =  lasso_key_query_verify(key, (const char*) query);
    if (query)
        g_free(query);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  char* lasso_key_query_sign( LassoKey* key {}, const char* query {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_key_1query_1sign(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jstring ret;
    LassoKey* key = NULL;
    char* query = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&key);
    jstring_to_string(env, jarg2, (char**)&query);
    return_value =  lasso_key_query_sign(key, (const char*) query);
    if (query)
        g_free(query);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_key_saml2_xml_verify( LassoKey* key {}, char* id {}, xmlNode* document {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_key_1saml2_1xml_1verify(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    jint ret;
    LassoKey* key = NULL;
    char* id = NULL;
    xmlNode* document = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&key);
    jstring_to_string(env, jarg2, (char**)&id);
    jstring_to_xml_node(env, jarg3, &document);
    return_value =  lasso_key_saml2_xml_verify(key, id, document);
    if (id)
        g_free(id);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  xmlNode* lasso_key_saml2_xml_sign( LassoKey* key {}, const char* id {}, xmlNode* document {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_key_1saml2_1xml_1sign(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    jstring ret;
    LassoKey* key = NULL;
    char* id = NULL;
    xmlNode* document = NULL;
    xmlNode* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&key);
    jstring_to_string(env, jarg2, (char**)&id);
    jstring_to_xml_node(env, jarg3, &document);
    return_value =  lasso_key_saml2_xml_sign(key, (const char*) id, document);
    if (id)
        g_free(id);
    xml_node_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  gboolean lasso_saml_name_identifier_equals( LassoSamlNameIdentifier* a {}, LassoSamlNameIdentifier* b {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_saml_1name_1identifier_1equals(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jboolean ret;
    LassoSamlNameIdentifier* a = NULL;
    LassoSamlNameIdentifier* b = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&a);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&b);
    return_value =  lasso_saml_name_identifier_equals(a, b);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  void lasso_misc_text_node_set_xml_content( LassoMiscTextNode* misc_text_node {}, xmlNode* node {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_misc_1text_1node_1set_1xml_1content(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    LassoMiscTextNode* misc_text_node = NULL;
    xmlNode* node = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&misc_text_node);
    jstring_to_xml_node(env, jarg2, &node);
    lasso_misc_text_node_set_xml_content(misc_text_node, node);
  }
/* Wrapper function for  xmlNode* lasso_misc_text_node_get_xml_content( LassoMiscTextNode* misc_text_node {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_misc_1text_1node_1get_1xml_1content(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoMiscTextNode* misc_text_node = NULL;
    xmlNode* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&misc_text_node);
    return_value =  lasso_misc_text_node_get_xml_content(misc_text_node);
    xml_node_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  int lasso_paos_response_validate( LassoPaosResponse* node {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_paos_1response_1validate(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoPaosResponse* node = NULL;
    int return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    return_value =  lasso_paos_response_validate(node);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  int lasso_paos_request_validate( LassoPaosRequest* node {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_paos_1request_1validate(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoPaosRequest* node = NULL;
    int return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&node);
    return_value =  lasso_paos_request_validate(node);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  void lasso_samlp_response_abstract_fill( LassoSamlpResponseAbstract* response {}, const char* InResponseTo {}, const char* Recipient {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp_1response_1abstract_1fill(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    LassoSamlpResponseAbstract* response = NULL;
    char* InResponseTo = NULL;
    char* Recipient = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&response);
    jstring_to_string(env, jarg2, (char**)&InResponseTo);
    jstring_to_string(env, jarg3, (char**)&Recipient);
    lasso_samlp_response_abstract_fill(response, (const char*) InResponseTo, (const char*) Recipient);
    if (InResponseTo)
        g_free(InResponseTo);
    if (Recipient)
        g_free(Recipient);
  }
/* Wrapper function for  void lasso_lib_logout_request_set_session_indexes( LassoLibLogoutRequest* lib_logout_request {}, GList* session_indexes {'element-type': 'string'}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1logout_1request_1set_1session_1indexes(JNIEnv *env, jclass clss
,jobject jarg1 ,jobjectArray jarg2 )
  {
    LassoLibLogoutRequest* lib_logout_request = NULL;
    GList* session_indexes = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&lib_logout_request);
    set_list_of_strings(env, &session_indexes,jarg2);
    lasso_lib_logout_request_set_session_indexes(lib_logout_request, session_indexes);
    free_glist(&session_indexes, (GFunc)free);
  }
/* Wrapper function for  GList* lasso_lib_logout_request_get_session_indexes( LassoLibLogoutRequest* lib_logout_request {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_lib_1logout_1request_1get_1session_1indexes(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jobjectArray ret;
    LassoLibLogoutRequest* lib_logout_request = NULL;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&lib_logout_request);
    return_value =  lasso_lib_logout_request_get_session_indexes(lib_logout_request);
    get_list_of_strings(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  gboolean lasso_saml2_name_id_equals( LassoSaml2NameID* name_id {}, LassoSaml2NameID* other_name_id {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1name_1id_1equals(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jboolean ret;
    LassoSaml2NameID* name_id = NULL;
    LassoSaml2NameID* other_name_id = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_id);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&other_name_id);
    return_value =  lasso_saml2_name_id_equals(name_id, other_name_id);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_saml2_assertion_has_audience_restriction( LassoSaml2Assertion* saml2_assertion {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1has_1audience_1restriction(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jboolean ret;
    LassoSaml2Assertion* saml2_assertion = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    return_value =  lasso_saml2_assertion_has_audience_restriction(saml2_assertion);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_saml2_assertion_is_audience_restricted( LassoSaml2Assertion* saml2_assertion {}, char* providerID {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1is_1audience_1restricted(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jboolean ret;
    LassoSaml2Assertion* saml2_assertion = NULL;
    char* providerID = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    jstring_to_string(env, jarg2, (char**)&providerID);
    return_value =  lasso_saml2_assertion_is_audience_restricted(saml2_assertion, providerID);
    if (providerID)
        g_free(providerID);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  void lasso_saml2_assertion_set_subject_name_id( LassoSaml2Assertion* saml2_assertion {}, LassoNode* node {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1set_1subject_1name_1id(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    LassoSaml2Assertion* saml2_assertion = NULL;
    LassoNode* node = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&node);
    lasso_saml2_assertion_set_subject_name_id(saml2_assertion, node);
  }
/* Wrapper function for  void lasso_saml2_assertion_set_subject_confirmation_name_id( LassoSaml2Assertion* saml2_assertion {}, LassoNode* node {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1set_1subject_1confirmation_1name_1id(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    LassoSaml2Assertion* saml2_assertion = NULL;
    LassoNode* node = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&node);
    lasso_saml2_assertion_set_subject_confirmation_name_id(saml2_assertion, node);
  }
/* Wrapper function for  void lasso_saml2_assertion_set_subject_confirmation_data( LassoSaml2Assertion* saml2_assertion {}, time_t tolerance {}, time_t length {}, const char* Recipient {}, const char* InResponseTo {}, const char* Address {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1set_1subject_1confirmation_1data(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jint jarg3 ,jstring jarg4 ,jstring jarg5 ,jstring jarg6 )
  {
    LassoSaml2Assertion* saml2_assertion = NULL;
    time_t tolerance;
    time_t length;
    char* Recipient = NULL;
    char* InResponseTo = NULL;
    char* Address = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    tolerance = (time_t)jarg2;
    length = (time_t)jarg3;
    jstring_to_string(env, jarg4, (char**)&Recipient);
    jstring_to_string(env, jarg5, (char**)&InResponseTo);
    jstring_to_string(env, jarg6, (char**)&Address);
    lasso_saml2_assertion_set_subject_confirmation_data(saml2_assertion, tolerance, length, (const char*) Recipient, (const char*) InResponseTo, (const char*) Address);
    if (Recipient)
        g_free(Recipient);
    if (InResponseTo)
        g_free(InResponseTo);
    if (Address)
        g_free(Address);
  }
/* Wrapper function for  void lasso_saml2_assertion_set_basic_conditions( LassoSaml2Assertion* saml2_assertion {}, time_t tolerance {'default': 'c:-1', 'optional': True}, time_t length {'default': 'c:-1', 'optional': True}, gboolean one_time_use {'default': 'b:FALSE', 'optional': True}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1set_1basic_1conditions(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jint jarg3 ,jboolean jarg4 )
  {
    LassoSaml2Assertion* saml2_assertion = NULL;
    time_t tolerance;
    time_t length;
    gboolean one_time_use;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    tolerance = (time_t)jarg2;
    length = (time_t)jarg3;
    one_time_use = (gboolean)jarg4;
    lasso_saml2_assertion_set_basic_conditions(saml2_assertion, tolerance, length, one_time_use);
  }
/* Wrapper function for  void lasso_saml2_assertion_add_audience_restriction( LassoSaml2Assertion* saml2_assertion {}, const char* providerID {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1add_1audience_1restriction(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    LassoSaml2Assertion* saml2_assertion = NULL;
    char* providerID = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    jstring_to_string(env, jarg2, (char**)&providerID);
    lasso_saml2_assertion_add_audience_restriction(saml2_assertion, (const char*) providerID);
    if (providerID)
        g_free(providerID);
  }
/* Wrapper function for  void lasso_saml2_assertion_add_proxy_limit( LassoSaml2Assertion* saml2_assertion {}, int proxy_count {'default': 'c:-1', 'optional': True}, GList* proxy_audiences {'optional': True, 'element-type': 'string'}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1add_1proxy_1limit(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jobjectArray jarg3 )
  {
    LassoSaml2Assertion* saml2_assertion = NULL;
    int proxy_count;
    GList* proxy_audiences = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    proxy_count = (int)jarg2;
    set_list_of_strings(env, &proxy_audiences,jarg3);
    lasso_saml2_assertion_add_proxy_limit(saml2_assertion, proxy_count, proxy_audiences);
    free_glist(&proxy_audiences, (GFunc)free);
  }
/* Wrapper function for  LassoSaml2AssertionValidationState lasso_saml2_assertion_validate_conditions( LassoSaml2Assertion* saml2_assertion {}, const char* relaying_party_providerID {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1validate_1conditions(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoSaml2Assertion* saml2_assertion = NULL;
    char* relaying_party_providerID = NULL;
    LassoSaml2AssertionValidationState return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    jstring_to_string(env, jarg2, (char**)&relaying_party_providerID);
    return_value =  lasso_saml2_assertion_validate_conditions(saml2_assertion, (const char*) relaying_party_providerID);
    if (relaying_party_providerID)
        g_free(relaying_party_providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoProvider* lasso_saml2_assertion_get_issuer_provider( const LassoSaml2Assertion* saml2_assertion {}, const LassoServer* server {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1get_1issuer_1provider(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jobject ret;
    LassoSaml2Assertion* saml2_assertion = NULL;
    LassoServer* server = NULL;
    LassoProvider* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&server);
    return_value =  lasso_saml2_assertion_get_issuer_provider((const LassoSaml2Assertion*) saml2_assertion, (const LassoServer*) server);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_saml2_assertion_add_attribute_with_node( LassoSaml2Assertion* assertion {}, const char* name {}, const char* nameformat {}, LassoNode* content {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1add_1attribute_1with_1node(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 ,jobject jarg4 )
  {
    jint ret;
    LassoSaml2Assertion* assertion = NULL;
    char* name = NULL;
    char* nameformat = NULL;
    LassoNode* content = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion);
    jstring_to_string(env, jarg2, (char**)&name);
    jstring_to_string(env, jarg3, (char**)&nameformat);
    jobject_to_gobject_noref(env, jarg4, (GObject**)&content);
    return_value =  lasso_saml2_assertion_add_attribute_with_node(assertion, (const char*) name, (const char*) nameformat, content);
    if (name)
        g_free(name);
    if (nameformat)
        g_free(nameformat);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoSaml2SubjectConfirmationData* lasso_saml2_assertion_get_subject_confirmation_data( LassoSaml2Assertion* saml2_assertion {}, gboolean create {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1get_1subject_1confirmation_1data(JNIEnv *env, jclass clss
,jobject jarg1 ,jboolean jarg2 )
  {
    jobject ret;
    LassoSaml2Assertion* saml2_assertion = NULL;
    gboolean create;
    LassoSaml2SubjectConfirmationData* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    create = (gboolean)jarg2;
    return_value =  lasso_saml2_assertion_get_subject_confirmation_data(saml2_assertion, create);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  const char* lasso_saml2_assertion_get_in_response_to( LassoSaml2Assertion* assertion {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1get_1in_1response_1to(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoSaml2Assertion* assertion = NULL;
    const char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion);
    return_value =  lasso_saml2_assertion_get_in_response_to(assertion);
    string_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_saml2_assertion_decrypt_subject( LassoSaml2Assertion* assertion {}, LassoServer* server {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1decrypt_1subject(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jint ret;
    LassoSaml2Assertion* assertion = NULL;
    LassoServer* server = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&server);
    return_value =  lasso_saml2_assertion_decrypt_subject(assertion, server);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoSaml2AssertionValidationState lasso_saml2_assertion_validate_time_checks( LassoSaml2Assertion* saml2_assertion {}, unsigned int tolerance {}, time_t now {'default': 'c:0', 'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1validate_1time_1checks(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jint jarg3 )
  {
    jint ret;
    LassoSaml2Assertion* saml2_assertion = NULL;
    unsigned int tolerance;
    time_t now;
    LassoSaml2AssertionValidationState return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    tolerance = (unsigned int)jarg2;
    now = (time_t)jarg3;
    return_value =  lasso_saml2_assertion_validate_time_checks(saml2_assertion, tolerance, now);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoSaml2AssertionValidationState lasso_saml2_assertion_validate_audience( LassoSaml2Assertion* saml2_assertion {}, const gchar* audience {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1validate_1audience(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoSaml2Assertion* saml2_assertion = NULL;
    gchar* audience = NULL;
    LassoSaml2AssertionValidationState return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    jstring_to_string(env, jarg2, (char**)&audience);
    return_value =  lasso_saml2_assertion_validate_audience(saml2_assertion, (const gchar*) audience);
    if (audience)
        g_free(audience);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_saml2_assertion_has_one_time_use( LassoSaml2Assertion* saml2_assertion {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1has_1one_1time_1use(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jboolean ret;
    LassoSaml2Assertion* saml2_assertion = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    return_value =  lasso_saml2_assertion_has_one_time_use(saml2_assertion);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  LassoSaml2AssertionValidationState lasso_saml2_assertion_allows_proxying( LassoSaml2Assertion* saml2_assertion {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1allows_1proxying(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoSaml2Assertion* saml2_assertion = NULL;
    LassoSaml2AssertionValidationState return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    return_value =  lasso_saml2_assertion_allows_proxying(saml2_assertion);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoSaml2AssertionValidationState lasso_saml2_assertion_allows_proxying_to( LassoSaml2Assertion* saml2_assertion {}, const char* audience {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1allows_1proxying_1to(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoSaml2Assertion* saml2_assertion = NULL;
    char* audience = NULL;
    LassoSaml2AssertionValidationState return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    jstring_to_string(env, jarg2, (char**)&audience);
    return_value =  lasso_saml2_assertion_allows_proxying_to(saml2_assertion, (const char*) audience);
    if (audience)
        g_free(audience);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  void lasso_saml2_assertion_set_one_time_use( LassoSaml2Assertion* saml2_assertion {}, gboolean one_time_use {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1assertion_1set_1one_1time_1use(JNIEnv *env, jclass clss
,jobject jarg1 ,jboolean jarg2 )
  {
    LassoSaml2Assertion* saml2_assertion = NULL;
    gboolean one_time_use;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&saml2_assertion);
    one_time_use = (gboolean)jarg2;
    lasso_saml2_assertion_set_one_time_use(saml2_assertion, one_time_use);
  }
/* Wrapper function for  lasso_error_t lasso_saml2_encrypted_element_server_decrypt( LassoSaml2EncryptedElement* encrypted_element {}, LassoServer* server {}, LassoNode** decrypted_node {'out': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1encrypted_1element_1server_1decrypt(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 ,jobject jarg3 )
  {
    jint ret;
    LassoSaml2EncryptedElement* encrypted_element = NULL;
    LassoServer* server = NULL;
    LassoNode** decrypted_node = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&encrypted_element);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&server);
    jobject_to_gobject_noref(env, jarg3, (GObject**)&decrypted_node);
    return_value =  lasso_saml2_encrypted_element_server_decrypt(encrypted_element, server, decrypted_node);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  GList* lasso_samlp2_logout_request_get_session_indexes( LassoSamlp2LogoutRequest* logout_request {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1logout_1request_1get_1session_1indexes(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jobjectArray ret;
    LassoSamlp2LogoutRequest* logout_request = NULL;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout_request);
    return_value =  lasso_samlp2_logout_request_get_session_indexes(logout_request);
    get_list_of_strings(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  void lasso_samlp2_logout_request_set_session_indexes( LassoSamlp2LogoutRequest* logout_request {}, GList* session_index {'element-type': 'char*'}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_samlp2_1logout_1request_1set_1session_1indexes(JNIEnv *env, jclass clss
,jobject jarg1 ,jobjectArray jarg2 )
  {
    LassoSamlp2LogoutRequest* logout_request = NULL;
    GList* session_index = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout_request);
    set_list_of_strings(env, &session_index,jarg2);
    lasso_samlp2_logout_request_set_session_indexes(logout_request, session_index);
    free_glist(&session_index, (GFunc)free);
  }
/* Wrapper function for  GList* lasso_saml2_key_info_confirmation_data_type_get_key_info( LassoSaml2KeyInfoConfirmationDataType* kicdt {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1key_1info_1confirmation_1data_1type_1get_1key_1info(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jobjectArray ret;
    LassoSaml2KeyInfoConfirmationDataType* kicdt = NULL;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&kicdt);
    return_value =  lasso_saml2_key_info_confirmation_data_type_get_key_info(kicdt);
    get_list_of_objects(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  void lasso_saml2_key_info_confirmation_data_type_set_key_info( LassoSaml2KeyInfoConfirmationDataType* kicdt {}, GList* key_infos {'element-type': 'LassoDsKeyInfo'}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_saml2_1key_1info_1confirmation_1data_1type_1set_1key_1info(JNIEnv *env, jclass clss
,jobject jarg1 ,jobjectArray jarg2 )
  {
    LassoSaml2KeyInfoConfirmationDataType* kicdt = NULL;
    GList* key_infos = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&kicdt);
    set_list_of_objects(env, &key_infos, jarg2);
    lasso_saml2_key_info_confirmation_data_type_set_key_info(kicdt, key_infos);
    free_glist(&key_infos, (GFunc)g_object_unref);
  }
/* Wrapper function for  int lasso_ecp_request_validate( LassoEcpRequest* request {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1request_1validate(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoEcpRequest* request = NULL;
    int return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&request);
    return_value =  lasso_ecp_request_validate(request);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  int lasso_ecp_response_validate( LassoEcpResponse* response {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1response_1validate(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoEcpResponse* response = NULL;
    int return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&response);
    return_value =  lasso_ecp_response_validate(response);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  int lasso_ecp_relay_state_validate( LassoEcpRelayState* relaystate {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1relay_1state_1validate(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoEcpRelayState* relaystate = NULL;
    int return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&relaystate);
    return_value =  lasso_ecp_relay_state_validate(relaystate);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoDsX509Data* lasso_ds_key_value_get_x509_data( LassoDsKeyValue* key_value {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1key_1value_1get_1x509_1data(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jobject ret;
    LassoDsKeyValue* key_value = NULL;
    LassoDsX509Data* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&key_value);
    return_value =  lasso_ds_key_value_get_x509_data(key_value);
    gobject_to_jobject_and_ref(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  void lasso_ds_key_value_set_x509_data( LassoDsKeyValue* key_value {}, LassoDsX509Data* x509_data {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1key_1value_1set_1x509_1data(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    LassoDsKeyValue* key_value = NULL;
    LassoDsX509Data* x509_data = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&key_value);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&x509_data);
    lasso_ds_key_value_set_x509_data(key_value, x509_data);
  }
/* Wrapper function for  const char* lasso_ds_x509_data_get_certificate( LassoDsX509Data* x509_data {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1x509_1data_1get_1certificate(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoDsX509Data* x509_data = NULL;
    const char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&x509_data);
    return_value =  lasso_ds_x509_data_get_certificate(x509_data);
    string_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  void lasso_ds_x509_data_set_certificate( LassoDsX509Data* x509_data {}, const char* certificate {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1x509_1data_1set_1certificate(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    LassoDsX509Data* x509_data = NULL;
    char* certificate = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&x509_data);
    jstring_to_string(env, jarg2, (char**)&certificate);
    lasso_ds_x509_data_set_certificate(x509_data, (const char*) certificate);
    if (certificate)
        g_free(certificate);
  }
/* Wrapper function for  const char* lasso_ds_x509_data_get_subject_name( LassoDsX509Data* x509_data {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1x509_1data_1get_1subject_1name(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoDsX509Data* x509_data = NULL;
    const char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&x509_data);
    return_value =  lasso_ds_x509_data_get_subject_name(x509_data);
    string_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  void lasso_ds_x509_data_set_subject_name( LassoDsX509Data* x509_data {}, const char* subject_name {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1x509_1data_1set_1subject_1name(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    LassoDsX509Data* x509_data = NULL;
    char* subject_name = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&x509_data);
    jstring_to_string(env, jarg2, (char**)&subject_name);
    lasso_ds_x509_data_set_subject_name(x509_data, (const char*) subject_name);
    if (subject_name)
        g_free(subject_name);
  }
/* Wrapper function for  const char* lasso_ds_x509_data_get_crl( LassoDsX509Data* x509_data {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1x509_1data_1get_1crl(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoDsX509Data* x509_data = NULL;
    const char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&x509_data);
    return_value =  lasso_ds_x509_data_get_crl(x509_data);
    string_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  void lasso_ds_x509_data_set_crl( LassoDsX509Data* x509_data {}, const char* crl {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_ds_1x509_1data_1set_1crl(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    LassoDsX509Data* x509_data = NULL;
    char* crl = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&x509_data);
    jstring_to_string(env, jarg2, (char**)&crl);
    lasso_ds_x509_data_set_crl(x509_data, (const char*) crl);
    if (crl)
        g_free(crl);
  }
/* Wrapper function for  void lasso_federation_build_local_name_identifier( LassoFederation* federation {}, const gchar* nameQualifier {}, const gchar* format {}, const gchar* content {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_federation_1build_1local_1name_1identifier(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 ,jstring jarg4 )
  {
    LassoFederation* federation = NULL;
    gchar* nameQualifier = NULL;
    gchar* format = NULL;
    gchar* content = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&federation);
    jstring_to_string(env, jarg2, (char**)&nameQualifier);
    jstring_to_string(env, jarg3, (char**)&format);
    jstring_to_string(env, jarg4, (char**)&content);
    lasso_federation_build_local_name_identifier(federation, (const gchar*) nameQualifier, (const gchar*) format, (const gchar*) content);
    if (nameQualifier)
        g_free(nameQualifier);
    if (format)
        g_free(format);
    if (content)
        g_free(content);
  }
/* Wrapper function for  gboolean lasso_federation_verify_name_identifier( LassoFederation* federation {}, LassoNode* name_identifier {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_federation_1verify_1name_1identifier(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jboolean ret;
    LassoFederation* federation = NULL;
    LassoNode* name_identifier = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&federation);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&name_identifier);
    return_value =  lasso_federation_verify_name_identifier(federation, name_identifier);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  LassoIdentity* lasso_profile_get_identity( LassoProfile* profile {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1identity(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jobject ret;
    LassoProfile* profile = NULL;
    LassoIdentity* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_get_identity(profile);
    gobject_to_jobject_and_ref(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  LassoSession* lasso_profile_get_session( LassoProfile* profile {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1session(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jobject ret;
    LassoProfile* profile = NULL;
    LassoSession* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_get_session(profile);
    gobject_to_jobject_and_ref(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  gboolean lasso_profile_is_identity_dirty( LassoProfile* profile {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_lasso_1profile_1has_1dirty_1identity(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jboolean ret;
    LassoProfile* profile = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_is_identity_dirty(profile);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_profile_is_session_dirty( LassoProfile* profile {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_lasso_1profile_1has_1dirty_1session(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jboolean ret;
    LassoProfile* profile = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_is_session_dirty(profile);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_profile_set_identity_from_dump( LassoProfile* profile {}, const gchar* dump {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1set_1identity_1from_1dump(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoProfile* profile = NULL;
    gchar* dump = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    jstring_to_string(env, jarg2, (char**)&dump);
    return_value =  lasso_profile_set_identity_from_dump(profile, (const gchar*) dump);
    if (dump)
        g_free(dump);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_profile_set_session_from_dump( LassoProfile* profile {}, const gchar* dump {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1set_1session_1from_1dump(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoProfile* profile = NULL;
    gchar* dump = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    jstring_to_string(env, jarg2, (char**)&dump);
    return_value =  lasso_profile_set_session_from_dump(profile, (const gchar*) dump);
    if (dump)
        g_free(dump);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_profile_get_nameIdentifier( LassoProfile* profile {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_lasso_1profile_1get_1federation_1nameIdentifier(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jobject ret;
    LassoProfile* profile = NULL;
    LassoNode* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_get_nameIdentifier(profile);
    gobject_to_jobject_and_ref(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  char* lasso_profile_get_artifact( LassoProfile* profile {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1artifact(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoProfile* profile = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_get_artifact(profile);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_profile_get_artifact_message( LassoProfile* profile {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1artifact_1message(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoProfile* profile = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_get_artifact_message(profile);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  void lasso_profile_set_artifact_message( LassoProfile* profile {}, const char* message {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1set_1artifact_1message(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    LassoProfile* profile = NULL;
    char* message = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    jstring_to_string(env, jarg2, (char**)&message);
    lasso_profile_set_artifact_message(profile, (const char*) message);
    if (message)
        g_free(message);
  }
/* Wrapper function for  void lasso_profile_set_signature_hint( LassoProfile* profile {}, LassoProfileSignatureHint signature_hint {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1set_1signature_1hint(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 )
  {
    LassoProfile* profile = NULL;
    LassoProfileSignatureHint signature_hint;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    signature_hint = (LassoProfileSignatureHint)jarg2;
    lasso_profile_set_signature_hint(profile, signature_hint);
  }
/* Wrapper function for  LassoProfileSignatureHint lasso_profile_get_signature_hint( LassoProfile* profile {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1signature_1hint(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoProfile* profile = NULL;
    LassoProfileSignatureHint return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_get_signature_hint(profile);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_profile_set_soap_fault_response( LassoProfile* profile {}, const char* faultcode {}, const char* faultstring {'optional': True}, GList* details {'optional': True, 'element-type': 'LassoNode'}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1set_1soap_1fault_1response(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 ,jobjectArray jarg4 )
  {
    jint ret;
    LassoProfile* profile = NULL;
    char* faultcode = NULL;
    char* faultstring = NULL;
    GList* details = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    jstring_to_string(env, jarg2, (char**)&faultcode);
    jstring_to_string(env, jarg3, (char**)&faultstring);
    set_list_of_objects(env, &details, jarg4);
    return_value =  lasso_profile_set_soap_fault_response(profile, (const char*) faultcode, (const char*) faultstring, details);
    if (faultcode)
        g_free(faultcode);
    if (faultstring)
        g_free(faultstring);
    free_glist(&details, (GFunc)g_object_unref);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  void lasso_profile_set_signature_verify_hint( LassoProfile* profile {}, LassoProfileSignatureVerifyHint signature_verify_hint {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1set_1signature_1verify_1hint(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 )
  {
    LassoProfile* profile = NULL;
    LassoProfileSignatureVerifyHint signature_verify_hint;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    signature_verify_hint = (LassoProfileSignatureVerifyHint)jarg2;
    lasso_profile_set_signature_verify_hint(profile, signature_verify_hint);
  }
/* Wrapper function for  LassoProfileSignatureVerifyHint lasso_profile_get_signature_verify_hint( LassoProfile* profile {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1signature_1verify_1hint(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoProfile* profile = NULL;
    LassoProfileSignatureVerifyHint return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_get_signature_verify_hint(profile);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoProviderRole lasso_profile_sso_role_with( LassoProfile* profile {}, const char* remote_provider_id {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1sso_1role_1with(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoProfile* profile = NULL;
    char* remote_provider_id = NULL;
    LassoProviderRole return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    jstring_to_string(env, jarg2, (char**)&remote_provider_id);
    return_value =  lasso_profile_sso_role_with(profile, (const char*) remote_provider_id);
    if (remote_provider_id)
        g_free(remote_provider_id);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_profile_get_signature_status( LassoProfile* profile {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1signature_1status(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoProfile* profile = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_get_signature_status(profile);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  char* lasso_profile_get_message_id( LassoProfile* profile {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1message_1id(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoProfile* profile = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_get_message_id(profile);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  void lasso_profile_set_message_id( LassoProfile* profile {}, const char* message_id {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1set_1message_1id(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    LassoProfile* profile = NULL;
    char* message_id = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    jstring_to_string(env, jarg2, (char**)&message_id);
    lasso_profile_set_message_id(profile, (const char*) message_id);
    if (message_id)
        g_free(message_id);
  }
/* Wrapper function for  LassoNode* lasso_profile_get_idp_list( LassoProfile* profile {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1get_1idp_1list(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jobject ret;
    LassoProfile* profile = NULL;
    LassoNode* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    return_value =  lasso_profile_get_idp_list(profile);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  void lasso_profile_set_idp_list( LassoProfile* profile {}, const LassoNode* idp_list {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_profile_1set_1idp_1list(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    LassoProfile* profile = NULL;
    LassoNode* idp_list = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&profile);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&idp_list);
    lasso_profile_set_idp_list(profile, (const LassoNode*) idp_list);
  }
/* Wrapper function for  char* lasso_name_id_management_dump( LassoNameIdManagement* name_id_management {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1id_1management_1dump(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoNameIdManagement* name_id_management = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_id_management);
    return_value =  lasso_name_id_management_dump(name_id_management);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_id_management_init_request( LassoNameIdManagement* name_id_management {}, char* remote_provider_id {'optional': True}, char* new_name_id {'optional': True}, LassoHttpMethod http_method {'optional': True, 'default': 'c:LASSO_HTTP_METHOD_ANY'}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1id_1management_1init_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 ,jint jarg4 )
  {
    jint ret;
    LassoNameIdManagement* name_id_management = NULL;
    char* remote_provider_id = NULL;
    char* new_name_id = NULL;
    LassoHttpMethod http_method;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_id_management);
    jstring_to_string(env, jarg2, (char**)&remote_provider_id);
    jstring_to_string(env, jarg3, (char**)&new_name_id);
    http_method = (LassoHttpMethod)jarg4;
    return_value =  lasso_name_id_management_init_request(name_id_management, remote_provider_id, new_name_id, http_method);
    if (remote_provider_id)
        g_free(remote_provider_id);
    if (new_name_id)
        g_free(new_name_id);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_id_management_build_request_msg( LassoNameIdManagement* name_id_management {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1id_1management_1build_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoNameIdManagement* name_id_management = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_id_management);
    return_value =  lasso_name_id_management_build_request_msg(name_id_management);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_id_management_process_request_msg( LassoNameIdManagement* name_id_management {}, gchar* request_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1id_1management_1process_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoNameIdManagement* name_id_management = NULL;
    gchar* request_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_id_management);
    jstring_to_string(env, jarg2, (char**)&request_msg);
    return_value =  lasso_name_id_management_process_request_msg(name_id_management, request_msg);
    if (request_msg)
        g_free(request_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_id_management_validate_request( LassoNameIdManagement* name_id_management {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1id_1management_1validate_1request(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoNameIdManagement* name_id_management = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_id_management);
    return_value =  lasso_name_id_management_validate_request(name_id_management);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_id_management_build_response_msg( LassoNameIdManagement* name_id_management {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1id_1management_1build_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoNameIdManagement* name_id_management = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_id_management);
    return_value =  lasso_name_id_management_build_response_msg(name_id_management);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_id_management_process_response_msg( LassoNameIdManagement* name_id_management {}, gchar* response_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1id_1management_1process_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoNameIdManagement* name_id_management = NULL;
    gchar* response_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_id_management);
    jstring_to_string(env, jarg2, (char**)&response_msg);
    return_value =  lasso_name_id_management_process_response_msg(name_id_management, response_msg);
    if (response_msg)
        g_free(response_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_assertion_query_init_request( LassoAssertionQuery* assertion_query {}, char* remote_provider_id {'optional': True}, LassoHttpMethod http_method {}, LassoAssertionQueryRequestType query_request_type {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_assertion_1query_1init_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jint jarg3 ,jint jarg4 )
  {
    jint ret;
    LassoAssertionQuery* assertion_query = NULL;
    char* remote_provider_id = NULL;
    LassoHttpMethod http_method;
    LassoAssertionQueryRequestType query_request_type;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion_query);
    jstring_to_string(env, jarg2, (char**)&remote_provider_id);
    http_method = (LassoHttpMethod)jarg3;
    query_request_type = (LassoAssertionQueryRequestType)jarg4;
    return_value =  lasso_assertion_query_init_request(assertion_query, remote_provider_id, http_method, query_request_type);
    if (remote_provider_id)
        g_free(remote_provider_id);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_assertion_query_validate_request( LassoAssertionQuery* assertion_query {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_assertion_1query_1validate_1request(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoAssertionQuery* assertion_query = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion_query);
    return_value =  lasso_assertion_query_validate_request(assertion_query);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_assertion_query_build_request_msg( LassoAssertionQuery* assertion_query {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_assertion_1query_1build_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoAssertionQuery* assertion_query = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion_query);
    return_value =  lasso_assertion_query_build_request_msg(assertion_query);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_assertion_query_process_request_msg( LassoAssertionQuery* assertion_query {}, gchar* request_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_assertion_1query_1process_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoAssertionQuery* assertion_query = NULL;
    gchar* request_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion_query);
    jstring_to_string(env, jarg2, (char**)&request_msg);
    return_value =  lasso_assertion_query_process_request_msg(assertion_query, request_msg);
    if (request_msg)
        g_free(request_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_assertion_query_build_response_msg( LassoAssertionQuery* assertion_query {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_assertion_1query_1build_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoAssertionQuery* assertion_query = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion_query);
    return_value =  lasso_assertion_query_build_response_msg(assertion_query);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_assertion_query_process_response_msg( LassoAssertionQuery* assertion_query {}, gchar* response_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_assertion_1query_1process_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoAssertionQuery* assertion_query = NULL;
    gchar* response_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion_query);
    jstring_to_string(env, jarg2, (char**)&response_msg);
    return_value =  lasso_assertion_query_process_response_msg(assertion_query, response_msg);
    if (response_msg)
        g_free(response_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_assertion_query_add_attribute_request( LassoAssertionQuery* assertion_query {}, char* format {}, char* name {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_assertion_1query_1add_1attribute_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    jint ret;
    LassoAssertionQuery* assertion_query = NULL;
    char* format = NULL;
    char* name = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion_query);
    jstring_to_string(env, jarg2, (char**)&format);
    jstring_to_string(env, jarg3, (char**)&name);
    return_value =  lasso_assertion_query_add_attribute_request(assertion_query, format, name);
    if (format)
        g_free(format);
    if (name)
        g_free(name);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoAssertionQueryRequestType lasso_assertion_query_get_request_type( LassoAssertionQuery* assertion_query {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_assertion_1query_1get_1request_1type(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoAssertionQuery* assertion_query = NULL;
    LassoAssertionQueryRequestType return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&assertion_query);
    return_value =  lasso_assertion_query_get_request_type(assertion_query);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_ecp_process_authn_request_msg( LassoEcp* ecp {}, const char* authn_request_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1process_1authn_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoEcp* ecp = NULL;
    char* authn_request_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&ecp);
    jstring_to_string(env, jarg2, (char**)&authn_request_msg);
    return_value =  lasso_ecp_process_authn_request_msg(ecp, (const char*) authn_request_msg);
    if (authn_request_msg)
        g_free(authn_request_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_ecp_process_response_msg( LassoEcp* ecp {}, const char* response_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1process_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoEcp* ecp = NULL;
    char* response_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&ecp);
    jstring_to_string(env, jarg2, (char**)&response_msg);
    return_value =  lasso_ecp_process_response_msg(ecp, (const char*) response_msg);
    if (response_msg)
        g_free(response_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_ecp_is_provider_in_sp_idplist( LassoEcp* ecp {}, const gchar* entity_id {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1is_1provider_1in_1sp_1idplist(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jboolean ret;
    LassoEcp* ecp = NULL;
    gchar* entity_id = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&ecp);
    jstring_to_string(env, jarg2, (char**)&entity_id);
    return_value =  lasso_ecp_is_provider_in_sp_idplist(ecp, (const gchar*) entity_id);
    if (entity_id)
        g_free(entity_id);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_ecp_is_idp_entry_known_idp_supporting_ecp( LassoEcp* ecp {}, const LassoSamlp2IDPEntry* idp_entry {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1is_1idp_1entry_1known_1idp_1supporting_1ecp(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jboolean ret;
    LassoEcp* ecp = NULL;
    LassoSamlp2IDPEntry* idp_entry = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&ecp);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&idp_entry);
    return_value =  lasso_ecp_is_idp_entry_known_idp_supporting_ecp(ecp, (const LassoSamlp2IDPEntry*) idp_entry);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  void lasso_ecp_set_known_sp_provided_idp_entries_supporting_ecp( LassoEcp* ecp {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1set_1known_1sp_1provided_1idp_1entries_1supporting_1ecp(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    LassoEcp* ecp = NULL;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&ecp);
    lasso_ecp_set_known_sp_provided_idp_entries_supporting_ecp(ecp);
  }
/* Wrapper function for  gboolean lasso_ecp_has_sp_idplist( LassoEcp* ecp {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1has_1sp_1idplist(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jboolean ret;
    LassoEcp* ecp = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&ecp);
    return_value =  lasso_ecp_has_sp_idplist(ecp);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  gchar* lasso_ecp_get_endpoint_url_by_entity_id( LassoEcp* ecp {}, const gchar* entity_id {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1get_1endpoint_1url_1by_1entity_1id(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jstring ret;
    LassoEcp* ecp = NULL;
    gchar* entity_id = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&ecp);
    jstring_to_string(env, jarg2, (char**)&entity_id);
    return_value =  lasso_ecp_get_endpoint_url_by_entity_id(ecp, (const gchar*) entity_id);
    if (entity_id)
        g_free(entity_id);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  int lasso_ecp_process_sp_idp_list( LassoEcp* ecp {}, const LassoSamlp2IDPList* sp_idp_list {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_ecp_1process_1sp_1idp_1list(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jint ret;
    LassoEcp* ecp = NULL;
    LassoSamlp2IDPList* sp_idp_list = NULL;
    int return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&ecp);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&sp_idp_list);
    return_value =  lasso_ecp_process_sp_idp_list(ecp, (const LassoSamlp2IDPList*) sp_idp_list);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_accept_sso( LassoLogin* login {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1accept_1sso(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLogin* login = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    return_value =  lasso_login_accept_sso(login);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_build_artifact_msg( LassoLogin* login {}, LassoHttpMethod http_method {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1build_1artifact_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 )
  {
    jint ret;
    LassoLogin* login = NULL;
    LassoHttpMethod http_method;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    http_method = (LassoHttpMethod)jarg2;
    return_value =  lasso_login_build_artifact_msg(login, http_method);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_build_assertion( LassoLogin* login {}, const char* authenticationMethod {'optional': True}, const char* authenticationInstant {'optional': True}, const char* reauthenticateOnOrAfter {'optional': True}, const char* notBefore {'optional': True}, const char* notOnOrAfter {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1build_1assertion(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 ,jstring jarg4 ,jstring jarg5 ,jstring jarg6 )
  {
    jint ret;
    LassoLogin* login = NULL;
    char* authenticationMethod = NULL;
    char* authenticationInstant = NULL;
    char* reauthenticateOnOrAfter = NULL;
    char* notBefore = NULL;
    char* notOnOrAfter = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    jstring_to_string(env, jarg2, (char**)&authenticationMethod);
    jstring_to_string(env, jarg3, (char**)&authenticationInstant);
    jstring_to_string(env, jarg4, (char**)&reauthenticateOnOrAfter);
    jstring_to_string(env, jarg5, (char**)&notBefore);
    jstring_to_string(env, jarg6, (char**)&notOnOrAfter);
    return_value =  lasso_login_build_assertion(login, (const char*) authenticationMethod, (const char*) authenticationInstant, (const char*) reauthenticateOnOrAfter, (const char*) notBefore, (const char*) notOnOrAfter);
    if (authenticationMethod)
        g_free(authenticationMethod);
    if (authenticationInstant)
        g_free(authenticationInstant);
    if (reauthenticateOnOrAfter)
        g_free(reauthenticateOnOrAfter);
    if (notBefore)
        g_free(notBefore);
    if (notOnOrAfter)
        g_free(notOnOrAfter);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_build_authn_request_msg( LassoLogin* login {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1build_1authn_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLogin* login = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    return_value =  lasso_login_build_authn_request_msg(login);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_build_authn_response_msg( LassoLogin* login {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1build_1authn_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLogin* login = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    return_value =  lasso_login_build_authn_response_msg(login);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_build_request_msg( LassoLogin* login {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1build_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLogin* login = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    return_value =  lasso_login_build_request_msg(login);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_build_response_msg( LassoLogin* login {}, gchar* remote_providerID {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1build_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLogin* login = NULL;
    gchar* remote_providerID = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    jstring_to_string(env, jarg2, (char**)&remote_providerID);
    return_value =  lasso_login_build_response_msg(login, remote_providerID);
    if (remote_providerID)
        g_free(remote_providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gchar* lasso_login_dump( LassoLogin* login {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1dump(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoLogin* login = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    return_value =  lasso_login_dump(login);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_init_authn_request( LassoLogin* login {}, const gchar* remote_providerID {'optional': True}, LassoHttpMethod http_method {'optional': True, 'default': 'c:LASSO_HTTP_METHOD_REDIRECT'}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1init_1authn_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jint jarg3 )
  {
    jint ret;
    LassoLogin* login = NULL;
    gchar* remote_providerID = NULL;
    LassoHttpMethod http_method;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    jstring_to_string(env, jarg2, (char**)&remote_providerID);
    http_method = (LassoHttpMethod)jarg3;
    return_value =  lasso_login_init_authn_request(login, (const gchar*) remote_providerID, http_method);
    if (remote_providerID)
        g_free(remote_providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_init_request( LassoLogin* login {}, gchar* response_msg {}, LassoHttpMethod response_http_method {'optional': True, 'default': 'c:LASSO_HTTP_METHOD_REDIRECT'}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1init_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jint jarg3 )
  {
    jint ret;
    LassoLogin* login = NULL;
    gchar* response_msg = NULL;
    LassoHttpMethod response_http_method;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    jstring_to_string(env, jarg2, (char**)&response_msg);
    response_http_method = (LassoHttpMethod)jarg3;
    return_value =  lasso_login_init_request(login, response_msg, response_http_method);
    if (response_msg)
        g_free(response_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_init_idp_initiated_authn_request( LassoLogin* login {}, const gchar* remote_providerID {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1init_1idp_1initiated_1authn_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLogin* login = NULL;
    gchar* remote_providerID = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    jstring_to_string(env, jarg2, (char**)&remote_providerID);
    return_value =  lasso_login_init_idp_initiated_authn_request(login, (const gchar*) remote_providerID);
    if (remote_providerID)
        g_free(remote_providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_login_must_ask_for_consent( LassoLogin* login {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1must_1ask_1for_1consent(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jboolean ret;
    LassoLogin* login = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    return_value =  lasso_login_must_ask_for_consent(login);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_login_must_authenticate( LassoLogin* login {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1must_1authenticate(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jboolean ret;
    LassoLogin* login = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    return_value =  lasso_login_must_authenticate(login);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_process_authn_request_msg( LassoLogin* login {}, const char* authn_request_msg {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1process_1authn_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLogin* login = NULL;
    char* authn_request_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    jstring_to_string(env, jarg2, (char**)&authn_request_msg);
    return_value =  lasso_login_process_authn_request_msg(login, (const char*) authn_request_msg);
    if (authn_request_msg)
        g_free(authn_request_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_process_authn_response_msg( LassoLogin* login {}, gchar* authn_response_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1process_1authn_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLogin* login = NULL;
    gchar* authn_response_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    jstring_to_string(env, jarg2, (char**)&authn_response_msg);
    return_value =  lasso_login_process_authn_response_msg(login, authn_response_msg);
    if (authn_response_msg)
        g_free(authn_response_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_process_request_msg( LassoLogin* login {}, gchar* request_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1process_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLogin* login = NULL;
    gchar* request_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    jstring_to_string(env, jarg2, (char**)&request_msg);
    return_value =  lasso_login_process_request_msg(login, request_msg);
    if (request_msg)
        g_free(request_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_process_response_msg( LassoLogin* login {}, gchar* response_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1process_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLogin* login = NULL;
    gchar* response_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    jstring_to_string(env, jarg2, (char**)&response_msg);
    return_value =  lasso_login_process_response_msg(login, response_msg);
    if (response_msg)
        g_free(response_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_validate_request_msg( LassoLogin* login {}, gboolean authentication_result {}, gboolean is_consent_obtained {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1validate_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jboolean jarg2 ,jboolean jarg3 )
  {
    jint ret;
    LassoLogin* login = NULL;
    gboolean authentication_result;
    gboolean is_consent_obtained;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    authentication_result = (gboolean)jarg2;
    is_consent_obtained = (gboolean)jarg3;
    return_value =  lasso_login_validate_request_msg(login, authentication_result, is_consent_obtained);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_login_process_paos_response_msg( LassoLogin* login {}, gchar* msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1process_1paos_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLogin* login = NULL;
    gchar* msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    jstring_to_string(env, jarg2, (char**)&msg);
    return_value =  lasso_login_process_paos_response_msg(login, msg);
    if (msg)
        g_free(msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_login_get_assertion( LassoLogin* login {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_login_1get_1assertion(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jobject ret;
    LassoLogin* login = NULL;
    LassoNode* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&login);
    return_value =  lasso_login_get_assertion(login);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_registration_build_request_msg( LassoNameRegistration* name_registration {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1registration_1build_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoNameRegistration* name_registration = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_registration);
    return_value =  lasso_name_registration_build_request_msg(name_registration);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_registration_build_response_msg( LassoNameRegistration* name_registration {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1registration_1build_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoNameRegistration* name_registration = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_registration);
    return_value =  lasso_name_registration_build_response_msg(name_registration);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gchar* lasso_name_registration_dump( LassoNameRegistration* name_registration {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1registration_1dump(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoNameRegistration* name_registration = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_registration);
    return_value =  lasso_name_registration_dump(name_registration);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_registration_init_request( LassoNameRegistration* name_registration {}, char* remote_providerID {}, LassoHttpMethod http_method {'optional': True, 'default': 'c:LASSO_HTTP_METHOD_ANY'}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1registration_1init_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jint jarg3 )
  {
    jint ret;
    LassoNameRegistration* name_registration = NULL;
    char* remote_providerID = NULL;
    LassoHttpMethod http_method;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_registration);
    jstring_to_string(env, jarg2, (char**)&remote_providerID);
    http_method = (LassoHttpMethod)jarg3;
    return_value =  lasso_name_registration_init_request(name_registration, remote_providerID, http_method);
    if (remote_providerID)
        g_free(remote_providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_registration_process_request_msg( LassoNameRegistration* name_registration {}, gchar* request_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1registration_1process_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoNameRegistration* name_registration = NULL;
    gchar* request_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_registration);
    jstring_to_string(env, jarg2, (char**)&request_msg);
    return_value =  lasso_name_registration_process_request_msg(name_registration, request_msg);
    if (request_msg)
        g_free(request_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_registration_process_response_msg( LassoNameRegistration* name_registration {}, gchar* response_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1registration_1process_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoNameRegistration* name_registration = NULL;
    gchar* response_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_registration);
    jstring_to_string(env, jarg2, (char**)&response_msg);
    return_value =  lasso_name_registration_process_response_msg(name_registration, response_msg);
    if (response_msg)
        g_free(response_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_registration_validate_request( LassoNameRegistration* name_registration {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1registration_1validate_1request(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoNameRegistration* name_registration = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&name_registration);
    return_value =  lasso_name_registration_validate_request(name_registration);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_defederation_build_notification_msg( LassoDefederation* defederation {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_defederation_1build_1notification_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoDefederation* defederation = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&defederation);
    return_value =  lasso_defederation_build_notification_msg(defederation);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_defederation_init_notification( LassoDefederation* defederation {}, gchar* remote_providerID {'optional': True}, LassoHttpMethod http_method {'optional': True, 'default': 'c:LASSO_HTTP_METHOD_ANY'}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_defederation_1init_1notification(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jint jarg3 )
  {
    jint ret;
    LassoDefederation* defederation = NULL;
    gchar* remote_providerID = NULL;
    LassoHttpMethod http_method;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&defederation);
    jstring_to_string(env, jarg2, (char**)&remote_providerID);
    http_method = (LassoHttpMethod)jarg3;
    return_value =  lasso_defederation_init_notification(defederation, remote_providerID, http_method);
    if (remote_providerID)
        g_free(remote_providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_defederation_process_notification_msg( LassoDefederation* defederation {}, gchar* notification_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_defederation_1process_1notification_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoDefederation* defederation = NULL;
    gchar* notification_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&defederation);
    jstring_to_string(env, jarg2, (char**)&notification_msg);
    return_value =  lasso_defederation_process_notification_msg(defederation, notification_msg);
    if (notification_msg)
        g_free(notification_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_defederation_validate_notification( LassoDefederation* defederation {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_defederation_1validate_1notification(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoDefederation* defederation = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&defederation);
    return_value =  lasso_defederation_validate_notification(defederation);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoSaml2EncryptedElement* lasso_provider_saml2_node_encrypt( const LassoProvider* provider {}, LassoNode* lasso_node {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1saml2_1node_1encrypt(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jobject ret;
    LassoProvider* provider = NULL;
    LassoNode* lasso_node = NULL;
    LassoSaml2EncryptedElement* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&lasso_node);
    return_value =  lasso_provider_saml2_node_encrypt((const LassoProvider*) provider, lasso_node);
    gobject_to_jobject(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  gchar* lasso_provider_get_assertion_consumer_service_url( LassoProvider* provider {}, const char* service_id {'optional': True}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1assertion_1consumer_1service_1url(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jstring ret;
    LassoProvider* provider = NULL;
    char* service_id = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jstring_to_string(env, jarg2, (char**)&service_id);
    return_value =  lasso_provider_get_assertion_consumer_service_url(provider, (const char*) service_id);
    if (service_id)
        g_free(service_id);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  gchar* lasso_provider_get_metadata_one( LassoProvider* provider {}, const char* name {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1metadata_1one(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jstring ret;
    LassoProvider* provider = NULL;
    char* name = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jstring_to_string(env, jarg2, (char**)&name);
    return_value =  lasso_provider_get_metadata_one(provider, (const char*) name);
    if (name)
        g_free(name);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  GList* lasso_provider_get_metadata_list( LassoProvider* provider {}, const char* name {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1metadata_1list(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobjectArray ret;
    LassoProvider* provider = NULL;
    char* name = NULL;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jstring_to_string(env, jarg2, (char**)&name);
    return_value =  lasso_provider_get_metadata_list(provider, (const char*) name);
    if (name)
        g_free(name);
    get_list_of_strings(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  LassoHttpMethod lasso_provider_get_first_http_method( LassoProvider* provider {'transfer': 'none'}, LassoProvider* remote_provider {}, LassoMdProtocolType protocol_type {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1first_1http_1method(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 ,jint jarg3 )
  {
    jint ret;
    LassoProvider* provider = NULL;
    LassoProvider* remote_provider = NULL;
    LassoMdProtocolType protocol_type;
    LassoHttpMethod return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&remote_provider);
    protocol_type = (LassoMdProtocolType)jarg3;
    return_value =  lasso_provider_get_first_http_method(provider, remote_provider, protocol_type);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_provider_accept_http_method( LassoProvider* provider {}, LassoProvider* remote_provider {}, LassoMdProtocolType protocol_type {}, LassoHttpMethod http_method {}, gboolean initiate_profile {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1accept_1http_1method(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 ,jint jarg3 ,jint jarg4 ,jboolean jarg5 )
  {
    jboolean ret;
    LassoProvider* provider = NULL;
    LassoProvider* remote_provider = NULL;
    LassoMdProtocolType protocol_type;
    LassoHttpMethod http_method;
    gboolean initiate_profile;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&remote_provider);
    protocol_type = (LassoMdProtocolType)jarg3;
    http_method = (LassoHttpMethod)jarg4;
    initiate_profile = (gboolean)jarg5;
    return_value =  lasso_provider_accept_http_method(provider, remote_provider, protocol_type, http_method, initiate_profile);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_provider_has_protocol_profile( LassoProvider* provider {}, LassoMdProtocolType protocol_type {}, const char* protocol_profile {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1has_1protocol_1profile(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jstring jarg3 )
  {
    jboolean ret;
    LassoProvider* provider = NULL;
    LassoMdProtocolType protocol_type;
    char* protocol_profile = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    protocol_type = (LassoMdProtocolType)jarg2;
    jstring_to_string(env, jarg3, (char**)&protocol_profile);
    return_value =  lasso_provider_has_protocol_profile(provider, protocol_type, (const char*) protocol_profile);
    if (protocol_profile)
        g_free(protocol_profile);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  gchar* lasso_provider_get_base64_succinct_id( const LassoProvider* provider {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1base64_1succinct_1id(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoProvider* provider = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    return_value =  lasso_provider_get_base64_succinct_id((const LassoProvider*) provider);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  xmlNode* lasso_provider_get_organization( const LassoProvider* provider {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1organization(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoProvider* provider = NULL;
    xmlNode* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    return_value =  lasso_provider_get_organization((const LassoProvider*) provider);
    xml_node_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  LassoProtocolConformance lasso_provider_get_protocol_conformance( const LassoProvider* provider {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1protocol_1conformance(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoProvider* provider = NULL;
    LassoProtocolConformance return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    return_value =  lasso_provider_get_protocol_conformance((const LassoProvider*) provider);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  void lasso_provider_set_protocol_conformance( LassoProvider* provider {}, LassoProtocolConformance protocol_conformance {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1set_1protocol_1conformance(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 )
  {
    LassoProvider* provider = NULL;
    LassoProtocolConformance protocol_conformance;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    protocol_conformance = (LassoProtocolConformance)jarg2;
    lasso_provider_set_protocol_conformance(provider, protocol_conformance);
  }
/* Wrapper function for  void lasso_provider_set_encryption_mode( LassoProvider* provider {}, LassoEncryptionMode encryption_mode {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1set_1encryption_1mode(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 )
  {
    LassoProvider* provider = NULL;
    LassoEncryptionMode encryption_mode;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    encryption_mode = (LassoEncryptionMode)jarg2;
    lasso_provider_set_encryption_mode(provider, encryption_mode);
  }
/* Wrapper function for  LassoEncryptionMode lasso_provider_get_encryption_mode( LassoProvider* provider {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1encryption_1mode(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoProvider* provider = NULL;
    LassoEncryptionMode return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    return_value =  lasso_provider_get_encryption_mode(provider);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  void lasso_provider_set_encryption_sym_key_type( LassoProvider* provider {}, LassoEncryptionSymKeyType encryption_sym_key_type {}, ) */
JNIEXPORT void JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1set_1encryption_1sym_1key_1type(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 )
  {
    LassoProvider* provider = NULL;
    LassoEncryptionSymKeyType encryption_sym_key_type;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    encryption_sym_key_type = (LassoEncryptionSymKeyType)jarg2;
    lasso_provider_set_encryption_sym_key_type(provider, encryption_sym_key_type);
  }
/* Wrapper function for  gchar* lasso_provider_get_default_name_id_format( LassoProvider* provider {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1default_1name_1id_1format(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoProvider* provider = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    return_value =  lasso_provider_get_default_name_id_format(provider);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  const char* lasso_provider_get_sp_name_qualifier( LassoProvider* provider {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1sp_1name_1qualifier(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoProvider* provider = NULL;
    const char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    return_value =  lasso_provider_get_sp_name_qualifier(provider);
    string_to_jstring(env, return_value, &ret);
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_provider_verify_single_node_signature( LassoProvider* provider {}, LassoNode* node {}, const char* id_attr_name {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1verify_1single_1node_1signature(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 ,jstring jarg3 )
  {
    jint ret;
    LassoProvider* provider = NULL;
    LassoNode* node = NULL;
    char* id_attr_name = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&node);
    jstring_to_string(env, jarg3, (char**)&id_attr_name);
    return_value =  lasso_provider_verify_single_node_signature(provider, node, (const char*) id_attr_name);
    if (id_attr_name)
        g_free(id_attr_name);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  GList* lasso_provider_get_idp_supported_attributes( LassoProvider* provider {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1idp_1supported_1attributes(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jobjectArray ret;
    LassoProvider* provider = NULL;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    return_value =  lasso_provider_get_idp_supported_attributes(provider);
    get_list_of_objects(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  char* lasso_provider_get_valid_until( LassoProvider* provider {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1valid_1until(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoProvider* provider = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    return_value =  lasso_provider_get_valid_until(provider);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_provider_get_cache_duration( LassoProvider* provider {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1cache_1duration(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoProvider* provider = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    return_value =  lasso_provider_get_cache_duration(provider);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  char* lasso_provider_get_metadata_one_for_role( LassoProvider* provider {}, LassoProviderRole role {}, const char* name {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1metadata_1one_1for_1role(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jstring jarg3 )
  {
    jstring ret;
    LassoProvider* provider = NULL;
    LassoProviderRole role;
    char* name = NULL;
    char* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    role = (LassoProviderRole)jarg2;
    jstring_to_string(env, jarg3, (char**)&name);
    return_value =  lasso_provider_get_metadata_one_for_role(provider, role, (const char*) name);
    if (name)
        g_free(name);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  GList* lasso_provider_get_metadata_list_for_role( const LassoProvider* provider {}, LassoProviderRole role {}, const char* name {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1metadata_1list_1for_1role(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jstring jarg3 )
  {
    jobjectArray ret;
    LassoProvider* provider = NULL;
    LassoProviderRole role;
    char* name = NULL;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    role = (LassoProviderRole)jarg2;
    jstring_to_string(env, jarg3, (char**)&name);
    return_value =  lasso_provider_get_metadata_list_for_role((const LassoProvider*) provider, role, (const char*) name);
    if (name)
        g_free(name);
    get_list_of_strings(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  GList* lasso_provider_get_metadata_keys_for_role( LassoProvider* provider {}, LassoProviderRole role {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1metadata_1keys_1for_1role(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 )
  {
    jobjectArray ret;
    LassoProvider* provider = NULL;
    LassoProviderRole role;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    role = (LassoProviderRole)jarg2;
    return_value =  lasso_provider_get_metadata_keys_for_role(provider, role);
    get_list_of_strings(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  LassoProviderRole lasso_provider_get_roles( LassoProvider* provider {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1get_1roles(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoProvider* provider = NULL;
    LassoProviderRole return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    return_value =  lasso_provider_get_roles(provider);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gboolean lasso_provider_match_conformance( LassoProvider* provider {}, LassoProvider* another_provider {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1match_1conformance(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jboolean ret;
    LassoProvider* provider = NULL;
    LassoProvider* another_provider = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&another_provider);
    return_value =  lasso_provider_match_conformance(provider, another_provider);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_provider_set_server_signing_key( LassoProvider* provider {}, LassoKey* key {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1set_1server_1signing_1key(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jint ret;
    LassoProvider* provider = NULL;
    LassoKey* key = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&key);
    return_value =  lasso_provider_set_server_signing_key(provider, key);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_provider_add_key( LassoProvider* provider {}, LassoKey* key {}, gboolean after {'default': 'b:FALSE', 'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1add_1key(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 ,jboolean jarg3 )
  {
    jint ret;
    LassoProvider* provider = NULL;
    LassoKey* key = NULL;
    gboolean after;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&key);
    after = (gboolean)jarg3;
    return_value =  lasso_provider_add_key(provider, key, after);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  int lasso_provider_verify_signature( LassoProvider* provider {}, const char* message {}, const char* id_attr_name {}, LassoMessageFormat format {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_provider_1verify_1signature(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 ,jint jarg4 )
  {
    jint ret;
    LassoProvider* provider = NULL;
    char* message = NULL;
    char* id_attr_name = NULL;
    LassoMessageFormat format;
    int return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&provider);
    jstring_to_string(env, jarg2, (char**)&message);
    jstring_to_string(env, jarg3, (char**)&id_attr_name);
    format = (LassoMessageFormat)jarg4;
    return_value =  lasso_provider_verify_signature(provider, (const char*) message, (const char*) id_attr_name, format);
    if (message)
        g_free(message);
    if (id_attr_name)
        g_free(id_attr_name);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_server_saml2_assertion_setup_signature( LassoServer* server {}, LassoSaml2Assertion* saml2_assertion {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1saml2_1assertion_1setup_1signature(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jint ret;
    LassoServer* server = NULL;
    LassoSaml2Assertion* saml2_assertion = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&saml2_assertion);
    return_value =  lasso_server_saml2_assertion_setup_signature(server, saml2_assertion);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_server_add_provider( LassoServer* server {}, LassoProviderRole role {}, const gchar* metadata {}, const gchar* public_key {'optional': True}, const gchar* ca_cert_chain {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1add_1provider(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jstring jarg3 ,jstring jarg4 ,jstring jarg5 )
  {
    jint ret;
    LassoServer* server = NULL;
    LassoProviderRole role;
    gchar* metadata = NULL;
    gchar* public_key = NULL;
    gchar* ca_cert_chain = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    role = (LassoProviderRole)jarg2;
    jstring_to_string(env, jarg3, (char**)&metadata);
    jstring_to_string(env, jarg4, (char**)&public_key);
    jstring_to_string(env, jarg5, (char**)&ca_cert_chain);
    return_value =  lasso_server_add_provider(server, role, (const gchar*) metadata, (const gchar*) public_key, (const gchar*) ca_cert_chain);
    if (metadata)
        g_free(metadata);
    if (public_key)
        g_free(public_key);
    if (ca_cert_chain)
        g_free(ca_cert_chain);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_server_add_provider_from_buffer( LassoServer* server {}, LassoProviderRole role {}, const gchar* metadata {}, const gchar* public_key {'optional': True}, const gchar* ca_cert_chain {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1add_1provider_1from_1buffer(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jstring jarg3 ,jstring jarg4 ,jstring jarg5 )
  {
    jint ret;
    LassoServer* server = NULL;
    LassoProviderRole role;
    gchar* metadata = NULL;
    gchar* public_key = NULL;
    gchar* ca_cert_chain = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    role = (LassoProviderRole)jarg2;
    jstring_to_string(env, jarg3, (char**)&metadata);
    jstring_to_string(env, jarg4, (char**)&public_key);
    jstring_to_string(env, jarg5, (char**)&ca_cert_chain);
    return_value =  lasso_server_add_provider_from_buffer(server, role, (const gchar*) metadata, (const gchar*) public_key, (const gchar*) ca_cert_chain);
    if (metadata)
        g_free(metadata);
    if (public_key)
        g_free(public_key);
    if (ca_cert_chain)
        g_free(ca_cert_chain);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gchar* lasso_server_dump( LassoServer* server {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1dump(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoServer* server = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    return_value =  lasso_server_dump(server);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  LassoProvider* lasso_server_get_provider( const LassoServer* server {}, const gchar* providerID {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1get_1provider(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobject ret;
    LassoServer* server = NULL;
    gchar* providerID = NULL;
    LassoProvider* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jstring_to_string(env, jarg2, (char**)&providerID);
    return_value =  lasso_server_get_provider((const LassoServer*) server, (const gchar*) providerID);
    if (providerID)
        g_free(providerID);
    gobject_to_jobject_and_ref(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_server_set_encryption_private_key( LassoServer* server {}, const gchar* filename_or_buffer {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1set_1encryption_1private_1key(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoServer* server = NULL;
    gchar* filename_or_buffer = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jstring_to_string(env, jarg2, (char**)&filename_or_buffer);
    return_value =  lasso_server_set_encryption_private_key(server, (const gchar*) filename_or_buffer);
    if (filename_or_buffer)
        g_free(filename_or_buffer);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_server_load_affiliation( LassoServer* server {}, const gchar* filename {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1load_1affiliation(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoServer* server = NULL;
    gchar* filename = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jstring_to_string(env, jarg2, (char**)&filename);
    return_value =  lasso_server_load_affiliation(server, (const gchar*) filename);
    if (filename)
        g_free(filename);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_server_set_encryption_private_key_with_password( LassoServer* server {}, const gchar* filename_or_buffer {'optional': True}, const gchar* password {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1set_1encryption_1private_1key_1with_1password(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    jint ret;
    LassoServer* server = NULL;
    gchar* filename_or_buffer = NULL;
    gchar* password = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jstring_to_string(env, jarg2, (char**)&filename_or_buffer);
    jstring_to_string(env, jarg3, (char**)&password);
    return_value =  lasso_server_set_encryption_private_key_with_password(server, (const gchar*) filename_or_buffer, (const gchar*) password);
    if (filename_or_buffer)
        g_free(filename_or_buffer);
    if (password)
        g_free(password);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_server_add_provider2( LassoServer* server {}, LassoProvider* provider {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1add_1provider2(JNIEnv *env, jclass clss
,jobject jarg1 ,jobject jarg2 )
  {
    jint ret;
    LassoServer* server = NULL;
    LassoProvider* provider = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jobject_to_gobject_noref(env, jarg2, (GObject**)&provider);
    return_value =  lasso_server_add_provider2(server, provider);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gchar* lasso_server_get_endpoint_url_by_id( const LassoServer* server {}, const gchar* provider_id {}, const gchar* endpoint_description {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1get_1endpoint_1url_1by_1id(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    jstring ret;
    LassoServer* server = NULL;
    gchar* provider_id = NULL;
    gchar* endpoint_description = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    jstring_to_string(env, jarg2, (char**)&provider_id);
    jstring_to_string(env, jarg3, (char**)&endpoint_description);
    return_value =  lasso_server_get_endpoint_url_by_id((const LassoServer*) server, (const gchar*) provider_id, (const gchar*) endpoint_description);
    if (provider_id)
        g_free(provider_id);
    if (endpoint_description)
        g_free(endpoint_description);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  GList* lasso_server_get_filtered_provider_list( const LassoServer* server {}, LassoProviderRole role {}, LassoMdProtocolType protocol_type {}, LassoHttpMethod http_method {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_server_1get_1filtered_1provider_1list(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 ,jint jarg3 ,jint jarg4 )
  {
    jobjectArray ret;
    LassoServer* server = NULL;
    LassoProviderRole role;
    LassoMdProtocolType protocol_type;
    LassoHttpMethod http_method;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&server);
    role = (LassoProviderRole)jarg2;
    protocol_type = (LassoMdProtocolType)jarg3;
    http_method = (LassoHttpMethod)jarg4;
    return_value =  lasso_server_get_filtered_provider_list((const LassoServer*) server, role, protocol_type, http_method);
    get_list_of_strings(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  gchar* lasso_session_dump( LassoSession* session {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1dump(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoSession* session = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&session);
    return_value =  lasso_session_dump(session);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  GList* lasso_session_get_assertions( LassoSession* session {}, const char* provider_id {'optional': True}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1get_1assertions(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobjectArray ret;
    LassoSession* session = NULL;
    char* provider_id = NULL;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&session);
    jstring_to_string(env, jarg2, (char**)&provider_id);
    return_value =  lasso_session_get_assertions(session, (const char*) provider_id);
    if (provider_id)
        g_free(provider_id);
    get_list_of_objects(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  gchar* lasso_session_get_provider_index( LassoSession* session {}, gint index {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1get_1provider_1index(JNIEnv *env, jclass clss
,jobject jarg1 ,jint jarg2 )
  {
    jstring ret;
    LassoSession* session = NULL;
    gint index;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&session);
    index = (gint)jarg2;
    return_value =  lasso_session_get_provider_index(session, index);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  gboolean lasso_session_is_empty( LassoSession* session {}, ) */
JNIEXPORT jboolean JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1is_1empty(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jboolean ret;
    LassoSession* session = NULL;
    gboolean return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&session);
    return_value =  lasso_session_is_empty(session);
    ret = (jboolean)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_session_remove_assertion( LassoSession* session {}, const gchar* providerID {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1remove_1assertion(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoSession* session = NULL;
    gchar* providerID = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&session);
    jstring_to_string(env, jarg2, (char**)&providerID);
    return_value =  lasso_session_remove_assertion(session, (const gchar*) providerID);
    if (providerID)
        g_free(providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoNode* lasso_session_get_assertion( LassoSession* session {}, const gchar* providerID {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1get_1assertion(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobject ret;
    LassoSession* session = NULL;
    gchar* providerID = NULL;
    LassoNode* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&session);
    jstring_to_string(env, jarg2, (char**)&providerID);
    return_value =  lasso_session_get_assertion(session, (const gchar*) providerID);
    if (providerID)
        g_free(providerID);
    gobject_to_jobject_and_ref(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_session_add_assertion( LassoSession* session {}, const char* providerID {}, LassoNode* assertion {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1add_1assertion(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jobject jarg3 )
  {
    jint ret;
    LassoSession* session = NULL;
    char* providerID = NULL;
    LassoNode* assertion = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&session);
    jstring_to_string(env, jarg2, (char**)&providerID);
    jobject_to_gobject_noref(env, jarg3, (GObject**)&assertion);
    return_value =  lasso_session_add_assertion(session, (const char*) providerID, assertion);
    if (providerID)
        g_free(providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  GList* lasso_session_get_name_ids( LassoSession* session {}, const gchar* providerID {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1get_1name_1ids(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobjectArray ret;
    LassoSession* session = NULL;
    gchar* providerID = NULL;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&session);
    jstring_to_string(env, jarg2, (char**)&providerID);
    return_value =  lasso_session_get_name_ids(session, (const gchar*) providerID);
    if (providerID)
        g_free(providerID);
    get_list_of_objects(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  GList* lasso_session_get_session_indexes( LassoSession* session {}, const gchar* providerID {}, LassoNode* name_id {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1get_1session_1indexes(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jobject jarg3 )
  {
    jobjectArray ret;
    LassoSession* session = NULL;
    gchar* providerID = NULL;
    LassoNode* name_id = NULL;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&session);
    jstring_to_string(env, jarg2, (char**)&providerID);
    jobject_to_gobject_noref(env, jarg3, (GObject**)&name_id);
    return_value =  lasso_session_get_session_indexes(session, (const gchar*) providerID, name_id);
    if (providerID)
        g_free(providerID);
    get_list_of_strings(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  GList* lasso_session_get_assertion_ids( LassoSession* session {}, const gchar* providerID {}, ) */
JNIEXPORT jobjectArray JNICALL Java_com_entrouvert_lasso_LassoJNI_session_1get_1assertion_1ids(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobjectArray ret;
    LassoSession* session = NULL;
    gchar* providerID = NULL;
    GList* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&session);
    jstring_to_string(env, jarg2, (char**)&providerID);
    return_value =  lasso_session_get_assertion_ids(session, (const gchar*) providerID);
    if (providerID)
        g_free(providerID);
    get_list_of_strings(env, return_value, &ret);
    free_glist(&return_value, NULL);
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_logout_build_request_msg( LassoLogout* logout {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1build_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLogout* logout = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout);
    return_value =  lasso_logout_build_request_msg(logout);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_logout_build_response_msg( LassoLogout* logout {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1build_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLogout* logout = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout);
    return_value =  lasso_logout_build_response_msg(logout);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  gchar* lasso_logout_dump( LassoLogout* logout {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1dump(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoLogout* logout = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout);
    return_value =  lasso_logout_dump(logout);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  gchar* lasso_logout_get_next_providerID( LassoLogout* logout {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1get_1next_1providerID(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoLogout* logout = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout);
    return_value =  lasso_logout_get_next_providerID(logout);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_logout_init_request( LassoLogout* logout {}, gchar* remote_providerID {'optional': True}, LassoHttpMethod request_method {'optional': True, 'default': 'c:LASSO_HTTP_METHOD_ANY'}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1init_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jint jarg3 )
  {
    jint ret;
    LassoLogout* logout = NULL;
    gchar* remote_providerID = NULL;
    LassoHttpMethod request_method;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout);
    jstring_to_string(env, jarg2, (char**)&remote_providerID);
    request_method = (LassoHttpMethod)jarg3;
    return_value =  lasso_logout_init_request(logout, remote_providerID, request_method);
    if (remote_providerID)
        g_free(remote_providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_logout_process_request_msg( LassoLogout* logout {}, gchar* request_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1process_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLogout* logout = NULL;
    gchar* request_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout);
    jstring_to_string(env, jarg2, (char**)&request_msg);
    return_value =  lasso_logout_process_request_msg(logout, request_msg);
    if (request_msg)
        g_free(request_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_logout_process_response_msg( LassoLogout* logout {}, gchar* response_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1process_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLogout* logout = NULL;
    gchar* response_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout);
    jstring_to_string(env, jarg2, (char**)&response_msg);
    return_value =  lasso_logout_process_response_msg(logout, response_msg);
    if (response_msg)
        g_free(response_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_logout_reset_providerID_index( LassoLogout* logout {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1reset_1providerID_1index(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLogout* logout = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout);
    return_value =  lasso_logout_reset_providerID_index(logout);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_logout_validate_request( LassoLogout* logout {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_logout_1validate_1request(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLogout* logout = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&logout);
    return_value =  lasso_logout_validate_request(logout);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_identifier_mapping_build_request_msg( LassoNameIdentifierMapping* mapping {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1identifier_1mapping_1build_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoNameIdentifierMapping* mapping = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&mapping);
    return_value =  lasso_name_identifier_mapping_build_request_msg(mapping);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_identifier_mapping_build_response_msg( LassoNameIdentifierMapping* mapping {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1identifier_1mapping_1build_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoNameIdentifierMapping* mapping = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&mapping);
    return_value =  lasso_name_identifier_mapping_build_response_msg(mapping);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_identifier_mapping_init_request( LassoNameIdentifierMapping* mapping {}, gchar* targetNamespace {}, gchar* remote_providerID {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1identifier_1mapping_1init_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 ,jstring jarg3 )
  {
    jint ret;
    LassoNameIdentifierMapping* mapping = NULL;
    gchar* targetNamespace = NULL;
    gchar* remote_providerID = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&mapping);
    jstring_to_string(env, jarg2, (char**)&targetNamespace);
    jstring_to_string(env, jarg3, (char**)&remote_providerID);
    return_value =  lasso_name_identifier_mapping_init_request(mapping, targetNamespace, remote_providerID);
    if (targetNamespace)
        g_free(targetNamespace);
    if (remote_providerID)
        g_free(remote_providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_identifier_mapping_process_request_msg( LassoNameIdentifierMapping* mapping {}, gchar* request_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1identifier_1mapping_1process_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoNameIdentifierMapping* mapping = NULL;
    gchar* request_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&mapping);
    jstring_to_string(env, jarg2, (char**)&request_msg);
    return_value =  lasso_name_identifier_mapping_process_request_msg(mapping, request_msg);
    if (request_msg)
        g_free(request_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_identifier_mapping_process_response_msg( LassoNameIdentifierMapping* mapping {}, gchar* response_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1identifier_1mapping_1process_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoNameIdentifierMapping* mapping = NULL;
    gchar* response_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&mapping);
    jstring_to_string(env, jarg2, (char**)&response_msg);
    return_value =  lasso_name_identifier_mapping_process_response_msg(mapping, response_msg);
    if (response_msg)
        g_free(response_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_name_identifier_mapping_validate_request( LassoNameIdentifierMapping* mapping {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_name_1identifier_1mapping_1validate_1request(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoNameIdentifierMapping* mapping = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&mapping);
    return_value =  lasso_name_identifier_mapping_validate_request(mapping);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  LassoFederation* lasso_identity_get_federation( LassoIdentity* identity {}, const char* providerID {}, ) */
JNIEXPORT jobject JNICALL Java_com_entrouvert_lasso_LassoJNI_identity_1get_1federation(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jobject ret;
    LassoIdentity* identity = NULL;
    char* providerID = NULL;
    LassoFederation* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&identity);
    jstring_to_string(env, jarg2, (char**)&providerID);
    return_value =  lasso_identity_get_federation(identity, (const char*) providerID);
    if (providerID)
        g_free(providerID);
    gobject_to_jobject_and_ref(env, (GObject*)return_value, &ret);;
    return ret;
  }
/* Wrapper function for  gchar* lasso_identity_dump( LassoIdentity* identity {}, ) */
JNIEXPORT jstring JNICALL Java_com_entrouvert_lasso_LassoJNI_identity_1dump(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jstring ret;
    LassoIdentity* identity = NULL;
    gchar* return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&identity);
    return_value =  lasso_identity_dump(identity);
    string_to_jstring(env, return_value, &ret);
    if (return_value)
        g_free(return_value);
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_lecp_build_authn_request_envelope_msg( LassoLecp* lecp {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_lecp_1build_1authn_1request_1envelope_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLecp* lecp = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&lecp);
    return_value =  lasso_lecp_build_authn_request_envelope_msg(lecp);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_lecp_build_authn_request_msg( LassoLecp* lecp {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_lecp_1build_1authn_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLecp* lecp = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&lecp);
    return_value =  lasso_lecp_build_authn_request_msg(lecp);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_lecp_build_authn_response_msg( LassoLecp* lecp {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_lecp_1build_1authn_1response_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLecp* lecp = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&lecp);
    return_value =  lasso_lecp_build_authn_response_msg(lecp);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_lecp_build_authn_response_envelope_msg( LassoLecp* lecp {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_lecp_1build_1authn_1response_1envelope_1msg(JNIEnv *env, jclass clss
,jobject jarg1 )
  {
    jint ret;
    LassoLecp* lecp = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&lecp);
    return_value =  lasso_lecp_build_authn_response_envelope_msg(lecp);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_lecp_init_authn_request( LassoLecp* lecp {}, const char* remote_providerID {'optional': True}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_lecp_1init_1authn_1request(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLecp* lecp = NULL;
    char* remote_providerID = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&lecp);
    jstring_to_string(env, jarg2, (char**)&remote_providerID);
    return_value =  lasso_lecp_init_authn_request(lecp, (const char*) remote_providerID);
    if (remote_providerID)
        g_free(remote_providerID);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_lecp_process_authn_request_msg( LassoLecp* lecp {}, const char* authn_request_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_lecp_1process_1authn_1request_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLecp* lecp = NULL;
    char* authn_request_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&lecp);
    jstring_to_string(env, jarg2, (char**)&authn_request_msg);
    return_value =  lasso_lecp_process_authn_request_msg(lecp, (const char*) authn_request_msg);
    if (authn_request_msg)
        g_free(authn_request_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_lecp_process_authn_request_envelope_msg( LassoLecp* lecp {}, const char* request_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_lecp_1process_1authn_1request_1envelope_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLecp* lecp = NULL;
    char* request_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&lecp);
    jstring_to_string(env, jarg2, (char**)&request_msg);
    return_value =  lasso_lecp_process_authn_request_envelope_msg(lecp, (const char*) request_msg);
    if (request_msg)
        g_free(request_msg);
    ret = (jint)return_value;
    return ret;
  }
/* Wrapper function for  lasso_error_t lasso_lecp_process_authn_response_envelope_msg( LassoLecp* lecp {}, const char* response_msg {}, ) */
JNIEXPORT jint JNICALL Java_com_entrouvert_lasso_LassoJNI_lecp_1process_1authn_1response_1envelope_1msg(JNIEnv *env, jclass clss
,jobject jarg1 ,jstring jarg2 )
  {
    jint ret;
    LassoLecp* lecp = NULL;
    char* response_msg = NULL;
    lasso_error_t return_value;
    jobject_to_gobject_noref(env, jarg1, (GObject**)&lecp);
    jstring_to_string(env, jarg2, (char**)&response_msg);
    return_value =  lasso_lecp_process_authn_response_envelope_msg(lecp, (const char*) response_msg);
    if (response_msg)
        g_free(response_msg);
    ret = (jint)return_value;
    return ret;
  }

